/**
 * The CouragePotion class represents a potion that can be consumed by the kobold,
 * which increases its charisma, but lowers its intelligence.
 */
function CouragePotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Courage Potion";
    var itemDescription = `A glass bottle filled to the brim with clear liquid.
                           Promises to make you more courageous.`;
    var baseValue = 40;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                            The colorless fluid within smells like liquor.
                            Alcohol.
                            Booze, the strong kind.
                            You're starting to think this may just be a bottle of whiskey.
                        [/p]
                        [p]
                            Does it really matter whether this is an alcoholic beverage or a potion?
                            You could use either, really.
                            You bring the bottle to your lips, and chug down.
                        [/p]
                        [p]
                            The liquid immediately proves to be a [b]hard[/b] drink.
                            You can already [b]feel[/b] yourself getting tipsy after having downed just a first mouthful of the stuff.
                            It somewhat burns your throat, but it's a [b]good[/b] kind of burn.
                            A [b]satifying[/b] pain.
                            It tastes pretty darn great.
                            Whatever liquor this is, it clearly has been aging for [b]years[/b].
                            It [b]really[/b] hits the spot.
                        [/p]
                        [p]
                            A couple of gulps later, you are completely [b]hammered[/b].
                            You almost fall down on your ass while trying to shake the final few drops from the bottle,
                            the entire world spinning around you.
                            You toss the bottle aside, and lick your lips.
                            You feel energized, [b]pumped[/b], as though you can take on the entire world.
                            But your hand-eye coordination is [b]way[/b] off.
                            You barely refrain from tripping over your own tail.
                        [/p]
                        [p]
                            Then, suddenly, as quickly as you became drunk, the sensation fades once more.
                            Your sight stabilizes, you regain fine motor control over [i]all[/i] your limbs, and your dizziness fades.
                            You seem to sober up in a matter of [b]seconds[/b].
                            But not [b]completely[/b].
                            Your brain remains a little sluggish, and your inhibitions are lowered just a bit.
                            You have grown more courageous, as promised.
                            But at what cost?
                        [/p]
                        [p]
                            Huh, guess that thing [b]was[/b] a potion, after all.
                            Booze that doesn't make you drunk?
                            You could use some more of that, even though being drunk is half of the fun of drinking.
                            You're not sure if you feel comfortable with these side effects, though.
                            Being able to approach and talk to people more easily will undoubtebly be a blast,
                            but you'll still need to be able to have the mental capacity to actually [b]form words[/b] to say.
                            And keeping at least [b]some[/b] token of hesitancy would be a good thing.
                            Right?
                        [/p]
                        [p]
                            [b]You have gained 1 charisma.[/b][nl]
                            <span class="warningtext">[b]You have lost 1 intelligence.[/b]</span>
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as courageous as you're ever going to get.
                            You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    /**
     * Builds and returns the consume popup contents when minned out.
     * @returns {string} The consume popup contents when minned out.
     */
    function buildMinContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are too dumb to drink this potion.
                            You spill it all over the floor.
                            Stupid kobold.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.COURAGE_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var cha = global.kobold.stats.get(StatsEnum.CHARISMA);
        var int = global.kobold.stats.get(StatsEnum.INTELLIGENCE);
        var maxed = (cha >= global.kobold.stats.statMax);
        var minned = (int <= global.kobold.stats.statMin);
        if (maxed) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMaxContents()));
            return false;
        }
        if (minned) {
            global.ui.showFullscreenPopup(global.parser.parse(buildMinContents()));
        } else {
            global.kobold.stats.increaseStat(StatsEnum.CHARISMA, 1);
            global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
            global.ui.showFullscreenPopup(buildPopupContents());
        }
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
