/**
 * Repository for all themes.
 * @param {boolean} careAboutSettings If true, the Themes will care about settings in use.
 */
function Themes(careAboutSettings) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Darkens all themes by dampening their background, main, detail and rare color values.
     */
    function darkenThemes() {
        var darkenFactor = global.settings.getDarkThemeModifier() / 100;
        for (var theme in that) {
            if (that[theme].constructor !== Theme) {
                continue;
            }
            that[theme].background.dampen(darkenFactor);
            that[theme].main.dampen(darkenFactor);
            that[theme].detail.dampen(darkenFactor);
            that[theme].rare.dampen(darkenFactor);
        }
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // /forest
    this.forest = new Theme({
        background: "#3B5323",
        main: "#5E2612",
        detail: "#008B00",
        rare: "#FCD116"
    });

    this.deepwoods = new Theme({
        background: {r: 40, g: 61, b: 35},
        main: {r: 70, g: 47, b: 18},
        detail: {r: 49, g: 91, b: 55},
        rare: {r: 255, g: 193, b: 132}
    });

    this.forest_night = new Theme({
        background: {r: 31, g: 13, b: 61},
        main: {r: 28, g: 0, b: 89},
        detail: {r: 41, g: 0, b: 132},
        rare: {r: 127, g: 193, b: 132}
    });

    // /hamlet
    this.hamlet_barn = new Theme({
        background: {r: 51, g: 39, b: 25},
        main: {r: 63, g: 51, b: 45},
        detail: {r: 58, g: 69, b: 78},
        rare: {r: 178, g: 128, b: 59}
    });

    this.hamlet_cave = new Theme({
        background: {r: 10, g: 10, b: 14},
        main: {r: 6, g: 6, b: 12},
        detail: {r: 11, g: 13, b: 23},
        rare: {r: 12, g: 38, b: 50}
    });

    this.hamlet_day = new Theme({
        background: {r: 32, g: 40, b: 3},
        main: {r: 42, g: 37, b: 31},
        detail: {r: 76, g: 34, b: 20},
        rare: {r: 60, g: 65, b: 59}
    });

    this.hamlet_mansion = new Theme({
        background: {r: 61, g: 15, b: 20},
        main: {r: 74, g: 37, b: 0},
        detail: {r: 159, g: 126, b: 40},
        rare: {r: 61, g: 15, b: 61}
    });

    this.hamlet_shop = new Theme({
        background: {r: 20, g: 20, b: 20},
        main: {r: 21, g: 18, b: 15},
        detail: {r: 30, g: 18, b: 12},
        rare: {r: 82, g: 82, b: 82}
    });

    this.hamlet_well = new Theme({
        background: {r: 10, g: 24, b: 23},
        main: {r: 7, g: 13, b: 1},
        detail: {r: 30, g: 44, b: 44},
        rare: {r: 16, g: 82, b: 123}
    });

    // /home
    this.home = new Theme({
        background: {r: 40, g: 61, b: 35},
        main: {r: 70, g: 47, b: 18},
        detail: {r: 49, g: 91, b: 55},
        rare: {r: 255, g: 193, b: 132}
    });

    this.home_dawn = new Theme({
        background: {r: 87, g: 21, b: 53},
        main: {r: 134, g: 12, b: 42},
        detail: {r: 160, g: 48, b: 68},
        rare: {r: 165, g: 49, b: 76}
    });

    this.home_night = new Theme({
        background: {r: 31, g: 13, b: 61},
        main: {r: 28, g: 0, b: 89},
        detail: {r: 41, g: 0, b: 132},
        rare: {r: 127, g: 96, b: 193}
    });

    // /varanar
    this.varanar_alley = new Theme({
        background: {r: 19, g: 19, b: 19},
        main: {r: 23, g: 23, b: 26},
        detail: {r: 35, g: 35, b: 35},
        rare: {r: 69, g: 0, b: 0}
    });

    this.varanar_generic = new Theme({
        background: {r: 49, g: 67, b: 97},
        main: {r: 63, g: 63, b: 77},
        detail: {r: 110, g: 118, b: 133},
        rare: {r: 63, g: 87, b: 121}
    });

    this.varanar_night = new Theme({
        background: {r: 31, g: 24, b: 37},
        main: {r: 42, g: 31, b: 39},
        detail: {r: 51, g: 49, b: 43},
        rare: {r: 95, g: 87, b: 77}
    });

    this.varanar_morning = new Theme({
        background: {r: 105, g: 28, b: 0},
        main: {r: 68, g: 34, b: 34},
        detail: {r: 76, g: 68, b: 46},
        rare: {r: 95, g: 114, b: 68}
    });

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the themes. Does nothing if settings are not cared about.
     */
    this.init = function () {
        if (careAboutSettings && global.settings.getDarkThemeEnabled()) {
            darkenThemes();
        }
    };
}
