/**
 * Talk section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementTalk(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementCartChoice.TALK;
    var reqController = ctrl.cart;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            With nothing better to do, you decide to pass the time by striking a conversation with the guard outside of your cell.
                            You whisper to him, yet there is no response.
                            Raising your voice a little, you casually begin to talk about how you're having a [b]terrible[/b] day.
                            You ask him how [b]his[/b] day is going.
                            There is no response.
                        [/p]
                        [p]
                            Taking his silence for attentivity,
                            you begin to chat about that one time you caught a [b]really[/b] large fish out of the river, with your bare hands!
                            You ask him if he's ever gone fishing.
                            You've seen the way humans and most anthros fish -- using poles and stuff.
                            That's not the way kobolds do it.
                            You just kind of jump in and try to [i]grab[/i] one.
                            You guess that would be kind of hard for someone lacking [i]claws[/i].
                        [/p]
                        [p]
                            That's not to say you wouldn't give the human method a try.
                            It seems relaxing, just sitting in a small boat, or at the river shore, waiting for something to tug on your line.
                            But then again, in [i]this[/i] forest, you doubt you'd be alone for long before attracting some [i]unwanted company[/i].
                            Besides, that fish you told him about?
                            Yeah, you got halfway through cooking that over a campfire before a gang jumped out of the bushes and made you run for your life.
                            That was the last time you tried to cook a catch instead of eating it raw.
                        [/p]
                        [p]
                            You ask the man whether or not he likes to eat fish.
                            You personally prefer meat.
                            You haven't had any proper meat in [b]ages[/b], though.
                            The stuff you usually eat is refuse left by [i]things[/i] [b]bigger[/b] and [b]meaner[/b] than you are.
                            Sometimes, hunters from the city don't even bother taking home their catch.
                            All the better for you, of course.
                        [/p]
                        [p]
                            The person you're talking to still hasn't said a single word.
                            You're starting to think they either [b]can't hear[/b] you,
                            or maybe they're simply not interested in talking to an annoying little kobold they're forced to [b]babysit[/b].
                            You awkwardly say it's been nice talking to them, whoever they are, and then you stop speaking to the wooden wall in front of you.
                        [/p]
                        [p]
                            Truth be told, this actually [b]was[/b] a pleasant experience, regardless of whether they even [b]heard you[/b] or not.
                            You got to reflect on some things and you remembered some pleasant memories.
                            With those in mind, you roll onto your back, close your eyes, and try to get some sleep.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.nextSceneName, ctrl.nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.talk.change();
        part += buildChoice();
        if (!ctrl.nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (ctrl.nextSceneReady) {
            registerContinueListener();
        }
    };
}
