/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodNeither(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoGoodPotionChoice.NEITHER;
    var reqController = ctrl.potion;
    var subController = ctrl.preOutside;
    var changeController = ctrl.neither;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.outside;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var knockedOut = global.kobold.history.shared.enslavement.nightOne.knockedOut;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var toReturn = `[p]
                            You've steered clear of [i]body-altering[/i] drugs so far,
                            partly because you like yourself the way you are,
                            and partly because you've never really had the [i]money[/i] to buy one.
                            Now that an opportunity is presenting itself, however,
                            you can't say you're not a teensy bit [i]interested[/i].
                            You might like your body even [b]better[/b] with a few [i]enhancements[/i].
                            But that's a [b]dangerous[/b] road to go down.
                        [/p]
                        [p]
                            You've thought about this plenty.
                            Perhaps even considered it once or twice.
                            But now that the opportunity has presented itself,
                            you somehow don't feel very inclined to take it.
                            Besides, you're not even sure that's [i]actually[/i]
                            ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}
                            and 
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}
                            in those bottles.
                            Who knows what the wolf put in them?
                        [/p]
                        [p]
                            After a bit of mental deliberation, you decide not to take either potion.
                            You give Fenrir an unhappy look, and shake your head no.
                            "[color=gblue]Neither?
                            Picky little thing, aren't you?
                            Well, suit yourself.
                            Don't expect me to hang on to these until you change your mind, though.[/color]"
                        [/p]
                        [p]
                            While you didn't end up [i]accepting[/i] his gift,
                            you can't help but feel slightly [i]grateful[/i] for the canine to offer it in the first place.
                            You know those concoctions don't come cheap, and you assume he went out of his way to get them for you.
                            A nice gesture, although he could have [b]asked[/b] you first.
                            But you [b]do[/b] suppose you were ${knockedOut ? `unconscious` : `asleep`} until not too long ago.
                            ${eager ? `` : `Then again, this entire ordeal might have all been a [b]trick[/b] to get you to trust him more.
                            With bandits, you can never know for sure.`}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
