/**
 * Not barn section of the farm scene.
 * @param {BreedingFarmController} controller The breeding farm controller.
 */
function NotBarnTea(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var declineId = "notBarnTeaDeclineButton";
    var acceptId = "notBarnTeaAcceptButton";

    var toDecline = new NotBarnTeaDecline(ctrl);
    var toAccept = new NotBarnTeaDoor(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You slowly shake your head no, softly stammering out that you aren't really interested in Cassidy's [i]proposal[/i].
                            You didn't come here to have sex, let alone with someone you've never met before.
                            A confused look forms on the vixen's face.
                            As though she doesn't quite understand what you just said.
                            She visibly attempts to form a coherent reply, yet no words escape her lips.
                            You guess she's not used to being rejected.
                        [/p]
                        [p]
                            "[color=orange]Are you sure you understood me correctly?[/color]" the vulpine asks, after a moment of painfully awkward silence.
                            You reply with a single, swift nod, full of conviction.
                            "[color=orange]So you're saying you [b]don't[/b] want to have sex with me? Right now? With no strings attached?[/color]"
                            Another nod.
                            It feels like you're finally starting to get through to her.
                            "[color=orange]Are you [b]not[/b] [i]into[/i] women?[/color]"
                            You roll your eyes and face away from her, refusing to even acknowledge, let alone [i]answer[/i] her question.
                        [/p]
                        [p]
                            The vixen lets out a loud sigh.
                            She removes her hand from your shoulder, and straightens her back once more, her face no longer mere inches away from yours.
                            Instead of her sultry look, Cassidy puts on a more [i]dignified[/i] visage, and clears her throat, before speaking once more:
                            "[color=orange]I [i]do[/i] apologize.
                            Usually, when one of your kind wanders in here due to sheer curiosity, they [b]jump[/b] at the opportunity to [i]have some fun[/i].
                            But I now see that [i]some[/i] of you aren't [b]completely[/b] driven by desire.[/color]"
                        [/p]
                        [p]
                            Her odd explanation only serves to raise more questions than it provides answers.
                            She does this thing all the time?
                            Why?
                            Does she [i]love[/i] kobolds [i]that much[/i]?
                            For a moment, you begin to doubt yourself.
                            Perhaps you shouldn't have been so suspicious.
                            Maybe she really [i]did[/i] just want to have sex with you.
                            Alas, it seems that ship has sailed.
                            Judging by her posture, you've thoroughly [b]soured[/b] the canine's excited mood.
                        [/p]
                        [p]
                            "[color=orange]Well then, regardless of whether or not you're in the mood to [i]indulge[/i] my need, you [i]are[/i] still my guest.
                            So, little one, how about we leave this dusty old barn and head indoors?
                            I'll make you a nice cup of tea, and we can chat for a bit.
                            If I can't use my body to warm you up, the least I can do is offer you some shelter from the coldness of the world, if only for a while.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildDeclineChoice() {
        var disabled = ctrl.tea.has() ? "disabled" : "";
        var isSelected = ctrl.tea.get() === NotBarnTeaChoice.DECLINE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${declineId}" ${disabled}>Decline</button>`;
        var tooltip = global.parser.parse(`You'd rather not take the risk of entering a nymphomaniac's home,
                                           especially after shooting down her initial request.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildAcceptChoice() {
        var disabled = ctrl.tea.has() ? "disabled" : "";
        var isSelected = ctrl.tea.get() === NotBarnTeaChoice.ACCEPT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${acceptId}" ${disabled}>Accept</button>`;
        var tooltip = global.parser.parse(`Sure. You could go for a cup of tea. But [b]no[/b] funny business!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildDeclineChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildAcceptChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + declineId), $("#" + acceptId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerDeclineListener() {
        $("#" + declineId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tea.set(NotBarnTeaChoice.DECLINE);
            loadNextPart(toDecline);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerAcceptListener() {
        $("#" + acceptId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tea.set(NotBarnTeaChoice.ACCEPT);
            loadNextPart(toAccept);
        });
    }


    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "notBarnTea";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.barn.get() !== BreedingBarnChoice.DECLINE) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toDecline.build();
        part += toAccept.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.barn.get() !== BreedingBarnChoice.DECLINE) {
            return;
        }

        toDecline.registerListeners();
        toAccept.registerListeners();

        if (ctrl.tea.has()) {
            return;
        }

        registerDeclineListener();
        registerAcceptListener();
    };
}

var NotBarnTeaChoice = {
    DECLINE: 1,
    ACCEPT: 2
};
