/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellHelp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellFallChoice.HELP;
    var reqController = ctrl.down;
    var subController = ctrl.help;
    var changeController = ctrl.help;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new HamletWellScold(ctrl);
    var secondNext = new HamletWellBeg(ctrl);

    var firstChoice = HamletWellHelpChoice.SCOLD;
    var secondChoice = HamletWellHelpChoice.BEG;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var pants = ctrl.misc.pants();
        var drank = global.kobold.history.shared.well.drankWater;
        var drowned = global.kobold.history.shared.well.drowned;
        var rocky = global.kobold.history.shared.well.fell;
        var arrivalChoice = ctrl.arrival.get();
        var wanted = arrivalChoice === HamletWellArrivalChoice.CLIMB || arrivalChoice === HamletWellArrivalChoice.ROPE;
        var arrivalDescriptor = `You didn't want to be in here to begin with.`;
        if (wanted) {
            arrivalDescriptor = `You wanted to explore this place, but after the tiring climb downwards,
                                all you can do is dread the thought that you might not be able to escape.`;
            if (rocky) {
                arrivalDescriptor = `You wanted to explore this place, but you couldn't even climb [i]down[/i] the well properly.`;
            }
        }
        var toReturn = `[p]
                            You don't think you can get out of this damp hole on your own.
                            ${arrivalDescriptor}
                            Your only option left is to shout for help, and hope somebody hears you.
                        [/p]
                        [p]
                            You take a deep breath, and [b]scream[/b] for aid.
                            Your shriek echoes throughout the well, but otherwise goes unanswered.
                            Doubt growing in the back of your mind, you shout for assistance a second time.
                            Once the reverberation comes to an end, you are left with silence.
                            Completely disheartened, you gaze upwards at the small bit of sky you can see, and let out a small sigh.
                        [/p]
                        [p]
                            Suddenly, a trio of silhouettes appear at the top of the well.
                            Are you imagining things?
                            You rub your eyes, thinking you were hit by a rock and are now hallucinating.
                            The figures persist.
                            They seem to be talking to one another, although you can't quite make out what they're saying.
                            Right as you were about to call out for aid a third time,
                            one of the three shouts into the well, with a shrill and juvenile sounding voice:
                            "[color=green]That's not a swimming pool, stupid lizard![/color]"
                        [/p]
                        [p]
                            All three of them burst out into laughter, loud enough for you to hear all the way down the well.
                            Judging by what little you can see of them, the pitch of their voices and their general attitude,
                            you guess these aren't [i]grown men[/i] you're talking to, but rather a group of young boys.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Scold</button>`;

        var tooltip = global.parser.parse(`Berate the kids for being so rude.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Beg</button>`;

        var tooltip = global.parser.parse(`Beg for help. Your life might be at stake!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var HamletWellHelpChoice = {
    SCOLD: 1,
    BEG: 2
};
