/**
 * Entrance section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "entranceContinueButton";

    var toFree = new SekiWorkshopFree(ctrl);
    var toBuy = new SekiWorkshopBuy(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]Seki's Workshop[/st]
                        [p]
                            You enter the workshop of Seki, the owl.
                            This kind old man has helped you through some tough times in the past.
                            In some ways, you consider him the father you never had.
                            On the other hand, he's more of a [i]fence[/i] that you sell stuff you've stolen to.
                            In that regard, you suppose he's somewhat of a [i]bad[/i] influence.
                        [/p]
                        [p]
                            The workshop itself is [i]dark[/i], barely illuminated.
                            Being an owl, Seki prefers pitch-blackness above all,
                            keeping just a few candles around to prevent his customers from knocking over any of the potions he's brewed.
                            As a kobold, darkness doesn't phase you.
                            Your nightvision is superb, a fact which has significantly aided your criminal career thus far.
                            You deftly manoeuvre around the various tables and displays, towards the wooden counter,
                            where you ring a small bell to summon your elderly comrade from the depths of his shop.
                        [/p]
                        [p]
                            The old man is quite the accomplished alchemist.
                            There isn't a potion he [i]doesn't[/i] know how to brew.
                            Rumor has it that the owl used to be an advisor to the single most influential person in the entire world, the Dragon Emperor himself.
                            You've never quite asked him about it, and he hasn't told you, so you figure it's one of those things that are best left unmentioned.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the alternate content of this section.
     * @returns {string} The content.
     */
    function buildAltContent() {
        var name = ctrl.name();
        var toReturn = `[st]Seki's Workshop[/st]
                        [p]
                            As soon as the door to the barely illuminated workshop closes behind you,
                            a comforting feeling of intense [b]safety[/b] washes over you.
                            It touches you, to know that [b]someone[/b] actually [b]cares[/b] about you.
                            Your eyes water up.
                            You grab Seki's feathery leg, cuddle up against it and burst out into tears,
                            letting go all of the emotions you've been bottling up since the start of your capture.
                        [/p]
                        [p]
                            The big bird struggles to take a knee,
                            but once he manages to lower himself to your eye-level,
                            he wraps his winged arms around you, embracing you in a tender hug,
                            letting you rest your weeping head on his age-old shoulder while you bawl your eyes out.
                            "[color=brown]Shhhh...there, there.[/color]" he consolingly whispers to you, gently rubbing your bare back to calm you down.
                            "[color=brown]The bad men can't hurt you anymore.
                            You're safe here, with me.
                            Everything's going to be okay.[/color]"
                        [/p]
                        [p]
                            The avian lets you cry for as long as you need to.
                            For several minutes, you find yourself relaxing in Seki's clutches, your bountiful tears slowly coming to a halt.
                            Once again, the elderly owl proves that he's the closest thing to a father you'll ever have.
                        [/p]
                        [p]
                            As you begin to recover from the traumatic night and a half you've been through,
                            Seki reaches into the pouch hanging off his neck.
                            After fiddling around for a bit, he produces a recurring present, something he's given you [b]dozens[/b] of times before.
                            A single, shiny ${global.kobold.inventory.createItemWithTooltip(new Lockpick())}.
                            "[color=brown]Look here, what I have for you.
                            Remember this?[/color]"
                            Lifting your head from his shoulder, you give the bird a meek nod.
                            Breaking his caring embrace, he places the trinket into your hand, using his feathery talon to wrap your fingers around it tightly.
                            "[color=brown]It's all yours, my precious little ${name}.
                            Just like when you were young.[/color]"
                        [/p]
                        [p]
                            A small smile forms on your teary-eyed face.
                            Seki always knows exactly how to cheer you up.
                            With great difficulty, and a little help from you, he rises to his feet once more.
                            He grabs an empty coin pouch off one of his shelves, and hands it to you.
                            You gratefully wear it around your neck, as he wears his.
                        [/p]
                        [p]
                            "[color=brown]I'm sorry for yelling at you earlier.
                            Seeing you in the hands of [b]slaver scum[/b] ruffled my old feathers quite a bit.
                            But it's all over now.[/color]"
                            You ask about the money he used to [i]buy[/i] you.
                            Wasn't that a lot?
                            "[color=brown]Don't worry, little lizard.
                            I...won't be needing it anymore.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.entrance.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.entrance.continue();
            if (ctrl.gold() > ctrl.minBuyGold) {
                loadNextPart(toBuy);
            } else {
                loadNextPart(toFree);
            }
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiEntrance";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.arrival.continued()) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (global.kobold.history.shared.enslavement.noonTwo.boughtBySeki) {
            part += buildAltContent();
            part += ctrl.entrance.altChange();
        } else {
            part += buildContent();
        }
        part += buildChoice();
        part += `</div>`;
        part += toFree.build();
        part += toBuy.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.arrival.continued()) {
            return;
        }

        toFree.registerListeners();
        toBuy.registerListeners();

        if (ctrl.entrance.continued()) {
            return;
        }

        registerContinueListener();
    };
}
