/**
 * End section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEatMention(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenEatOfferChoice.MENTION;
    var reqController = ctrl.offer;
    var changeController = ctrl.mention;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.gaveHouseMentioned = true;
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You look away and mention that you [i]might[/i] have had a [i]disagreement[/i] with the previous owner.
                            And, well, as far as you know, the psycho bitch's dead body is still somewhere in the barn.
                            The sheep glares at you, shaking his head.
                            You say you really didn't mean to kill her, 
                            but she had you [b]trapped[/b] on this [b]table[/b] and she wanted to all kinds of [b]bad things[/b] to you and--
                            "[color=ppink]Hush, [i]kuhbold[/i].[/color]" interrupts the caprine.
                            "[color=ppink]The less ah know 'bout this, the better.[/color]"
                        [/p]
                        [p]
                            The man sighs loudly, putting the bag with his wedding ring in it around his neck once more.
                            "[color=ppink]Listen here.
                            I'll take the house, I'll get rid of the body, and I'll feed yer friend.[/color]"
                            You try to mention that they aren't actually your [i]friends[/i],
                            but the sheep loudly clears his throat to indicate that you've said enough already.
                        [/p]
                        [p]
                            "[color=ppink]I'm doin' this only because me waif would have wanted it.
                            Ah thank ye for the house, but ye must understand that ah cannae approve of what ye did to obtain it yerself.
                            The guards'd have mah head if they knew ah was talkin' to ah [b]murderin'[/b] [i]kuhbold[/i].
                            Not turning ye in makes me an [i]accessory[/i], but I'll risk it for the sake of me waif's dream of a world without 'unger.[/color]"
                        [/p]
                        [p]
                            The fat man rises from his chair.
                            "[color=ppink]Thank ye once again.
                            This doesn't make up for what you've done,
                            but it at least puts ye on the path of redemption.
                            Don't go 'round 'killin' anyone else now, ye hear?
                            There's hope left for us all.
                            Even [b]murderers[/b] like you.[/color]"
                        [/p]
                        [p]
                            The sheep signals for you to rise to your feet.
                            The two of you walk to the front door.
                            "[color=ppink]I'm going upstairs to pack me things.
                            You've done a good deed today.
                            Let's keep the corpse between you and me, okay?[/color]"
                            You give the man a small nod.
                            "[color=ppink]Good ${male ? `lad` : `lass`}.
                            Off you go now.
                            Come visit some time, will ye?[/color]"
                        [/p]
                        [p]
                            Before you even have a chance to respond, the caprine opens the door,
                            and practically [b]pushes[/b] you out of the building, into the coldness of the streets.
                            You turn around to say goodbye, but he rudely slams the door in your face.
                            Ungrateful bastard.
                            Then again, he might just have been a little [i]shocked[/i] to know the person he took in and fed was a [b]murderer[/b].
                        [/p]
                        [p]
                            Oh well.
                            At least it feels good knowing that someone will look after those [i]enslaved[/i] kobolds Cassidy was keeping.
                            You believe you did a good thing, helping out the owner of the soup kitchen.
                            Come to think of it, you didn't even catch his name.
                            Oh well, he seemed like a reliable enough guy.
                            And hey, he managed to feed [b]you[/b], right?
                        [/p]
                        [p]
                            Your conscience clear, your spirits lifted and your ego slightly boosted,
                            you set off for Varanar's grand evenue.
                            Last night, all the stores were closed,
                            but most of them should be open around now.
                            Time to see some sights!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("varanar_generic");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}
