

// SCENE Home

// scenes\Home\saved\ambush\HomeAmbush.js

/**
 * Ambush section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbush(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `ambushContinueButton`;
    var toBed = new HomeAmbushToBed(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            While the odds of you taking on the oversized kobold-crossbreed in a fair fight are slim to none,
                            you figure that if you manage to sneak up behind him, you can get a critical first hit in.
                            If you can bonk his unprotected head hard enough, you might just knock him out before he knows what hit'em.
                        [/p]
                        [p]
                            You lower your posture and begin to prowl about, using the dense underbrush as concealment.
                            Sneaking around your shack in a big half-circle, you end up behind it, and more importantly: behind the debt collector.
                            You silently approach the pig-like kobold from the rear, every soft footstep bringing you closer to him.
                        [/p]
                        [p]
                            You stop just a couple of feet short of the treestump the pigbold is sitting on, 
                            intending to perform a charging, leaping bash which is sure to knock him out cold.
                            You close your eyes, and steel your nerves.`;

        var weapon = ctrl.saved.weapon();
        if (weapon) {
            toReturn += `   You ready your ${global.kobold.inventory.createItemWithTooltip(weapon)}.`;
        } else {
            toReturn += `   You ball up your hands, preparing to strike.`;
        }

        toReturn += `       Suddenly, a deep and rumbling voice snaps you out of your concentration.
                            You open your eyes, and are greeted by the sight of a scaly muscular belly protruding from below a leather chestpiece, 
                            mere inches away from your face. 
                        [/p]
                        [p]
                            [c]
                                "[color=brown]
                                    [b]Thought I didn't see you there, kid?[/b]
                                [/color]"
                            [/c]
                        [/p]
                        [p]
                            Before you have a chance to respond, the surprisingly agile and swift pig-hybrid [b]rams[/b] his powerful fist into your forehead,
                            with an immense force strong enough to send you [b]flying[/b].
                            The back of your head hits a nearby tree, nearly cracking open your skull from the rear.
                            Your brain, which was only [b]barely[/b] able to withstand the first blow, fails to weather the second impact.
                            You pass out, your lifeless body slumping to the ground.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.ambush.knockContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.ambush.knockContinue();
            loadNextPart(toBed);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbush";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.AMBUSH) {
            return "";
        }
        var change = ctrl.saved.ambush.knockChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toBed.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.AMBUSH) {
            return;
        }
        toBed.registerListeners();

        if (ctrl.saved.ambush.knockContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\ambush\HomeAmbush.js

// scenes\Home\saved\ambush\HomeAmbushToBed.js

/**
 * To bed section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbushToBed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `ambushWakeContinueButton`;
    var toWake = new HomeAmbushWakeUp(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You begin to wake up a [b]long[/b] time later, your head absolutely [b]killing[/b] you.
                            Slowly regaining consciousness, you clutch your forehead, which feels like it was hit by a [b]catapult[/b].
                            The rear of your cranium, too, feels as though it's been through [b]hell[/b].
                            Carefully feeling around, 
                            your thoroughly rocked brain narrowly registers the small amount of cold, clotted
                            [b][color=red]blood[/color][/b] your fingers collect from around the gash at the back of your head.
                        [/p]
                        [p]
                            You wearily open your heavy eyelids, which are luckily greeted by night-time instead of the brightness of day.
                            You don't think you'd be able to process any vibrant colors right now.
                            Your brain struggles to cope with even the small amount of moonlight dropping in through the treetops.
                            At least you're still on the ground near your house.
                            Not being kidnapped is a good thing.
                        [/p]
                        [p]
                            Becoming aware of the blood on your fingers, you let out a pained groan.
                            You poke around your skull a bit more intently.
                            The aching wound seems to have closed on its own already, although you can't say for sure how much blood you lost.
                        [/p]
                        [p]
                            You examine the rest of your body.
                            Everything but your head seems to be intact.
                            Everything apart from your coin pouch, which you find on the ground next to you, completely emptied.
                        [/p]
                        [p]
                            You wince in pain as you slowly rise to your feet, steadying yourself against the tree you slammed into.
                            You feel like you're about to pass out again, but manage to collect yourself enough to stagger into your house.
                            Closing the wooden door behind you, you practically [b]drop[/b] onto the bale of hay that you call your [i]bed[/i], 
                            before losing consciousness once more.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.ambush.sleepContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.ambush.sleepContinue();
            loadNextPart(toWake);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbushBed";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.ambush.knockContinued()) {
            return "";
        }
        global.ui.applyTheme("home_night");
        var change = ctrl.saved.ambush.sleepChange(ctrl.gold());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toWake.build();
        part += `</div>`;

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.ambush.knockContinued()) {
            return;
        }

        toWake.registerListeners();

        if (ctrl.saved.ambush.sleepContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\ambush\HomeAmbushToBed.js

// scenes\Home\saved\ambush\HomeAmbushWakeUp.js

/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAmbushWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Once again, you rise after a long period of slumber.
                            Your head still feels as though it was trampled on by the mounts of an entire cavalry unit,
                            but your mind is just a little more [i]clear[/i] than before.
                            Your brain has had time to recover from the two heavy blows it was forced to endure,
                            to the point where you can tolerate keeping your eyes open despite 
                            the early rays of sunlight shining through the cracks in between the wooden planks making up the walls of your shack.
                        [/p]
                        [p]
                            Sitting up straight on your [i]bed[/i], you try to recall exactly what happened.
                            One moment, you were sneaking up to a debt collector.
                            The next, he'd punched you [b]so[/b] hard he knocked you [b]the fuck[/b] out.
                            You can't quite remember [i]how[/i] you made it to your bed in between then and now, but you're glad that you did.
                        [/p]
                        [p]
                            The injury at the back of your head seems to have healed up nicely while you were unconscious.
                            It's not bleeding, not anymore, that is, and the pain has dulled to the point where you can gently touch it [b]without[/b] wincing.
                            You clean the blood off the back of your skull using a bit of straw, before getting up off of your bale of hay.
                        [/p]
                        [p]
                            With concerns over your current health slowly fading, the bigger picture of things slowly creeps to mind.
                            You're pretty sure that guy was a debt collector.
                            If he wasn't, you're fucked.
                            But you don't want to imagine that scenario right now.
                            Right now, you want to believe that despite getting seriously hurt, you managed to buy yourself a couple of days worth of time, at the very least.
                        [/p]
                        [p]
                            You stretch your limbs, and test your shaky balance.
                            It takes a few moments, but you manage to steady your posture and clear your mind.
                            You're fine.
                            Just fine.
                            Your brain wasn't hurt [i]that[/i] badly.
                            Or so you tell yourself to inspire some much-needed conviction, some [b]drive[/b] to [b]keep going[/b].
                            At least you [i]hope[/i] you didn't suffer any [i]permanent[/i] damage from this encounter.
                        [/p]
                        [p]
                            You sigh loudly.
                            The debt collector may have taken over two hundred coins, but you [b]still[/b] owe the clan another fifty orso.
                            While you [b]could[/b] do with [b]a lot[/b] more rest, you really don't want mister half-pig to pay you another visit.
                            Next time, he might outright [b]kill[/b] you instead of just knocking you out.
                        [/p]
                        [p]
                            You exit your hovel.
                            The sun is rising, and the forest is slowly coming to life, a myriad of animal noises reverberating across the woodland.
                            Realizing that you'll never be lucky enough to rob a money transport and live to tell the tale [b]a second time[/b], 
                            you decide to seek your fortune outside of the woods.
                            You can either go to Varanar directly, or you can first take a small detour to the rural hamlet just outside of town.
                            Whichever route you choose, you hope you'll end up better off than you are now.
                        [/p]`;
        
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAmbushWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.ambush.sleepContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.ambush.wakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the Hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.ambush.sleepContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\saved\ambush\HomeAmbushWakeUp.js

// scenes\Home\saved\hide\HomeHide.js

/**
 * Hide section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHide(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toBed = new HomeHideToBed(ctrl);
    
    var continueId = `homeHideContinue`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You're [i]smart[/i].
                            If you approach the debt collector with a bag of gold strapped around your neck,
                            he'll most certainly take it from you, to [i]settle the score[/i].
                            But, if you [i]don't have[/i] any gold to give, then he can't [i]take[/i] any.
                            Screw smart.
                            You're a [b]genius[/b].
                        [/p]
                        [p]
                            You take off your pouch of gold, dig a small hole into the ground, and bury it right next to a tree,
                            the loose dirt concealed by a small bush.
                            With your purse hidden, you approach the kobold-pig hybrid with a smug smirk plastered across your face.
                        [/p]
                        [p]
                            "[color=brown][b]You're late.[/b][/color]" the brute speaks, in a deep and bass voice.
                            He rises from his treestump-seat as you approach, towering a good foot above you,
                            undoubtedly weighing multiple times your own mass.
                            "[color=brown][b]Rat wants his money. I'm here to collect.[/b][/color]" the fat lizard continues, scratching his bulging belly.
                        [/p]
                        [p]
                            You calmly and clearly explain that you don't really [i]have[/i] any coins for the half-pig to collect.
                            The big kobold snorts loudly, staring down at you with a hateful glare on his face.
                            He loudly cracks his knuckles, hands balling up into fists.
                            You suddenly realize that you haven't really thought this plan all the way through.
                            Perhaps you aren't as much of a genius as you hoped you were.
                        [/p]
                        [p]
                            Out of the corner of your eye, you spot the motion of a burly arm swinging upwards,
                            but the bandit's scaly fist plows into the underside of your muzzle before you manage to react.
                            The hefty, unexpected uppercut knocks you off of your feet.
                            You fall backwards, onto the leafy forest floor, a bit of blood spilling from your maw onto the ground.
                        [/p]
                        [p]
                            Even as your body comes to a rest, your brain still can't fully comprehend what exactly just happened.
                            Only when the kobold hybrid straddles your chest, pinning you down with the full weight of his relatively [b]enormous[/b] body,
                            does fear begin to emerge at the back of your mind.
                            For a moment, you consider telling him about your buried gold, yet before you can so much as open your mouth,
                            the savage mercilessly begins to [b]wail[/b] on you, brutally bashing your face, 
                            alternating between both of his hands to keep the steady stream of violence coming.
                        [/p]
                        [p]
                            Your mind spaces out, seemingly [i]leaving[/i] your body as your head gets violently [b]thrashed[/b].
                            You wake up from your preservation instinct-induced blackout as the burly ruffian rises from your body,
                            huffing and panting from the vicious beatdown.
                        [/p]
                        [p]
                            Your face is in agonizing pain.
                            Your eyes are [b]punched[/b] shut.
                            You spit out the chipped remains of what was once one of your teeth.
                            You can barely breathe through the blood oozing from your snout, a lot of which is piling up at the back of your throat.
                            You roll onto your side, just to let some of it seep from your mouth more easily.
                        [/p]
                        [p]
                            He's still not quite yet done.
                            With a loud, angry growl, the enforcer ruthlessly [b]kicks[/b] you in the gut, his foot [b]burying[/b] into your unprotected belly,
                            knocking the air out of your meagre frame.
                            You cough up a considerable amount of blood, as your constant flow of tears intensifies.
                            Breathing raggedly, panting for air and whimpering for mercy, you curl up into a ball as the half-kobold retracts his foot.
                        [/p]
                        [p]
                            The debt collector snorts yet again, before hocking down a disgusting wad of phlegm, directly onto of your face.
                            "[color=brown][b]You're lucky I don't get paid enough to kill.[/b][/color]" he says, flexing his fingers and wiping your blood from his knuckles.
                            "[color=brown][b]Others do. Watch your back.[/b][/color]" 
                            With those words uttered, the sadistic pig walks away, leaving you a bloodied and broken mess, idly sobbing on the leafy forest floor.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.hide.ballContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.hide.ballContinue();
            loadNextPart(toBed);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHide";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.HIDE) {
            return "";
        }
        var change = ctrl.saved.hide.ballChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toBed.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.HIDE) {
            return;
        }
        
        toBed.registerListeners();

        if (ctrl.saved.hide.ballContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\hide\HomeHide.js

// scenes\Home\saved\hide\HomeHideToBed.js

/**
 * To bed section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHideToBed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var toWake = new HomeHideWakeUp(ctrl);

    var continueId = `homeHideBedContinue`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You lie there for a few more hours.
                            You are conscious, yet your body is crippled with pain.
                            You slowly rock back and forth in your fetal position, more than a little traumatized.
                            You've never quite been brutalized like that before.
                            The entire ordeal has left you mentally [b]demolished[/b].
                        [/p]
                        [p]
                            Your face hurts.
                            Your stomach hurts.
                            Your [b]everything[/b] hurts.
                            You bring your hands to your visage.
                            The swelling seems to have gone down a bit, enough for you to open your eyes.
                            The sun has set, and night-time is upon you.
                        [/p]
                        [p]
                            You slowly unfurl from your self-protecting posture.
                            You are shivering, not just from your poor mental condition, but from being cold.
                            You rise to your unsteady feet, wiping some of the blood off of your muzzle.
                        [/p]
                        [p]
                            At least...at least there's one thing that can offer you [i]some[/i] solace.
                            You limp away from your shed, stopping at a familiar tree and dropping to your knees.
                            You dig rampantly, with both your hands, uncovering your well-hidden stash of gold.
                            You press the dirt-covered coinpouch against your chest, cradling it.
                            Your near-[b]broken[/b] mind [b]needs[/b] something to cling to.
                            Your plan [b]worked[/b], or so you claim, to keep yourself from falling apart.
                        [/p]
                        [p]
                            A small smile forms upon your disfigured face, 
                            but it quickly fades to tears once more as you fail to hold up the pretense for more than a few moments.
                            The horrible pain you're in is [b]not[/b] worth [b]any[/b] amount of gold,
                            but you wish you didn't have to realize that cold, hard fact.
                        [/p]
                        [p]
                            You stagger back towards your home.
                            You push open your shed's wooden door.
                            After closing it behind you, you fall down on top of the bale of hay that you call your [i]bed[/i].
                            Still clutching your filthy purse, you slowly cry your battered form to sleep, hoping you'll wake up in the morning.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.hide.sleepContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.hide.sleepContinue();
            loadNextPart(toWake);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHideBed";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.hide.ballContinued()) {
            return "";
        }
        global.ui.applyTheme("home_night");
        var change = ctrl.saved.hide.sleepChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toWake.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.hide.ballContinued()) {
            return;
        }
        
        toWake.registerListeners();

        if (ctrl.saved.hide.sleepContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\hide\HomeHideToBed.js

// scenes\Home\saved\hide\HomeHideWakeUp.js

/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHideWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You wake up many hours later, after a pained and troubled slumber,
                            drifting in and out of the realm of consciousness,
                            on the brink of being too awake to sleep and too asleep to think.
                        [/p]
                        [p]
                            At the cusp of dawn, you are roused from your restless drowse by a ray of blinding light shining in through a crack in the wooden wall of your shed.
                            You groaningly open your still slightly swollen eyelids.
                            Your entire body hurts, yet not nearly as much as it did yesterday.
                            While your face took most of the intense beating, it has seemingly gone [i]numb[/i],
                            the pain radiating from your visage dull and distant, intensifying only when you touch your wounded scales.
                        [/p]
                        [p]
                            Your mouth has stopped bleeding.
                            With your tongue, which is one of the few parts of your body that isn't aching, you feel around your gums.
                            One of your teeth outright [b]broke[/b], and fragments of it tore open the rest of your mouth, save for your tongue.
                            While you've managed to spit out most of the debris, the entirety of the inside of your mouth is lined with small cuts,
                            which you assume you'll be feeling for a long time still, despite them having stopped bleeding already.
                        [/p]
                        [p]
                            Your jaw, which you believed to be broken last night, seems to be in slightly better condition than you thought it was.
                            While it definitely hurts to open and close, it doesn't feel like anything is severely [b]fractured[/b] or [i]in the wrong place[/i].
                            Your snout, similarly, isn't in quite the poor shape you figured it was.
                            Your muzzle isn't deformed in any way, and apart from the tooth your lost, you don't think any [i]major[/i] damage was done.
                        [/p]
                        [p]
                            Maybe you were panicking just a little [i]too[/i] much yesterday.
                            While the kobold hybrid undeniably [i]fucked you up[/i], he was kind enough not to [b]permanently[/b] disfigure you.
                            He probably figured you'd be dead in a few days anyway.
                        [/p]
                        [p]
                            You shift to a seated position on your [i]bed[/i].
                            Your stomach still hurts quite a lot.
                            You hope you have no lasting [i]internal[/i] injuries, but you have no real way to check.
                            As you rise to your unsteady feet, a sudden wave of inexplicable euphoria washes over you.
                            As though your brain realizes [b]most[/b] of the pain is over, [b]for now[/b].
                        [/p]
                        [p]
                            Your thoughts wander towards the future.
                            While you may have kept your considerable [i]hoard[/i] of gold for now,
                            you doubt the Three-Tailed Rat will simply [b]stop[/b] coming after you when his extorter comes home empty-handed.
                            At best, you figure you'll be kidnapped, and get a chance to pay off your debts still.
                            At worst, you'll be poisoned, stabbed in the back or otherwise assassinated [b]before[/b] 
                            you can even explain that you actually [b]do[/b] have the rat's money.
                        [/p]
                        [p]
                            You wipe any lingering blood off of your still-sensitive face, before leaving the comfortable, familiar snugness of your small, wooden shack.
                            You take a deep breath of fresh morning air, or at least as deep as you can before your battered body begins to ache.
                        [/p]
                        [p]
                            The cool air clears your mind.
                            You take a moment to think, realizing that you've been surviving on [i]pure luck[/i] for a long time now.
                            You decide to seek a more assured fortune outside of the woods.
                            You can either go to Varanar directly, or you can first make a small stop at the rural hamlet just outside of town.
                            Whichever route you choose, you hope you'll end up better off than you are now.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHideWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.hide.sleepContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.hide.wakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.hide.sleepContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\saved\hide\HomeHideWakeUp.js

// scenes\Home\saved\approach\give\HomeGive.js

/**
 * Give section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeGive(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `giveContinueButton`;
    var toNext = new HomeGiveWakeUp(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You tilt your head upwards, staring at the pigbold's face with a nervous smile on your face.
                            You are more than a little fearful of the broad and muscle-gutted thug.
                            He looks like he could outright [b]tear you in half[/b] should you refuse his request.
                            If anything, you should be thankful that he's asking you [i]somewhat[/i] nicely instead of just [b]taking[/b] your gold.
                        [/p]
                        [p]
                            You take hold of the small rope tying your purse around your neck, and you deftly lift it over your head.
                            After taking one last glance at the hefty bundle of money, you slowly hand it over to the half-kobold in front of you,
                            his arm not so much as [i]flinching[/i] as you place the heavy pouch in his open palm, staying perfectly still despite the added weight.
                        [/p]
                        [p]
                            The bandit inspects the pouch, opening it up to confirm its contents.
                            Being greeted by the sight of over two hundred coins staring back at him, he figures you [b]aren't[/b] trying to deceive him.
                            The ruffian moves your pouch to the side of his leather pants, tilting the small bag to let the coins within [i]pour[/i] into his pocket.
                        [/p]
                        [p]
                            As the clattering of coins comes to an end, the pigbold's attention turns towards you once more.
                            He tosses you your emptied purse, before speaking, his voice slightly less ominous than before, yet still rather threatening.
                            "[color=brown][b]Good. 
                            If this ain't enough, the Rat'll be expecting you to cough up the rest in a few days, in which case we'll be meetin' again.
                            If it's too much, consider the excess a fine for bein' late.[/b][/color]"
                        [/p]
                        [p]
                            After a small, mutual nod to [b]ensure[/b] that his threatening words had reached the depths of your fear-addled mind,
                            the burly hybrid turns away from you, and begins his journey back towards the capital, without looking back even once.
                        [/p]
                        [p]
                            You let out a deep sigh.
                            That was [b]stressful[/b], but you're glad you got it over with.
                            You feel like you did the right thing here.
                            You [i]manned up[/i], acted like an adult, and everything worked out fine in the end.
                        [/p]
                        [p]
                            As the slight euphoric rush you find yourself in quickly fades, you yawn loudly.
                            So far, you hadn't realized how [i]tired[/i] this strenuous, emotion and exertion-filled day had made you,
                            adrenaline and necessity driving you onwards up until now.
                            The hard part is finally over.
                            You can relax, if just for one night.
                        [/p]
                        [p]
                            You enter your small, homely shack, and plop yourself down on top of the comfortable, warm bale of hay that you call your [i]bed[/i].
                            You cover yourself in a few handfuls of straw which serve as a blanket of sorts.
                            After snugly nestling yourself just a little deeper into your resting spot, you slowly doze off into a well-deserved nap.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.debt.firstSegmentContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.firstSegmentContinue();
            loadNextPart(toNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeGive";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.ACCEPT) {
            return "";
        }
        var change = ctrl.saved.debt.acceptChange(ctrl.gold());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toNext.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.ACCEPT) {
            return;
        }

        toNext.registerListeners();

        if (ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\approach\give\HomeGive.js

// scenes\Home\saved\approach\give\HomeGiveWakeUp.js

/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeGiveWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You wake up nearly half a day of deep, dreamless sleep later, still tucked in to your hay-bed, relishing in the warmth it provides.
                            As you slowly open your eyes, 
                            you are greeted with the first few rays of morning sunlight shining brightly through the cracks in the walls of your shack.
                            You stay in bed for just a few more minutes.
                        [/p]
                        [p]
                            Finally, you lazily rise from your comfortable position, wiping a few straws of hay off of the top of your head.
                            You yawn loudly, this time not from exhaustion, but out of the satisfaction of a solid night's sleep. 
                            You contently stretch your limbs.
                            You have a feeling today is going to be a good day.
                        [/p]
                        [p]
                            You step out of your small hovel, and are greeted with a gust of fresh, cool morning air, which you breathe in deeply.
                            It reinvigorates you, expells some of the sleepiness from your brain.
                            You rub your eyes as your mind wakes up at its own pace, lagging behind your body as usual.
                        [/p]
                        [p]
                            You've paid off most of your debts.
                            Great.
                            Now you only need to find a way to scrounge up about fifty more coins in a couple of days, and you'll be golden.
                            You doubt you'll be able to gather that money in the forest, though.
                        [/p]
                        [p]
                            You figure it's time to set out,
                            to venture into the city and test your luck there.
                            Maybe you should drop by the small hamlet outside of town first,
                            just to get a better feel for what humans and other species twice your size are like.
                            Whichever route you choose, you hope you'll end up feeling just as [b]good[/b] and [b]fulfilled[/b] as you do now.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeGiveWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.debt.acceptWakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\saved\approach\give\HomeGiveWakeUp.js

// scenes\Home\saved\approach\refuse\HomeRefuse.js

/**
 * Refuse section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `refuseContinueButton`;

    var toNext = new HomeRefuseWakeUp(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            So this guy thinks he can [b]bully[/b] you out of [b]your[/b] hard-earned gold just because he's bigger, stronger and [b]heavier[/b] than you are?!
                            No way.
                            You glare up at him with a defiant look on your face as you shake your head no.
                            You aren't going to give him what he wants.
                        [/p]
                        [p]
                            "[color=brown][b]Suit yourself.[/b][/color]"
                            the burly half-kobold replies, looming over you as though he was going to let himself fall forwards and [b]squash[/b] you underneath his weight.
                            Then, out of nowhere, in the flash of an eye, the brute's fist strikes the lower half of your muzzle,
                            with a force strong enough to outright [b]knock[/b] you off your feet.
                        [/p]
                        [p]
                            You scream out in pain as you fall backwards onto the leafy forest floor.
                            The moment you hit the ground, you immediately try to scramble to your feet, or at least to scurry backwards,
                            your fight or flight and self-preservation instincts kicking in.
                            Before you manage to move even an inch, the heavy-set hybrid's foot comes crashing down upon your chest, pinning you against the ground.
                        [/p]
                        [p]
                            Panicking, you struggle and you squirm, yet you fail to escape from the pigbold's clutches.
                            As though he's done this a thousand times before, he ignores your wriggling, 
                            calmly leans down, reaches for the purse now lying atop your chest and harshly [b]tugs[/b] it away from your neck,
                            the flimsy cord keeping it in place snapping with ease.
                        [/p]
                        [p]
                            Having gotten what he was after, the enforcer removes his foot from your chest, and takes a few steps backwards.
                            You instantly hop to your feet, and drop into a combat stance, yet the thug seems uninterested in fighting.
                            Instead, he casually transfers the contents of your gold-pouch into his own pocket.
                        [/p]
                        [p]
                            You slowly slip out of your fighting posture.
                            Your jaw begins to ache as adrenaline fades from your system, 
                            a painful reminder of the sheer [b]strength[/b] of the man before you.
                            The rational part of your brain reasons that even [b]if[/b] he considered you a worthy foe,
                            you'd just end up getting the [b]shit[/b] beaten out of you regardless.
                        [/p]
                        [p]
                            The harsh fact that the half-kobold has [b]won[/b] this [i]not-quite-fight[/i] only truly sinks in 
                            as he tosses the now-empty pouch that used to contain your money in your face.
                            "[color=brown][b]Next time you act uppity, I'll beat you to a pulp.[/b][/color]" the brute warns.
                            You don't doubt his words for even a second.
                            "[color=brown][b]And if this ain't enough to cover your debt, we'll be seeing eachother again real soon.[/b][/color]"
                        [/p]
                        [p]
                            With your coin pocketed and his final threat uttered, the debt collector turns around, and casually strolls away from your humble abode.
                            Disheartened and hurting, you decide not to give chase.
                            Your clutch your jaw, opening and closing your mouth a few times to make sure nothing's [i]broken[/i].
                            It hurts, but you think you'll be fine.
                            Although he only hit you once, he hit you [b]good[/b].
                            And even then, you had the feeling he was still [b]holding back[/b].
                        [/p]
                        [p]
                            You sigh loudly, tying the neck-cord of your once-filled coin pouch back together.
                            You [b]really[/b] wanted to keep at least [b]some[/b] of your money.
                            At least you showed him, and yourself, that you have [b]guts[/b].
                            If you had ${ctrl.gender() === GenderEnum.MALE ? "external" : ""} balls, they'd be as big as a feral horse's.
                            You give yourself a figurative pat on the back for not backing down at first.
                        [/p]
                        [p]
                            After further lamenting your monetary loss, you decide to call it an early night.
                            You step into your small, homely shack, and plop yourself down on top of the bale of hay that you call your [i]bed[/i].
                            After such a long and tiring day, you easily drift to sleep in a matter of mere minutes.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.debt.firstSegmentContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.firstSegmentContinue();
            loadNextPart(toNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeRefuse";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.REFUSE) {
            return "";
        }
        var change = ctrl.saved.debt.refuseChange(ctrl.gold());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toNext.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.REFUSE) {
            return;
        }

        toNext.registerListeners();

        if (ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Home\saved\approach\refuse\HomeRefuse.js

// scenes\Home\saved\approach\refuse\HomeRefuseWakeUp.js

/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeRefuseWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your sleep is troubled by [i]nightmares[/i], 
                            your mind subconsciously re-living the awful, scary moments of the passed day over and over again.
                            You toss and turn in your [i]bed[/i], until finally, at the break of dawn, you awake from your slumber,
                            finding yourself resting on the cold, dirt floor instead of in the warm embrace of hay.
                        [/p]
                        [p]
                            You let out an annoyed moan as you rise to your feet.
                            While you slept like shit, at least your jaw is feeling a bit better.
                            On the other hand, your body is feeling a bit [i]stiff[/i] from sleeping on the ground.
                            But you don't let that stop you from going out the door.
                            As you leave your home, you are immediately greeted by a gust of fresh morning air,
                            which does wonders to wipe away your budding morning-grumpiness.
                        [/p]
                        [p]
                            With your mind cleared, you think about the future for a moment.
                            You still owe the Three-Tailed Rat about fifty gold, a sum which you're certain he won't just forget about.
                            You take in a deep breath, and decide that the best course of action for you to take would be to head for Varanar,
                            although you could take a small detour and visit the tiny hamlet right outside the city limits first.
                            Whichever route you choose, you hope you'll end [i]this[/i] day with a better nap than the one you just woke up from.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeRefuseWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.debt.refuseWakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\saved\approach\refuse\HomeRefuseWakeUp.js

// scenes\Home\saved\approach\HomeApproach.js

/**
 * Approachj section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeApproach(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var refuseId = "savedRefuseButton";
    var giveId = "savedGiveButton";
    
    var toRefuse = new HomeRefuse(ctrl);
    var toGive = new HomeGive(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide [b]not[/b] to fuck around and to simply approach the man and have a reasonable, civil conversation with him.
                            He takes note of you as you draw near, rising from his treestump-seat, towering a good foot above you, 
                            undoubtedly weighing multiple times your own mass.
                        [/p]
                        [p]
                            "[color=brown][b]You're late.[/b][/color]" the brute speaks, before crudely scratching his bulging belly.
                            He eyes your meagre frame up and down.
                            Noticing the coin-filled pouch hanging off your neck, the fat lizard rudely points one of his chubby fingers at it.
                            "[color=brown][b]That's what I'm here for.[/b][/color]"  he continues, turning his pointing hand into a receiving cup.
                            "[color=brown][b]Rat wants his money. Hand it over.[/b][/color]" 
                            The enforcer's other hand balls up into a menacingly raised fist.
                            "[color=brown][b]Or else.[/b][/color]" 
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the refuse choice button.
     */
    function buildRefuseChoice() {
        var disabled = ctrl.saved.debt.has() ? "disabled" : "";
        var isSelected = ctrl.saved.debt.get() === HomeApproachChoice.REFUSE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${giveId}" ${disabled}>Hand it over</button>`;

        var tooltip = `Give him your purse.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the give choice button.
     */
    function buildGiveChoice() {
        var disabled = ctrl.saved.debt.has() ? "disabled" : "";
        var isSelected = ctrl.saved.debt.get() === HomeApproachChoice.ACCEPT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${refuseId}" ${disabled}>Refuse</button>`;

        var tooltip = `Shake your head no.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildRefuseChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildGiveChoice();
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + refuseId), $("#" + giveId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerRefuseListener() {
        $("#" + refuseId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.set(HomeApproachChoice.REFUSE);
            loadNextPart(toRefuse);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerGiveListener() {
        $("#" + giveId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.set(HomeApproachChoice.ACCEPT);
            loadNextPart(toGive);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeApproach";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.TALK) {
            return "";
        }
        global.ui.applyTheme("home");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toRefuse.build();
        part += toGive.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.getApproachChoice() !== HomeSavedChoice.TALK) {
            return;
        }

        toRefuse.registerListeners();
        toGive.registerListeners();

        if (ctrl.saved.debt.has()) {
            return;
        }

        registerRefuseListener();
        registerGiveListener();
    };
}

var HomeApproachChoice = {
    REFUSE: 1,
    ACCEPT: 2
};

// END scenes\Home\saved\approach\HomeApproach.js

// scenes\Home\saved\HomeSaved.js

/**
 * Saved section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeSaved(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var hideId = "savedHideButton";
    var talkId = "savedTalkButton";
    var ambushId = "savedAmbushButton";

    var toHide = new HomeHide(ctrl);
    var toTalk = new HomeApproach(ctrl);
    var toAmbush = new HomeAmbush(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]Early arrival[/st]`;
        toReturn += `   [p]
                            After a short, relaxing trek through the forest,
                            you begin to near your small hovel,
                            located near the northern edge of the woods.
                            You've been living there for just about as long as you can remember.
                            You think it used to serve as a storage room for a larger building,
                            seeing as the somewhat concealed dirt track leading towards your home abruptly ends a good bit away from the actual shack.
                        [/p]
                        [p]
                            As your shed comes into view, you spot a shady figure sitting alongside it on the tree stump that has been serving as your outside-stool.
                            The person in question is a kobold like you, but even from a distance you can see that he's [b]far[/b] larger than you are,
                            in both size and in [b]girth[/b].
                            A crossbreed between your race and something [i]bigger[/i], or so you figure.
                            Probably a pig, judging by his [i]size[/i].
                        [/p]
                        [p]
                            The half-kobold is wearing a ${global.kobold.inventory.createItemWithTooltip(new StuddedLeatherChestPiece())}
                            with matching, equally combat-ready ${global.kobold.inventory.createItemWithTooltip(new LeatherPants())}.
                            His attire makes you think that he was sent to collect your [i]debt[/i], by any means necessary.
                            He isn't visibly armed, but you doubt someone of his [b]bulk[/b] needs anything other than his oversized fists to beat the shit out of you.
                        [/p]
                        [p]
                            The pigbold seemingly hasn't noticed you yet.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the sneak choice button.
     */
    function buildHideChoice() {
        var disabled = ctrl.saved.hasMadeApproachChoice() ? "disabled" : "";
        var isSelected = ctrl.saved.getApproachChoice() === HomeSavedChoice.HIDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${hideId}" ${disabled}>Hide your gold</button>`;

        var tooltip = `Stash your gold in a nearby bush before approaching.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the talk choice button.
     */
    function buildTalkChoice() {
        var disabled = ctrl.saved.hasMadeApproachChoice() ? "disabled" : "";
        var isSelected = ctrl.saved.getApproachChoice() === HomeSavedChoice.TALK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${talkId}" ${disabled}>Talk to him</button>`;

        var tooltip = `Approach the debt collector and talk to him.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the ambush choice button.
     */
    function buildAmbushChoice() {
        var disabled = ctrl.saved.hasMadeApproachChoice() ? "disabled" : "";
        var isSelected = ctrl.saved.getApproachChoice() === HomeSavedChoice.AMBUSH;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${ambushId}" ${disabled}>Ambush him</button>`;

        var tooltip = `Sneak up from behind and try to ambush the kobold.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 185px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildHideChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildTalkChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildAmbushChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + hideId), $("#" + talkId), $("#" + ambushId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerHideListener() {
        $("#" + hideId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.makeApproachChoice(HomeSavedChoice.HIDE);
            loadNextPart(toHide);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerTalkListener() {
        $("#" + talkId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.makeApproachChoice(HomeSavedChoice.TALK);
            loadNextPart(toTalk);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerAmbushListener() {
        $("#" + ambushId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.makeApproachChoice(HomeSavedChoice.AMBUSH);
            loadNextPart(toAmbush);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeSaved";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.status() !== HomeStatusEnum.SAVED) {
            return "";
        }
        if (!ctrl.saved.hasMadeApproachChoice()) {
            ctrl.introAudio.playSettingsDependent();
        }
        global.ui.applyTheme("home");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toHide.build();
        part += toTalk.build();
        part += toAmbush.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.status() !== HomeStatusEnum.SAVED) {
            return;
        }

        toHide.registerListeners();
        toTalk.registerListeners();
        toAmbush.registerListeners();

        if (ctrl.saved.hasMadeApproachChoice()) {
            return;
        }

        registerHideListener();
        registerTalkListener();
        registerAmbushListener();
    };
}

var HomeSavedChoice = {
    HIDE: 1,
    TALK: 2,
    AMBUSH: 3
};

// END scenes\Home\saved\HomeSaved.js

// scenes\Home\saved\HomeSavedController.js

/**
 * Controller for the saved part of the home scene.
 * @param {string} sceneId The id of the scene.
 */
function HomeSavedController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var approachId = "savedApproach";
    var debtId = "savedDebt";
    var weaponId = "savedWeapon";
    var ambushId = "savedAmbush";
    var hideId = "savedHide";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Makes the approach choice.
     * @param {HomeSavedChoice} choice The choice.
     */
    this.makeApproachChoice = function (choice) {
        if (choice === HomeSavedChoice.AMBUSH) {
            global.kobold.history.shared.debtCollector.status = DebtCollectorEnum.AMBUSHED;
        }
        if (choice === HomeSavedChoice.HIDE) {
            global.kobold.history.shared.debtCollector.status = DebtCollectorEnum.UNPAID;
        }
        global.kobold.history.setKey(id, approachId, choice);
    };

    /**
     * Fetches the approach choice from history and returns it.
     * May return undefined if the approach choice has not yet been set.
     */
    this.getApproachChoice = function () {
        return global.kobold.history.getKey(id, approachId);
    };

    /**
     * Returns true if the approach choice has been made.
     */
    this.hasMadeApproachChoice = function () {
        return global.kobold.history.has(id, approachId);
    };


    function DebtController(key) {
        var segment = key + "first";
        var acceptChangeId = key + "acceptChange";
        var refuseChangeId = key + "refuseChange";
        var acceptWakeChangeId = key + "acceptWakeChange";
        var refuseWakeChangeId = key + "refuseWakeChange";
        this.get = function () {
            return global.kobold.history.getKey(id, key);
        };
        this.set = function (choice) {
            if (choice === HomeApproachChoice.ACCEPT) {
                global.kobold.history.shared.debtCollector.status = DebtCollectorEnum.PAID;
            }
            if (choice === HomeApproachChoice.REFUSE) {
                global.kobold.history.shared.debtCollector.status = DebtCollectorEnum.REFUSED;
            }
            global.kobold.history.setKey(id, key, choice);
        };
        this.has = function () {
            return global.kobold.history.has(id, key);
        };
        this.firstSegmentContinue = function () {
            global.kobold.history.setKey(id, segment, true);
        };
        this.firstSegmentContinued = function () {
            return global.kobold.history.has(id, segment);
        };
        this.acceptChange = function (coins) {
            global.kobold.history.doIfNotSet(id, acceptChangeId, true, function () {
                global.kobold.history.shared.debtCollector.paid += coins;
                global.kobold.inventory.coins = 0;
                global.kobold.status.mental.increase(20, "Immense relief");
                global.kobold.stats.increaseStat(StatsEnum.INTELLIGENCE, 1);
            });
            return global.ui.change.buildNotification([
                new Change("Debt paid", "Coins", -coins),
                new Change("Immense relief", "Sanity", +20),
                new Change("Mature conduct", "Intelligence", +1)
            ]);
        };
        this.refuseChange = function (coins) {
            global.kobold.history.doIfNotSet(id, refuseChangeId, true, function () {
                global.kobold.history.shared.debtCollector.paid += coins;
                global.kobold.inventory.coins = 0;
                global.kobold.status.physical.decrease(20, "Punched");
                global.kobold.status.mental.decrease(5, "Bravery");
            });
            return global.ui.change.buildNotification([
                new Change("Money taken", "Coins", -coins),
                new Change("Punched", "Health", -20),
                new Change("Money taken", "Sanity", -10),
                new Change("Bravery", "Sanity", +5)
            ]);
        };
        this.acceptWakeChange = function () {
            global.kobold.history.doIfNotSet(id, acceptWakeChangeId, true, function () {
                global.kobold.status.physical.increase(40, "Well-earned nap");
                global.kobold.status.stamina.increase(40, "Well-earned nap");
            });
            return global.ui.change.buildNotification([
                new Change("Well-earned nap", "Health", +40),
                new Change("Well-earned nap", "Stamina", +40)
            ]);
        };
        this.refuseWakeChange = function () {
            global.kobold.history.doIfNotSet(id, refuseWakeChangeId, true, function () {
                global.kobold.status.physical.increase(10, "Jaw-pain subsided");
                global.kobold.status.mental.decrease(10, "Troubled sleep");
                global.kobold.status.stamina.increase(20, "Mediocre rest");
            });
            return global.ui.change.buildNotification([
                new Change("Pain subsided", "Health", +10),
                new Change("Troubled sleep", "Sanity", -10),
                new Change("Mediocre rest", "Stamina", +20)
            ]);
        };
    }

    this.debt = new DebtController(debtId);

    function AmbushController(key) {
        var knockChangeId = key + "KnockChange";
        var knockId = key + "Knocked";
        var sleepChangeId = key + "SleepChange";
        var sleepId = key + "Sleep";
        var wakeChangeId = key + "WakeChange";
        this.knockChange = function () {
            global.kobold.history.doIfNotSet(id, knockChangeId, true, function () {
                global.kobold.status.physical.decrease(40, "Knocked out");
            });
            return global.ui.change.buildNotification([
                new Change("Knocked out", "Health", -40)
            ]);
        };
        this.knockContinue = function () {
            global.kobold.history.setKey(id, knockId, true);
        };
        this.knockContinued = function () {
            return global.kobold.history.has(id, knockId);
        };
        this.sleepChange = function (coins) {
            global.kobold.history.doIfNotSet(id, sleepChangeId, true, function () {
                global.kobold.history.shared.debtCollector.paid += coins;
                global.kobold.inventory.coins = 0;
                global.kobold.status.mental.decrease(20, "Brain damage");
            });
            return global.ui.change.buildNotification([
                new Change("Debt collected", "Coins", -coins),
                new Change("Brain damage", "Sanity", -20)
            ]);
        };
        this.sleepContinue = function () {
            global.kobold.history.setKey(id, sleepId, true);
        };
        this.sleepContinued = function () {
            return global.kobold.history.has(id, sleepId);
        };
        this.wakeChange = function () {
            global.kobold.history.doIfNotSet(id, wakeChangeId, true, function () {
                global.kobold.status.physical.increase(10, "Wounds healing");
                global.kobold.status.stamina.increase(20, "Pained slumber");
                global.kobold.stats.decreaseStat(StatsEnum.AGILITY, 1);
                global.kobold.stats.decreaseStat(StatsEnum.INTELLIGENCE, 1);
            });
            return global.ui.change.buildNotification([
                new Change("Wounds healing", "Health", +10),
                new Change("Pained slumber", "Stamina", +20),
                new Change("Permanent damage", "Agility", -1),
                new Change("Permanent damage", "Intelligence", -1)
            ]);
        };
    }

    this.ambush = new AmbushController(ambushId);

    function HideController(key) {
        var ballId = key + "Ball";
        var ballChangeId = key + "BallChange";
        var sleepChangeId = key + "SleepChange";
        var sleepId = key + "Sleep";
        var wakeChangeId = key + "WakeChange";
        this.ballChange = function () {
            global.kobold.history.doIfNotSet(id, ballChangeId, true, function () {
                global.kobold.status.physical.decrease(70, "Brutal beatdown");
            });
            return global.ui.change.buildNotification([
                new Change("Brutal beatdown", "Health", -70)
            ]);
        };
        this.ballContinue = function () {
            global.kobold.history.setKey(id, ballId, true);
        };
        this.ballContinued = function () {
            return global.kobold.history.has(id, ballId);
        };
        this.sleepChange = function () {
            global.kobold.history.doIfNotSet(id, sleepChangeId, true, function () {
                global.kobold.status.mental.decrease(10, "Brutal beatdown");
            });
            return global.ui.change.buildNotification([
                new Change("Kept coins", "Sanity", +10),
                new Change("But at what cost?", "Sanity", -20)
            ]);
        };
        this.sleepContinue = function () {
            global.kobold.history.setKey(id, sleepId, true);
        };
        this.sleepContinued = function () {
            return global.kobold.history.has(id, sleepId);
        };
        this.wakeChange = function () {
            global.kobold.history.doIfNotSet(id, wakeChangeId, true, function () {
                global.kobold.status.physical.increase(20, "Wounds healing nicely");
                global.kobold.status.mental.increase(10, "Cautious optimism");
                global.kobold.status.stamina.increase(20, "Pained slumber");
                global.kobold.stats.increaseStat(StatsEnum.ENDURANCE, 1);
            });
            return global.ui.change.buildNotification([
                new Change("Wounds healing", "Health", +20),
                new Change("Cautious optimism", "Sanity", +10),
                new Change("Pained slumber", "Stamina", +20),
                new Change("What doesn't kill you", "Endurance", +1)
            ]);
        };
    }

    this.hide = new HideController(hideId);

    /**
     * Stored and returns the kobold's weapon.
     */
    this.weapon = function () {
        global.kobold.history.setIfNotSet(id, weaponId, global.kobold.inventory.equipment.weapon);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, weaponId));
    };
}

// END scenes\Home\saved\HomeSavedController.js

// scenes\Home\unsaved\ground\ant\HomeAnt.js

/**
 * Ant section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeAnt(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.gender() === GenderEnum.MALE;
        var pants = ctrl.pants();
        var bra = ctrl.bra();
        var shirt = ctrl.shirt();
        var underwear = ctrl.underwear();
        var toReturn = `[p]
                            In many parts of the world, these ants are [b]highly[/b] sought after.
                            Some harvest their venom to make powerful lust-inducing potions,
                            others keep entire colonies to [i]indulge[/i] themselves every now and again.
                            You've even heard of some brothels containing walled-off gardens filled with anthills full of this particular breed,
                            visited by the most exclusive of clientele who pay a bunch of gold for just a single encounter with the Venusian ants.
                        [/p]
                        [p]
                            You should consider yourself [b]lucky[/b] for having the rare chance to have some fun with these marvellous little insects.
                            A second one bites down, more aphrodisiac rushing into your system, 
                            ${male ? `your member rapidly hardening, emerging from your cockslit` : `your groin growing more damp with every passing second`}.
                        [/p]
                        [p]
                        `;

        if (pants) {
            toReturn += `   You quickly lower your ${global.kobold.inventory.createItemWithTooltip(pants)}`;
            if (underwear) {
                toReturn += ` and your ${global.kobold.inventory.createItemWithTooltip(underwear)}`;
            }
            toReturn += `, exposing your ${male ? `now fully erect length` : `heated folds`} to the coldness of your surroundings.`;
        } else if (underwear) {
            toReturn += `   You quickly lower your ${global.kobold.inventory.createItemWithTooltip(underwear)},
                            exposing your ${male ? `now fully erect length` : `heated folds`} to the coldness of your surroundings.`;
        }

        if (male) {
            toReturn += `   You grip your needy shaft, and immediately start to stroke it, a third bite eliciting a small,
                            feminine moan from your lips as every motion of your hand causes immense pleasure,
                            your body made temporarily oversensitive by the ants' venom.`;
        } else {
            if(shirt) {
                toReturn += `   You quickly take off your ${global.kobold.inventory.createItemWithTooltip(shirt)}.`;
            }
            if (bra) {
                toReturn += `   You remove your ${global.kobold.inventory.createItemWithTooltip(bra)}, and start to play with your breasts.`;
            } else {
                toReturn += `   You casually start to play with your breasts.`;
            }
            toReturn += `   One of your hands finds its way between your legs, and you wantonly begin to rub your slick slit,
                            a third bite eliciting a small moan from your lips. Every touch causes immense pleasure,
                            your body made temporarily oversensitive by the ants' venom.`;
        }

        toReturn += `   [/p]
                        [p]
                            But still, it's not enough. You need [b]more[/b].
                            You rise from the ground, causing a few more ants to bite, sending spikes of arousal up your spine, clouding your mind.
                            The rational part of your brain knows this is a [b]bad[/b] idea, yet that part is being drowned out by sheer [b]lust[/b].
                            As though your body is acting on its own, you walk over to the anthill, 
                            ${male ? `drop down onto all fours, and thrust your quivering cock directly into the dirt mound` : `squat down, and press your needy loins directly against the dirt mound`}.
                        [/p]
                        [p]
                            Their lair touched, the ants are driven into a frenzy.
                        `;

        if (male) {
            toReturn += `   They swarm over your length, your eyes rolling back into your head as an untold amount of aphrodisiac is injected directly into your loins.
                            You pull your hips back only so you can begin to thrust your shaft in and out of the anthill, outright [b]fucking[/b] the ground,
                            getting off not to any sort of [i]tightness[/i], 
                            but rather to the sheer amount of venom and the super-enhanced feeling of the ants moving about your most sensitive body part.
                        [/p]
                        [p]
                            Needless to say, you don't last long.
                            After just a few humps, you can quickly feel your end approaching.
                            You [b]pound[/b] the mound of dirt into [b]ground[/b], almost to the point of collapse,
                            until finally slamming your member all the way inside one final time, 
                            your hips pressing directly against the tip of the anthill as you reach your climax,
                            squirting wave after wave of thick, heady spunk directly into the lair of the ants.
                        [/p]
                        [p]
                            The moment you reach your orgasm, the tiny creatures instantly seem to recoil from your scales,
                            crawling off of you and back into their hive, like they got what they were after.
                            Your body is already filled to the brim with as much aphrodisiac as it can handle, so you don't really mind.
                        [/p]
                        [p]
                            It takes quite a while for your balls to empty, your climax fueled by the ants' venom.
                            When you finally do pull out of the anthill, you feel completely [b]drained[/b].
                            You roll off to the side, and take a moment to recover.
                            Panting loudly, you cast a gaze downwards, at your member.
                            It seems...[i]bigger[/i] than before.
                            A side effect of the aphrodisiac?
                        [/p]
                        [p]
                            As you slowly rise to your feet, you notice dawn is breaking.
                            No point in going back to sleep now.`;
        } else {
            toReturn += `   They crawl up your waist, some even finding their way into your snatch, 
                            your eyes rolling into the back of your head as their potent aphrodisiac is injected into your very innards.
                            You grab a few more off the ground and place them on your chest, one of them ending up directly on your left nipple,
                            a loud, pleasured grunt echoing through the woods as the little insect bites down.
                        [/p]
                        [p]
                            Needless to say, you don't last long.
                            As need builds up inside of your body, you begin to rub your sopping-wet cunt against the anthill, 
                            its coarse texture ultimately sending you over the edge.
                            You scream out in pure ecstasy as you press your soaking slit down onto the dirt mound as hard as you can,
                            your feminine fluids squirting liberally deep into the lair of the ants.
                        [/p]
                        [p]
                            The moment you reach your orgasm, the tiny creatures instantly seem to recoil from your scales,
                            crawling off of you and back into their hive, like they got what they were after.
                            Your body is already filled to the brim with as much aphrodisiac as it can handle, so you don't really mind.
                        [/p]
                        [p]
                            It takes quite a while for your climax to come to an end, your pleasure fueled by the ants' venom.
                            When you finally do pull away from the anthill, you feel completely [b]drained[/b].
                            You step to the side, and take a moment to recover.
                            Panting loudly, you cast a gaze downwards at your body, but find your view blocked by your breasts.
                            They seem...[i]bigger[/i] than before.
                            A side effect of the aphrodisiac?
                        [/p]
                        [p]
                            As you wipe some of the lingering fluids off your groin, you notice dawn is breaking.
                            No point in going back to sleep now.`;
        }
        
        if (pants || bra || underwear) {
            toReturn += `   You slip back into your attire.`;
        }


        toReturn += `       Despite the large amount of aphrodisiac still coursing through your veins,
                            your arousal seems to have faded along with your orgasm.
                            Your mind is quickly clearing, too.
                            With your lust sated, you turn your attention towards the future.
                        [/p]
                        [p]`;
        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar.
                            Maybe you'll stop at the small hamlet outside of the city walls along the way.
                            While you'd love to bring some of the ants along with you, they have all disappeared back into the hole they once came from.
                            A shame, they could have fetched a handsome price.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeAnt";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getGroundChoice() !== HomeGroundChoice.ANT) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.antChange(ctrl.gender());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getGroundChoice() !== HomeGroundChoice.ANT) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\unsaved\ground\ant\HomeAnt.js

// scenes\Home\unsaved\ground\shake\HomeShake.js

/**
 * Shake section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeShake(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var masturbateId = "unsavedMasturbateButton";
    var sleepId = "unsavedSleepButton";

    var toMasturbate = new HomeMasturbate(ctrl);
    var toSleep = new HomeWetDream(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.gender() === GenderEnum.MALE;
        var toReturn = `[p]
                            Startled, you hop to your feet and frantically begin to swat the ants off of you.
                            The ones you don't manage to wipe off with the first pass of your hand immediately bite down,
                            your system flooded by enough venom to drive a dragon wild.
                        [/p]
                        [p]
                            You take a few steps backwards, away from the ant-pouring mound, as you continue to remove more bugs from your body.
                            You swat one on your side with the flat of your hand, you pluck one off of your tail, and crush one of the insects making its way up your chest.
                            Just as you thought you were completely ant-free, one final specimen digs its mandibles into your back, 
                            before being smitten by your rightful wrath.
                        [/p]
                        [p]
                            The rest of the bugs retreat back into their anthill, dissuaded by the distance you've created between you and it.
                            While you've managed to overcome the ants themselves, the potent aphrodisiac inflicted by their bites courses through your veins.
                            In between your legs, 
                            your ${male ? `fully erect member twitches and throbs,` : `sopping wet slit is`} practically [b]begging[/b] for attention.
                            You are [b]so[/b] aroused that your knees are growing weak, the urge, no, the [b]need[/b] 
                            to ${male ? `jerk off` : `touch yourself`} intensifying with every passing moment.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the ant choice button.
     */
    function buildMasturbateChoice() {
        var disabled = ctrl.unsaved.shake.has() ? "disabled" : "";
        var isSelected = ctrl.unsaved.shake.get() === HomeShakeChoice.MASTURBATE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${masturbateId}" ${disabled}>Masturbate</button>`;

        var tooltip = `Relieve yourself. You wouldn't be able to sleep like this anyway.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the shake choice button.
     */
    function buildSleepChoice() {
        var disabled = ctrl.unsaved.shake.has() ? "disabled" : "";
        var isSelected = ctrl.unsaved.shake.get() === HomeShakeChoice.SLEEP;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${sleepId}" ${disabled}>Sleep</button>`;

        var tooltip = `Repress the dirty thoughts flooding your mind and try to get some rest.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildMasturbateChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSleepChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + masturbateId), $("#" + sleepId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerMasturbateListener() {
        $("#" + masturbateId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.shake.set(HomeShakeChoice.MASTURBATE);
            loadNextPart(toMasturbate);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerSleepListener() {
        $("#" + sleepId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.shake.set(HomeShakeChoice.SLEEP);
            loadNextPart(toSleep);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeShake";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getGroundChoice() !== HomeGroundChoice.SHAKE) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toMasturbate.build();
        part += toSleep.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getGroundChoice() !== HomeGroundChoice.SHAKE) {
            return;
        }

        toMasturbate.registerListeners();
        toSleep.registerListeners();

        if (ctrl.unsaved.shake.has()) {
            return;
        }

        registerMasturbateListener();
        registerSleepListener();
    };
}

var HomeShakeChoice = {
    MASTURBATE: 1,
    SLEEP: 2
};

// END scenes\Home\unsaved\ground\shake\HomeShake.js

// scenes\Home\unsaved\ground\shake\masturbate\HomeMasturbate.js

/**
 * Masturbate section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeMasturbate(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.gender() === GenderEnum.MALE;
        var pants = ctrl.pants();
        var bra = ctrl.bra();
        var underwear = ctrl.underwear();
        var toReturn = `[p]
                            You let out a small, needy grunt as you lustily lick your lips, your hands drifting towards your groin.`;

        if (pants) {
            toReturn += `   You quickly lower your ${global.kobold.inventory.createItemWithTooltip(pants)}`;
            if (underwear) {
                toReturn += ` and your ${global.kobold.inventory.createItemWithTooltip(underwear)}`;
            }
            toReturn += `, exposing your ${male ? `rock-hard member` : `heated folds`} to the coldness of your surroundings.`;
        } else if (underwear) {
            toReturn += `   You quickly lower your ${global.kobold.inventory.createItemWithTooltip(underwear)},
                            exposing your ${male ? `rock-hard member` : `heated folds`} to the coldness of your surroundings.`;
        }

        if (male) {
            toReturn += `   You grip your quivering shaft, and deftly begin to stroke it with your hand,
                            every touch feeling [b]ten times[/b] more intense, your flesh overly sensitive due to the ants' venom.
                        [/p]
                        [p]
                            Leaning against a nearby tree, you pick up your pace, 
                            an abundance of warm precum oozing from the tapered tip of your needy cock lubing up your shaft and your palm,
                            slickening your jerking.
                        [/p]
                        [p]
                            In your aphrodisiac-addled state, you fail to last very long.
                            All too soon, you can feel your end rapidly approaching.
                            Arching your back and letting out a small, rather feminine moan, you shoot your load onto the bark of the tree you were leaning against,
                            your internal balls working overtime to pump out wave after wave of thick, 
                            heady spunk which glistens beautifully in the slowly rising sun's first rays of light.`;
        } else {
            toReturn += `   You slide two of your fingers in between your messy thighs, and press them against your slick slit.
                            Even this slight touch is enough to draw a soft moan from your lips, your body overly sensitive due to the ants' venom.
                        [/p]
                        [p]
                            You spread your legs, and without further ado, you slide both digits inside of your completely [b]drenched[/b] folds, to the very knuckle.
                            You can barely refrain from howling in pleasure as you begin to pump your fingers in and out of your sopping wet cunt,
                            the magnified feeling unlike anything you've ever felt before.
                            Sadly, it is [i]due to[/i] this enhanced satisfaction that you only manage to last for just about a minute of masturbation 
                            before you feel your climax building up inside of you.
                        [/p]
                        [p]
                            With the sun slowly starting to rise, and with your lust greater than ever before, 
                            you decide [i]not[/i] to [b]deprive[/b] yourself from a much-needed orgasm any longer.
                            One final time, you [b]ram[/b] your fingers deep inside of you, before reaching your end,
                            your entire body quivering in pleasure, an abundance of your feminine fluid squirting out onto the leafy forest floor,
                            glistening beautifully in the very first rays of sunlight.
                            `;
        }

        toReturn += `   [/p]
                        [p]
                            Panting loudly, you revel in post-orgasmic bliss for a few moments, 
                            before wiping your groin${pants || underwear ? ` and redressing` : ``}.
                            The ants' venom is slowly being filtered from your system, and with it, your spontaneous arousal vanishes as well.
                        [/p]
                        [p]
                            After licking your fingers clean, you decide there's no point in going back to sleep.
                            Those couple of hours that you rested [i]before[/i] the ants got to you'll have to suffice.
                            While this was fun, it's time to think about more important things.
                            You turn your mind to the future.
                        [/p]
                        [p]`;

        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar.
                            Maybe you'll stop at the small hamlet outside of the city walls along the way.
                            If anything, you hope you at least won't end up sleeping next to another anthill tonight.
                        [/p]`;


        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeMasturbate";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.shake.get() !== HomeShakeChoice.MASTURBATE) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.masturbateChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.shake.get() !== HomeShakeChoice.MASTURBATE) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\unsaved\ground\shake\masturbate\HomeMasturbate.js

// scenes\Home\unsaved\ground\shake\wetdream\HomeWetDream.js

/**
 * Wet dream section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeWetDream(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.gender() === GenderEnum.MALE;
        var sawDragoness = global.kobold.history.shared.dragonessPrincess.relation !== DragonessPrincessEnum.UNMET;
        var toReturn = `[p]
                            No!
                            You [b]aren't[/b] giving in to these darned [b]pests[/b]' venom.
                            While they're just simple insects doing whatever their instinct tells them to, you are [b]not[/b].
                            You may be at the bottom of the civilized world, but if there's anything you [i]are[/i] above, it is simple-minded creatures such as ants.
                        [/p]
                        [p]
                            This is a matter of principle.
                            You will [b]not[/b] be brought to your knees by a bunch of tiny six-legged freaks, 
                            no matter [b]how[/b] much your groin is [b]aching[/b] for attention.
                            You take a deep breath and steel your resolve.
                            ${male ? `With your member proudly protruding from your groin,` : `With your arousal beginning to seep down your inner thighs,`}
                            you begin to look for a new place to sleep.
                        [/p]
                        [p]
                            It isn't long before you come across a tiny blanket of moss, big enough for at least [i]some[/i] of your small frame to rest on.
                            Tiredness beginning to set in once more, you decide not to look any further.
                            You quickly check for anthills, and are glad to see that this time, there are none around.
                            You drop down to the ground, rest your head atop of the surprisingly soft moss, and within seconds manage to drift to sleep once more.
                        [/p]
                        [p]
                            Being as [i]excited[/i] as you are, your slumber is plagued by erotic dreams of various kinds.
                            One moment, you are tied up in a dungeon, getting abused by a sadistic, whip-armed fox.
                            The next, you find yourself getting caught by the soldiers that you robbed, 
                            a particularly buff looking wolf amongst them ramming his oversized knot inside of you.
                            ${sawDragoness ? `The blue-scaled dragoness also plays a role in your wet dreams. You envision yourself lapping at her folds while she rides your face, moaning in pleasure.` : ``}
                        [/p]
                        [p]
                            You slowly drift away from your pleasured dreams, waking up to find your hand having subconsciously drifted towards your groin.
                            During the night, you may have touched yourself a bit, but you proudly come to the conclusion that you [b]didn't[/b] masturbate.
                            You can practically [b]feel[/b] the ants' venom fading from your body, your arousal vanishing along with it.
                        [/p]
                        [p]
                            You let out a sigh of relief.
                            You've managed to retain your pride in the face of adversity, 
                            and you've won a figurative mental battle against a bunch of tiny, mindless bugs.
                            Regardless of the mediocrity of this achievement,
                            you feel content to know that you can remain in control of your body even when aroused.
                        [/p]
                        [p]
                            As the sun rises once again, so do you.
                            Getting up off of the ground, the coldness of the morning grips your body.
                            It washes away the heat of your arousal, like a dip in the river on a frigid winter night.
                            The last hint of your excitement vanishing, your mind turns to the future.
                        [/p]
                        [p]`;
        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar.
                            Maybe you'll stop at the small hamlet outside of the city walls along the way.
                            If anything, you hope you at least won't end up sleeping next to another anthill tonight.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeWetDream";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.shake.get() !== HomeShakeChoice.SLEEP) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.wetChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.shake.get() !== HomeShakeChoice.SLEEP) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\unsaved\ground\shake\wetdream\HomeWetDream.js

// scenes\Home\unsaved\ground\HomeGround.js

/**
 * Ground sleeping section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeGround(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var antId = "unsavedAntButton";
    var shakeId = "unsavedShakeButton";

    var toAnt = new HomeAnt(ctrl);
    var toShake = new HomeShake(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.gender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You owe the clan [b]a lot[/b] of money.
                            You wouldn't be surprised if the Three-Tailed Rat were to send some kind of night-time 
                            assassination squad to your home to try and [i]teach you[/i] a [b]lethal late-night lesson[/b].
                        [/p]
                        [p]
                            You can't risk sleeping in your home. That's the first place they'd come looking for you.
                            While using the hammock is a nice idea, you'd be [b]far[/b] too exposed.
                            You decide to choose [b]safety[/b] over [i]comfort[/i].
                            The ground is where you'll sleep tonight.
                        [/p]
                        [p]
                            You wander a little further into the woods, away from your shed.
                            After a solid minute of walking, you stumble upon a bush large enough to conceal your entire body.
                            You sigh loudly, getting flashbacks from your younger days as you reluctantly lower yourself into the foliage,
                            your small frame coming to rest on the cold ground at the very root of the shrub.
                        [/p]
                        [p]
                            While by no means warm, at least the plant's leaves somewhat protect you from the freezing cold washing over the land.
                            This isn't your first time sleeping on the forest floor, but your mind is too weary to reminisce right now.
                            Curling up into a ball, you slowly drift to sleep.
                        [/p]
                        [p]
                            You wake up far earlier than you'd have liked, to the feeling of something small [i]crawling[/i] over your scales.
                            At first you think you're dreaming, but the sensation persist.
                            It moves along your exposed belly, creeping every which way.
                        [/p]
                        [p]
                            As you open your heavy eyelids and stare down at your body, you are greeted with the cause of the odd sensation.
                            A bunch of ants are crawling about your lower body, many more swarming out of a nearby anthill that you failed to spot earlier.
                            Worse yet, these aren't just regular ants.
                            Even in the near pitch-blackness of night, you can make out their distinctly [color=pink]pink[/color] hue.
                            These are the dreaded [b]Venusian ants[/b], 
                            whose bite is said to inject a potent aphrodisiac strong enough for ten of them to make a male horse erect.
                        [/p]
                        [p]
                            Your mind instantly snaps awake as one of the small bugs digs its pincers into your scales.
                            It doesn't [i]hurt[/i] more than a small pinch, yet your groin instantly responds to the venom,
                            ${male ? "your member stirring to life inside of your cockslit" : "your slit growing just a little more moist"}.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the ant choice button.
     */
    function buildAntChoice() {
        var disabled = ctrl.unsaved.hasMadeGroundChoice() ? "disabled" : "";
        var isSelected = ctrl.unsaved.getGroundChoice() === HomeGroundChoice.ANT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${antId}" ${disabled}>Want more</button>`;

        var tooltip = global.parser.parse(`The aphrodisiac feels good. [b]So[/b] good. You want [b]more[/b] of their venom. You [b]need[/b] more of it.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the shake choice button.
     */
    function buildShakeChoice() {
        var disabled = ctrl.unsaved.hasMadeGroundChoice() ? "disabled" : "";
        var isSelected = ctrl.unsaved.getGroundChoice() === HomeGroundChoice.SHAKE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${shakeId}" ${disabled} style="font-size: 18px;">Shake them off</button>`;

        var tooltip = `Get the little things off of you before they can do more harm!`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildAntChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildShakeChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + antId), $("#" + shakeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerAntListener() {
        $("#" + antId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.makeGroundChoice(HomeGroundChoice.ANT);
            loadNextPart(toAnt);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerShakeListener() {
        $("#" + shakeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.makeGroundChoice(HomeGroundChoice.SHAKE);
            loadNextPart(toShake);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeGround";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.GROUND) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toAnt.build();
        part += toShake.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.GROUND) {
            return;
        }

        toAnt.registerListeners();
        toShake.registerListeners();

        if (ctrl.unsaved.hasMadeGroundChoice()) {
            return;
        }

        registerAntListener();
        registerShakeListener();
    };
}

var HomeGroundChoice = {
    ANT: 1,
    SHAKE: 2
};

// END scenes\Home\unsaved\ground\HomeGround.js

// scenes\Home\unsaved\hammock\HomeHammock.js

/**
 * Hammock section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeHammock(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You decide you'd rather not risk sleeping inside of your home in case the Rat's men return.
                            Seeing as you don't think you'd get much sleep at all on the cold, hard ground, 
                            you choose to spend your night on the hammock, 
                            an excellent compromise between comfort and the risk of getting caught by [i]whoever[/i] is looking for you.
                        [/p]
                        [p]
                            Even [i]if[/i] someone were to come [i]back[/i] to your shack during the night, 
                            you reason there's no way they'd come looking for you in the forest itself.
                            While you'll be suspended above any sort of concealing shrubbery, 
                            your slightly more remote location as well as the darkness of night are sure to hide you from any prying eyes.
                        [/p]
                        [p]
                            You march into the woods beyond your hovel.
                            Even you, having a good idea of where your hammock [i]should[/i] be, have a hard time actually [b]finding[/b] it in the middle of night.
                            Only after a good five minutes of determined searching do you finally come across your chosen nighttime solution.
                            Of course, with someone sleeping in it, it's bound to be a little more visible than when empty, but oh well.
                            You've made your bed, and now you're going to lie in it.
                        [/p]
                        [p]
                            You crawl into the hammock, and after a bit of fumbling, manage to reach a comfortable resting position.
                            The only thing you didn't consider was the temperature.
                            It's pretty chilly outside, and you have nothing to cover yourself with.
                            In an attempt to conserve precious body heat, you curl up into a ball.
                            Shuddering from the cold, you slowly drift to sleep.
                        [/p]
                        [p]
                            While the near-freezing temperature rouses you from your slumber more than once,
                            it does so for only a few minutes at a time before you drift back into unconsciousness.
                            You manage to get a decent amount of oft-interrupted rest in.
                        [/p]
                        [p]
                            As the sun begins to rise, you wake up properly, chilled to the very bone.
                            Shivering uncontrollably, you slip out of your hammock.
                            You breathe some warm air onto your ice-cold scaly hands and rub them together to create friction.
                        [/p]
                        [p]
                            While you wish you'd be able to wake up nice and slow,
                            your frigid surroundings spur you to immediately begin to move about in order to generate some much-needed body heat.
                            You rub your eyes, stretch your legs, and walk back to your shed.
                        [/p]
                        [p]
                            It looks to be in exactly the same condition you left it yesterday.
                            You're starting to regret not sleeping indoors.
                            But alas, what is done, is done.
                        [/p]
                        [p]
                            You continue to warm up your body by rubbing your legs and your arms with your hands.
                            With the sun gradually warming your surroundings, 
                            you ultimately manage to reach the point where you're no longer [b]too[/b] cold to think.
                        [/p]
                        [p]`;

        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar.
                            Maybe you'll stop at the small hamlet outside of the city walls along the way.
                            If anything, you hope you'll at least sleep somewhere a little warmer tonight.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeHammock";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.HAMMOCK) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.hammockChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.HAMMOCK) {
            return;
        }

        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\unsaved\hammock\HomeHammock.js

// scenes\Home\unsaved\inside\HomePillaged.js

/**
 * Pillaged section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomePillaged(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your home may be pillaged, but that doesn't mean you can't still sleep in it.
                            Whoever raided your place is probably long-gone.
                            Sticking around a seemingly abandoned hovel would be meaningless for them,
                            and nobody's going to come looking for you while it's dark out.
                        [/p]
                        [p]
                            Having mentally reassured yourself that everything will be just fine, you walk up to the front-end of your shed.
                            You try to open the busted door, but to your annoyance, this causes it to fall off of its hinges completely, 
                            tumbling down against the wooden back-wall of your home, nearly taking the entire ramshackle thing down with it.
                        [/p]
                        [p]`;

        var male = ctrl.gender() === GenderEnum.MALE;
        if (male) {
            toReturn += `   You let out a loud sigh.
                            Stepping inside, over the remains of the entryway, you use your masculine strength to lift up the door.
                            It's human-sized, but that doesn't stop you from putting it back onto its hinges.
                        [/p]
                        [p]
                            Slightly inspired by your own prowess, `;
        } else {
            toReturn += `   You let out a loud sigh.
                            Stepping inside, over the remains of the entryway, you try, but fail to lift up your door.
                            It's human-sized, making it far too heavy for someone of your posture to properly handle.
                        [/p]
                        [p]
                            Slightly disheartened, `;
        }

        toReturn += `       you begin to collect the scattered remains of the bale of hay that you call your [i]bed[/i].
                            Those [b]savages[/b] completely [b]tore[/b] it apart, probably thinking you had some valuables concealed within.
                            You almost feel like a bird making a nest.
                            It takes a couple of minutes, but you eventually manage to form a small pile of straw, big enough for you to sleep on.
                        [/p]
                        [p]
                            You lie down on top of the warm, comfortable former-fodder.`;

        if (male) {
            toReturn += `   The hay, together with your fixed door, provide for a warm and snug environment.`;
        } else {
            toReturn += `   The hay shields you from the cold seeping in through the busted door.`;
        }

        toReturn += `       Due to sheer exhaustion, you manage to drift to sleep rather quickly.
                        [/p]
                        [p]
                            ${male ? "Thanks to your fixed door," : "Despite your door being broken,"} you end up having a nice, if brief, little nap.
                            You slowly wake up hours later, completely [b]buried[/b] in the pile of straw, your scaly body being nurtured by the lingering warmth it provides.
                            While you'd love to stay and rest for just a bit longer, dawn is breaking.
                            You were right about people [i]not[/i] looking for you during the night, but you don't want to risk sticking around during daytime.
                        [/p]
                        [p]
                            You rise from your nest feeling quite rejuvinated.
                            Your short slumber did you good.
                            It allowed your brain and your body both to recover significantly.
                            You are ready to put the trials and tribulations of yesterday aside, and do whatever you need to do to make it through another day.
                        [/p]
                        [p]
                            You step out of the ${male ? "fixed" : "busted"} door, and are instantly greeted with a gust of cool morning air.
                            You breathe in deeply, clearing your mind before thinking about the future.`;

        var gold = ctrl.gold();
        if (!gold) {
            toReturn += `   You are completely [b]broke[/b]. 
                            You have no money whatsoever to pay your overdue debts with.
                            Desperate times call for desperate measures.`;
        } else if (gold > 150) {
            toReturn += `   You have quite a bit of money, but sadly it's still not enough to pay your overdue debt.`;
        } else if (gold > 203) {
            toReturn += `   You have [b]a lot[/b] of money, more than you gained from just robbing the caravan, even.
                            You're [b]very[/b] close to being able to pay off your debt.
                            You just need a [i]teensy[/i] bit more.
                            But you aren't going to get it from these woods.`;
        }

        toReturn += `       You decide to head out, to seek your fortune in the great city of Varanar,
                            and maybe take a stop at the small hamlet outside of the city walls along the way.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homePillaged";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.INSIDE) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.unsaved.pillageChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unsaved.getSleepChoice() !== HomeUnsavedChoice.INSIDE) {
            return;
        }

        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}

// END scenes\Home\unsaved\inside\HomePillaged.js

// scenes\Home\unsaved\HomeUnsaved.js

/**
 * Unsaved section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeUnsaved(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var insideId = "unsavedInsideButton";
    var hammockId = "unsavedHammockButton";
    var groundId = "unsavedGroundButton";

    var toInside = new HomePillaged(ctrl);
    var toHammock = new HomeHammock(ctrl);
    var toGround = new HomeGround(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]Late arrival[/st]`;
        var deepwoods = global.kobold.history.sceneStackHas("RiversideMarsh");
        toReturn += `   [p]
                            After a short trek through the forest, you begin to near your small hovel, located near the northern edge of the woods.
                            Thank goodness you're not far off, because ${deepwoods ? "it's getting [b]very[/b] late" : "night is upon you"}, 
                            and you know how [i]dangerous[/i] things can get around the woodland after the sun goes down.
                        [/p]
                        [p]
                            Your wooden [i]shed[/i], illuminated dimly by moonlight shining through the treetops, soon comes into view.
                            As you approach, however, you notice something's [i]wrong[/i].
                            The door to your humble abode hangs crooked on its sturdy hinges, obviously [b]forced[/b] open.
                            You've no doubt that this was the work of the Three-Tailed Rat's men.
                            The only question that lingers in your mind is whether or not they're still in the area.
                        [/p]
                        [p]
                            You skulk around your shoddy shack, keeping your eyes peeled and your ears open,
                            yet you can't quite find anyone at first glance.
                            You reckon they must have left after discovering that your home contains nothing but the hay you sleep on.
                            Too bad for them, you carry about all you own, which isn't really all that much.
                        [/p]
                        [p]
                            You let out a loud yawn, your mind weary from the [i]active[/i] day you've had, worn out both physically as well as emotionally.
                            While you'd love to pull an all-nighter just to see if any of those no-good [b]looters[/b] would have the [b]guts[/b] to return 
                            to your shack while you're present, both your body and your brain are [b]far[/b] too tired to stay up for much longer, let alone the entire night.
                        [/p]
                        [p]
                            However sleepy you may be, you're still alert enough to realize that [i]should[/i] whoever raided your home return to find you sleeping,
                            that would [b]not[/b] end well for you.
                            Then again, why [i]would[/i] they return?
                            They didn't find anything of value, and you doubt anyone would come looking for you in the middle of night.
                            But with the Three-Tailed Rat Clan, you never know.
                        [/p]
                        [p]
                            Besides sleeping in what remains of your shed, there's also the possibility of resting outdoors,
                            which might prove to be a little more safe.
                        [/p]
                        [p]
                            A few months ago, you found a fisherman's abandoned net washed up on the bank of the river.
                            Instead of letting it go to waste, you tied up the intertwined rope-webbing in between two trees,
                            fashioning yourself a hammock not too far off from your home.
                            While undoubtedly more [i]comfortable[/i] than sleeping on the ground,
                            you would also be quite a bit more [i]visible[/i] and [i]vulnerable[/i] as opposed to sleeping in a bush.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the inside choice button.
     */
    function buildInsideChoice() {
        var disabled = ctrl.unsaved.hasMadeSleepChoice() ? "disabled" : "";
        var isSelected = ctrl.unsaved.getSleepChoice() === HomeUnsavedChoice.INSIDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${insideId}" ${disabled}>Inside</button>`;

        var tooltip = `Your home may be plundered, but you doubt they took <span class="italic">all</span> of your hay.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the hammock choice button.
     */
    function buildHammockChoice() {
        var disabled = ctrl.unsaved.hasMadeSleepChoice() ? "disabled" : "";
        var isSelected = ctrl.unsaved.getSleepChoice() === HomeUnsavedChoice.HAMMOCK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${hammockId}" ${disabled} style="font-size: 18px;">On the hammock</button>`;

        var tooltip = `The hammock is comfortable enough to get some decent rest in, but you'd be pretty exposed during the night.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the ground choice button.
     */
    function buildGroundChoice() {
        var disabled = ctrl.unsaved.hasMadeSleepChoice() ? "disabled" : "";
        var isSelected = ctrl.unsaved.getSleepChoice() === HomeUnsavedChoice.GROUND;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${groundId}" ${disabled}>On the ground</button>`;

        var tooltip = `Your home is no longer safe, and you'd rather not sleep in a strung-up net with a bunch of people potentially hunting you.
                       Rest on the cold ground, in a nearby bush.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 300px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You sleep: </div>`;
        choice += buildInsideChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildHammockChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildGroundChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + insideId), $("#" + hammockId), $("#" + groundId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerInsideListener() {
        $("#" + insideId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.makeSleepChoice(HomeUnsavedChoice.INSIDE);
            loadNextPart(toInside);
        });

    }

    /**
     * Adds a listener to the button.
     */
    function registerHammockListener() {
        $("#" + hammockId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.makeSleepChoice(HomeUnsavedChoice.HAMMOCK);
            loadNextPart(toHammock);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerGroundListener() {
        $("#" + groundId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unsaved.makeSleepChoice(HomeUnsavedChoice.GROUND);
            loadNextPart(toGround);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeUnsaved";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.status() !== HomeStatusEnum.UNSAVED) {
            return "";
        }
        if (!ctrl.unsaved.hasMadeSleepChoice()) {
            ctrl.introAudio.playSettingsDependent();
        }
        global.ui.applyTheme("home_night");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += toInside.build();
        part += toHammock.build();
        part += toGround.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.status() !== HomeStatusEnum.UNSAVED) {
            return;
        }

        toInside.registerListeners();
        toHammock.registerListeners();
        toGround.registerListeners();

        if (ctrl.unsaved.hasMadeSleepChoice()) {
            return;
        }

        registerInsideListener();
        registerHammockListener();
        registerGroundListener();
    };
}

var HomeUnsavedChoice = {
    INSIDE: 1,
    HAMMOCK: 2,
    GROUND: 3
};

// END scenes\Home\unsaved\HomeUnsaved.js

// scenes\Home\unsaved\HomeUnsavedController.js

/**
 * Controller for the unsaved part of the home scene.
 * @param {string} sceneId The id of the scene.
 */
function HomeUnsavedController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;

    var sexExId = "unsavedSexEx";
    var sleepId = "unsavedSleep";
    var groundId = "unsavedGround";
    var shakeId = "unsavedShake";
    var hammockChangeId = "unsavedHammockChange";
    var pillageChangeId = "unsavedPillageChange";
    var wetChangeId = "unsavedWetChange";
    var masturbateChangeId = "unsavedMasturbateChange";
    var antChangeId = "unsavedAntChange";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Makes the sleep choice.
     * @param {HomeUnsavedChoice} choice The choice.
     */
    this.makeSleepChoice = function (choice) {
        global.kobold.history.setKey(id, sleepId, choice);
    };

    /**
     * Fetches the sleep choice from history and returns it.
     * May return undefined if the sleep choice has not yet been set.
     */
    this.getSleepChoice = function () {
        return global.kobold.history.getKey(id, sleepId);
    };

    /**
     * Returns true if the sleep choice has been made.
     */
    this.hasMadeSleepChoice = function () {
        return global.kobold.history.has(id, sleepId);
    };


    /**
     * Makes the ground choice.
     * @param {HomeGroundChoice} choice The choice.
     */
    this.makeGroundChoice = function (choice) {
        global.kobold.history.setKey(id, groundId, choice);
    };

    /**
     * Fetches the ground choice from history and returns it.
     * May return undefined if the ground choice has not yet been set.
     */
    this.getGroundChoice = function () {
        return global.kobold.history.getKey(id, groundId);
    };

    /**
     * Returns true if the ground choice has been made.
     */
    this.hasMadeGroundChoice = function () {
        return global.kobold.history.has(id, groundId);
    };

    this.hammockChange = function () {
        global.kobold.history.doIfNotSet(id, hammockChangeId, true, function () {
            global.kobold.status.physical.decrease(10, "Near-hypothermia");
            global.kobold.status.stamina.increase(15, "Poor sleep");
            if (global.kobold.status.exertion.get()) {
                global.kobold.history.setKey(id, sexExId, true);
                global.kobold.status.exertion.decrease(20, "Slept");
            }
        });

        var changes = [
            new Change("Near-hypothermia", "Health", -10),
            new Change("Poor sleep", "Stamina", +15)
        ];
        if (global.kobold.history.has(id, sexExId)) {
            changes.push(new Change("Slept", "Sexual exhaustion", -20, true));
        }
        return global.ui.change.buildNotification(changes);
    };

    this.pillageChange = function () {
        global.kobold.history.doIfNotSet(id, pillageChangeId, true, function () {
            global.kobold.status.physical.increase(25, "Short nap");
            global.kobold.status.mental.increase(25, "Short nap");
            global.kobold.status.stamina.increase(25, "Short nap");
            if (global.kobold.status.exertion.get()) {
                global.kobold.history.setKey(id, sexExId, true);
                global.kobold.status.exertion.decrease(25, "Short nap");
            }
        });

        var changes = [
            new Change("Short nap", "Health", +25),
            new Change("Short nap", "Sanity", +25),
            new Change("Short nap", "Stamina", +25)
        ];
        if (global.kobold.history.has(id, sexExId)) {
            changes.push(new Change("Short nap", "Sexual exhaustion", -25, true));
        }
        return global.ui.change.buildNotification(changes);
    };

    this.wetChange = function () {
        global.kobold.history.doIfNotSet(id, wetChangeId, true, function () {
            global.kobold.status.physical.increase(15, "Brief nap");
            global.kobold.status.mental.increase(10, "Mental victory");
            global.kobold.status.stamina.increase(15, "Brief nap");
            global.kobold.status.exertion.increase(10, "Unsated lust");
        });
        return global.ui.change.buildNotification([
            new Change("Brief nap", "Health", +15),
            new Change("Mental victory", "Sanity", +10),
            new Change("Brief nap", "Stamina", +15),
            new Change("Unsated lust", "Sexual exhaustion", +10, true)
        ]);
    };

    this.masturbateChange = function () {
        global.kobold.history.doIfNotSet(id, masturbateChangeId, true, function () {
            global.kobold.status.physical.decrease(5, "Sleep deprivation");
            global.kobold.status.mental.decrease(5, "Sleep deprivation");
            global.kobold.status.stamina.decrease(5, "Sleep deprivation");
            global.kobold.status.exertion.increase(20, "Masturbation");
        });
        return global.ui.change.buildNotification([
            new Change("Sleep deprivation", "Health", -5),
            new Change("Sleep deprivation", "Sanity", -5),
            new Change("Sleep deprivation", "Stamina", -5),
            new Change("Masturbation", "Sexual exhaustion", +20, true)
        ]);
    };

    this.antChange = function (gender) {
        global.kobold.history.doIfNotSet(id, antChangeId, true, function () {
            global.kobold.status.physical.decrease(5, "Sleep deprivation");
            global.kobold.status.mental.decrease(10, "Fucked an anthill");
            global.kobold.status.stamina.decrease(10, "Fucked an anthill");
            global.kobold.status.exertion.increase(25, "Fucked an anthill");
            if (gender === GenderEnum.MALE) {
                global.kobold.body.growDick(global.kobold.body.dick + 1);
            } else {
                global.kobold.body.growBreasts(global.kobold.body.breasts + 1);
            }
        });

        var changes = [
            new Change("Sleep deprivation", "Health", -5),
            new Change("Fucked an anthill", "Sanity", -10),
            new Change("Fucked an anthill", "Stamina", -10),
            new Change("Fucked an anthill", "Sexual exhaustion", +25, true)
        ];

        if (gender === GenderEnum.MALE) {
            changes.push(new Change("Lasting effects", "Dick size", +1));
        } else {
            changes.push(new Change("Lasting effects", "Breast size", +1));
        }

        return global.ui.change.buildNotification(changes);
    };

    function ShakeController(key) {
        this.get = function () {
            return global.kobold.history.getKey(id, key);
        };
        this.set = function (choice) {
            global.kobold.history.setKey(id, key, choice);
        };
        this.has = function () {
            return global.kobold.history.has(id, key);
        };
    }

    this.shake = new ShakeController(shakeId);
}

// END scenes\Home\unsaved\HomeUnsavedController.js

// scenes\Home\HomeController.js

/**
 * Controller for the Home scene.
 * @param {string} sceneId The id of the scene.
 */
function HomeController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var statusId = "status";
    var genderId = "gender";
    var autoSaveId = "autoSave";
    var goldId = "gold";
    var continueId = "continue";
    var underwearId = "underwear";
    var pantsId = "pants";
    var braId = "bra";
    var shirtId = "shirt";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.hamletSceneName = "SekiWorkshop";
    this.hamletFolder = "HamletDay2";
    this.saved = new HomeSavedController(id);
    this.unsaved = new HomeUnsavedController(id);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /*
     * Stores the status of the home at scene-entry time.
     */
    this.status = function () {
        global.kobold.history.setIfNotSet(id, statusId, global.kobold.history.shared.home.status);
        return global.kobold.history.getKey(id, statusId);
    };

    /*
     * Stores the kobold's base gender.
     */
    this.gender = function () {
        global.kobold.history.setIfNotSet(id, genderId, global.kobold.body.getBaseGender());
        return global.kobold.history.getKey(id, genderId);
    };

    /*
     * Autosaves the game if necessary.
     */
    this.autoSave = function () {
        global.kobold.history.doIfNotSet(id, autoSaveId, true, function () {
            global.saveManager.autoSave();
        });
    };


    /**
     * Logs and returns the amount of gold the kobold had at the start of the scene.
     */
    this.gold = function () {
        global.kobold.history.setIfNotSet(id, goldId, global.kobold.inventory.coins);
        return global.kobold.history.getKey(id, goldId);
    };

    /**
     * Signals the scene has been continued.
     */
    this.continue = function () {
        global.kobold.history.setKey(id, continueId, true);
    };

    /**
     * Returns whether or not the scene has continued.
     * @returns {boolean} True if the scene has continued, false otherwise.
     */
    this.hasContinued = function () {
        return global.kobold.history.has(id, continueId);
    };

    this.pants = function () {
        global.kobold.history.setIfNotSet(id, pantsId, global.kobold.inventory.equipment.pants);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, pantsId));
    };

    this.bra = function () {
        global.kobold.history.setIfNotSet(id, braId, global.kobold.inventory.equipment.bra);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, braId));
    };
    
    this.shirt = function () {
        global.kobold.history.setIfNotSet(id, shirtId, global.kobold.inventory.equipment.shirt);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, shirtId));
    };

    this.underwear = function () {
        global.kobold.history.setIfNotSet(id, underwearId, global.kobold.inventory.equipment.underwear);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, underwearId));
    };
    
    this.introAudio =  new AudioController(id, "res/audio/home/tension.mp3", 100);
}

// END scenes\Home\HomeController.js

// scenes\Home\Home.js

/**
 * The Home scene. One of the options following the Forest.
 */
function Home() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "Home";
    var sceneNameUnsaved = "Home - Late";
    var sceneNameSaved = "Home - Early";
    var ctrl = new HomeController(sceneId);
    var saved = new HomeSaved(ctrl);
    var unsaved = new HomeUnsaved(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Returns true if the home was saved, and false otherwise.
     * @returns {boolean} True if the home was saved, and false otherwise.
     */
    function hasSaved() {
        var status = ctrl.status();
        return (status === HomeStatusEnum.SAVED);
    }

    /**
     * Sets this scene's name.
     */
    function setName() {
        var sceneName = hasSaved() ? sceneNameSaved : sceneNameUnsaved;
        that.name = sceneName;
    }

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]home[/t]`);
        tab += hasSaved() ? saved.build() : unsaved.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = "Error";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setName();
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        hasSaved() ? saved.registerListeners() : unsaved.registerListeners();
        ctrl.autoSave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new Home();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Home\Home.js



// END SCENE Home

