

// SCENE SlaveNoonTwo

// scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoFarmer.js

/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoFarmer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.FARMER;
    var reqController = ctrl.result;
    var changeController = ctrl.farmer;

    var nextSceneReady = ctrl.farmerSceneReady;
    var nextSceneName = ctrl.farmerSceneName;
    var nextFolderName = ctrl.farmerFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Farmer buys kobold. His kid looks very excited.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoFarmer.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoVixen.js

/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoVixen(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.VIXEN;
    var reqController = ctrl.result;

    var continueId = arguments.callee.name + "ButtonOne";

    var idsToRemove = [
        "SlaveNoonTwoVixen",
        "SlaveNoonTwoResults"
    ];

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var dick = ctrl.resultBodyMisc.dick();
        var injected = ctrl.gag.get();
        var drank = ctrl.outside.get() === SlaveNoonTwoOutsideChoice.DRINK;
        var toReturn = `[p]
                            "[color=orange]One hundred.[/color]" a gentle, feminine voice rings out.
                            It's the half-naked vixen.
                            She's soon challenged by the goblin, whose stingy pockets seem far deeper than what you'd have imagined.
                            "[color=green]One hundred and twenty![/color]"
                            The kind-looking canine casts a wicked leer towards the small humanoid.
                            "[color=orange]One hundred and fifty. Or would you rather deal with a back-handed [b]greenskin[/b]?[/color]"
                            "[color=green][b]One fifty-one[/b]![/color]"
                        [/p]
                        [p]
                            Bartholomew seems conflicted.
                            For a moment, it feels as though a [b]fight[/b] is brewing between the two interested parties.
                            But then, right as temperatures are about to reach a boiling point, Fenrir steps in to settle the debate,
                            your captor taking over from the caravan master.
                            "[color=gblue]Us canines have to stick together.
                            [b]Sold[/b], to the lady in black![/color]"
                            The goblin grumbles and complains, but the wolf's decision is final.
                            The crowd parts and money exchanges hands.
                            Seki must have wandered off somewhere during the bidding.
                            He's nowhere to be seen.
                        [/p]
                        [p]
                            While Barto chats with the woman, Fenrir approaches you.
                            "[color=gblue]Well, ${name}, you're hers now.
                            Next time we meet, you can thank me for not letting that [b]filthy[/b] goblin have you.
                            I'm no psychic, but I've a feeling at least the bitch'll treat you a bit better.
                            Either way, good luck.
                            You're going to need it.[/color]"
                        [/p]
                        [p]
                            Having said his farewells, the big wolf pushes you forwards, nudging you off of the small stage, towards your new [i]mistress[/i].
                            The deal concluded, the human and the lupine walk back to the carriages, bickering on how to split their profits.
                            The vixen approaches you, leaning down to talk eye-to-eye.
                            "[color=orange]Hey there, little ${dick ? `buddy` : `girl`}.[/color]"
                            She flashes you a toothy grin.
                            "[color=orange]You're all [b]mine[/b] now.
                            But don't worry, I won't hurt you, as long as you do everything I say.
                            You're going to have lots of [b]fun[/b] staying with me, I'm sure of it.[/color]"
                        [/p]`;

        if (injected) {
            toReturn += `[p]
                            The vixen notices the gag in your mouth.
                            "[color=orange]Let's get that [i]thing[/i] out of your mouth, shall we?[/color]"
                            You give her an eager look.
                            She moves one of her hands towards the rope tied around your muzzle
                            - which Fenrir told you [b]not[/b] to touch -
                            and with a single [i]flick[/i] of her claws, she [b]surgically[/b] severs the cord.
                            You reach for the underwear in your mouth, but the female fox beats you to it,
                            gracefully tugging the unsanitary, ${drank ? `feral-and-` : ``}kobold-spit drenched underpants from your muzzle.
                        [/p]
                        [p]
                            Finally able to fully close your jaws once more, you spit on the dry ground to get the lingering taste of [b]wolf ass[/b] out of your mouth.
                            The vulpine, meanwhile, deeply [b]sniffs[/b] the saliva-saturated garment,
                            before giving it a tiny lick, the disgusting flavor seemingly [i]pleasing[/i] her.
                            "[color=orange]This is [b]his[/b], isn't it?[/color]"
                            You meekly nod in response, knowing perfectly well who she's talking about.
                            "[color=orange]I'd have paid double if I knew you came with [i]extras[/i].[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            ${injected ? `Your gag removed, the` : `The`} busty woman grabs your hand.
                            "[color=orange]I don't live far from here.
                            Let's walk there together, shall we?[/color]"
                            She's so [b]nice[/b].
                            Her palm is [b]soft[/b] and [b]warm[/b].
                            Living with [b]her[/b] is becoming a more inviting idea with every passing second.
                        [/p]
                        [p]
                            The two of you casually stroll alongside one of the hamlet's two main roads.
                            A few dozen yards further, you continue your journey on a small dirt path,
                            the opposite way of Seki's workshop, towards a large [b]mansion[/b] with an attached barn.
                            Wow, she must be [b]rich[/b] or something!
                            For a moment, you get your hopes up,
                            thinking you'll be allowed to spend your days in the luxury of an actual [b]house[/b],
                            but alas, the canine guides you to the stables instead.
                        [/p]
                        [p]
                            No big deal, rather a comfortable shelter with lots of hay than being forced to sleep outside, right?
                            The moment the big barn doors close behind you, the vixen immediately takes off her shirt, exposing her nude body.
                            So she [b]wasn't[/b] wearing anything underneath.
                            "[color=orange][b]Much[/b] better.
                            I [b]hate[/b] clothing.
                            Far too [i]constricting[/i].[/color]"
                            She's a [b]nudist[/b]?!
                            You get the feeling you're going to [b]love[/b] it here, despite the [i]weird[/i], lingering smell that you can't quite place.
                        [/p]
                        [p]
                            "[color=orange]Welcome to your new home, my little [b]pet[/b].[/color]"
                            If you get to stare at her naked body all day long, you'll [b]gladly[/b] be her [i]servant[/i],
                            or whatever she meant by that.
                            "[color=orange]Let's get you oriented, shall we?[/color]"
                        [/p]
                        [p]
                            The two of you walk to the back of the building, where an inconspicuous solemn table stands.
                            "[color=orange]Stay here for a minute, okay?[/color]"
                            You nod to your new [i]mistress[/i], taking the time to inspect the barn.
                            It's divided into two rows of cubicles, pens for whatever creatures the canine is keeping,
                            with the path the two of you just walked in between the corrals.
                            Outside of some strewn about hay, there isn't really much to look at.
                        [/p]
                        [p]
                            Your gaze quickly returns to the vixen.
                            She bends over deeply, rummaging through a sack before fetching out something you can't quite make out.
                            Then, she steps into one of the pens.
                            After half a minute or so, she emerges once more, with a leash in her hand.
                            A leash attached to a collar around the neck of a crying, pink, female kobold, clearly [b]unhappy[/b] to be here.
                        [/p]
                        [p]
                            Dumbstruck, you stare at Cassidy, as she guides the kobold towards the table you're standing next to.
                            Your mistress harshly [b]pushes[/b] what you can only presume to be her [i]other[/i] pet back-first onto the table,
                            a set of hidden mechanisms instantly activating, metal bindings snapping the lizard's arms and legs into place.
                            She struggles against them, but fails to free herself.
                        [/p]
                        [p]
                            Right as you are about to ask what the [b]hell[/b] is going on here,
                            the canine roughly [b]grabs[/b] you by the back of your neck,
                            crudely bringing you to your knees in between the female kobold's forcibly spread legs.
                            You barely manage to utter a protest before she shoves your face into the lizard's feminine loins.
                            "[color=orange]Be a good ${dick ? `boy` : `girl`} and [b]lick[/b] for me, okay?
                            Get her nice and [b]ready[/b].
                            It'll all make sense soon.[/color]"
                        [/p]
                        [p]
                            Lick?!
                            [b]Hell no![/b]
                            The pink kobold was clearly [b]not[/b] okay with what is happening here!
                            And neither are you!
                            You struggle against Cassidy's grasp, but she firmly keeps you in place, using just one of her hands.
                            With the other, she manipulates the plunger of the syringe she'd fetched earlier,
                            drawing liquid from an ominously looking bottle.
                        [/p]
                        [p]
                            As your squirming intensifies, the vixen suddenly [b]stabs[/b] the needle of the syringe into your arm, injecting your with its contents.
                            You yelp out in pain.
                            ${dick ? `You start to feel [b]hot[/b] and [b]flushed[/b].
                            You begin to pant, not from exertion, but from [b]arousal[/b].
                            Your member rapidly hardens, emerging from your cockslit.` : `Instantly,
                            your breasts recede into your chest completely, your bosom flattened.
                            Your ovaries [b]painfully[/b] wither, instead replaced by fully-formed internal [b]testicles[/b].
                            Your cervix grows shut, your clit vanishes completely, and a small, tapered, koboldic cock springs forth inside of you.
                            [b]You are now a boy[/b].
                            Worse yet, you feel [b]hot[/b] and [b]flushed[/b].
                            You begin to pant, not from exertion, but from [b]arousal[/b].
                            Your small, brand new member rapidly hardens, emerging from your cunt-turned-cockslit.`}
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            An intense [b]need[/b] to [b]breed[/b] builds up inside of you.
                            You greedily begin to [b]huff[/b] the female pheromones wafting from the slit in front of your face.
                            It smells [b]so[/b] good.
                            You need [b]more[/b].
                            "[color=orange]There you go.
                            Now you're getting into it.
                            Come on, now.
                            [b]Lick[/b].[/color]"
                        [/p]
                        [p]
                            An [b]excellent[/b] suggestion.
                            One you can't possibly resist.
                            Driven by a mind of its own, your tongue snakes out of your mouth,
                            outright [b]lapping[/b] at the pink kobold's folds, [b]tasting[/b] her feminine flavor.
                            It's not nearly enough to quell your burning desires.
                            Cassidy lets go of your neck.
                            You're not going anywhere.
                            The girl squirms as much as her restrains will allow.
                            As you begin to [b]eat her out[/b] properly, she [b]cries[/b] for help, only to be quickly silenced by the vixen.
                            "[color=orange]Good boy.
                            Don't worry, she'll end up liking this as much as you will, eventually.
                            Now on your feet, my precious new [b]breeder[/b].
                            [b]Mount the bitch.[/b][/color]"
                        [/p]
                        [p]
                            Like a mindless husk, you do exactly as your mistress tells you.
                            You retract your tongue from the pink kobold's folds.
                            Despite being unwilling, her wetness stains the front of your muzzle.
                            Its rich scent and lingering, bittersweet taste spurs you on further.
                            You rise to your feet and lean over her.
                            Positioning the tapered tip of your throbbing ${dick ? `` : `new`} member in between her legs,
                            you [b]ram[/b] your hips forwards, spreading her folds, firmly lodging your cock inside of her.
                        [/p]
                        [p]
                            The kobold's struggles intensify.
                            A few drops of blood ooze from her slit.
                            A virgin?
                            Not anymore.
                            She screams out in desperation and in pain, but her frantic pleas are muffled by Cassidy's furred hands.
                            The vixen doesn't even need to tell you to get started.
                            Your hips move on their own, rapidly pistoning your member in and out of the lizard's overly-tight cunt,
                            your green scales loudly slapping against her pink ones as you [b]hump[/b] away to your heart's content.
                        [/p]
                        [p]
                            Your need intensifies.
                            Your tongue lolls out of your mouth obscenely.
                            You can already feel your end approaching.
                            You grip onto the kobold's shoulders, fucking her [b]harder[/b] and [b]faster[/b],
                            [b]pounding[/b] her against the table with [b]all[/b] of your might, like a possessed [b]animal[/b].
                            Then, barely a minute after the intense [b]rutting[/b] began,
                            you [b]force[/b] your length in as deep as it'll go, one final time.
                            With a loud [b]grunt[/b], you reach your end,
                            your ${dick ? `` : `freshly formed`} internal balls pumping out wave after wave of spunk deep inside of your reluctant [b]bitch[/b],
                            thoroughly [b]breeding[/b] her.
                        [/p]
                        [p]
                            Your cock hardens again mere seconds after finishing.
                            Overtaken by aphrodisiac, your mind goes blank, and you continue to fuck the pink kobold for [b]hours[/b] on end,
                            dumping more loads inside of her than you can [b]count[/b].
                            Cassidy doesn't even bother to stay present all the time.
                            She fetches tea, does household chores and tends to her other [i]pets[/i].
                            At the end of the day, once you're fully spent, she guides you to one of the corrals,
                            where you drift to sleep after masturbating once or twice more.                            
                        [/p]
                        [p]
                            Everything from thereonout is a blur.
                            You get administered more drugs on a daily basis,
                            keeping you in a constant rutting-high,
                            driven by nothing but your desire to plant your seed inside of a fertile womb,
                            or [b]any[/b] hole tight enough to squeeze an orgasm out of you.
                        [/p]
                        [p]
                            You spend [b]days[/b] fucking the other kobolds in your pen.
                            Males, females, you don't care.
                            Sometimes you return the favor, and get them off as well.
                            Other times, you pump them full and leave them hanging until they [b]beg[/b] for release.
                            You find that works especially well on the ones that are chained up for their [b]bad behavior[/b].
                            Your member steadily growing due to the constant influx of various potions, you establish yourself as your pen's [b]alpha male[/b].
                        [/p]
                        [p]
                            Some of the other kobolds are reluctant to let you fuck them.
                            They don't want to be here.
                            They [b]beg[/b] you not to fuck them.
                            A few even snarl or claw at you.
                            After [b]hours[/b] of insisting, [b]all[/b] of them eventually cave.
                            If they don't, you wait until they go to sleep, and then [b]force[/b] yourself upon them.
                            None have the audacity to strike you, fearing the mistress' reprisal.
                            The last one who dared to start a fight got taken to the [b]butcher[/b].
                        [/p]
                        [p]
                            It isn't long until Cassidy starts taking a liking to you.
                            You become her [b]favorite[/b] pet.
                            You get better food than the rest, the privilege of roaming around at your own leisure instead of being confined to any one corral,
                            and the first go at breaking in fresh virgins.
                            Eventually, you even get to fuck the vixen herself.
                            At first, in the barn.
                            Then in her house.
                            After nearly a month of fucking her brains out daily, she invites you to her bedroom.
                        [/p]
                        [p]
                            A week later, she lets you sleep in bed with her,
                            instead of sending you back to the barn after sating her needs.
                            You cuddle up tightly against her warm fur, your spent member dribbling cum onto her back.
                            She rolls around to face you, lovingly kisses you on the head, and then embraces you like a lover would.
                            Finally, for the first time in years, you are truly happy.
                            With your scaly muzzle nestled snugly in between her firm breasts, the both of you slowly drift to sleep.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    Bull end.
                                [/b]
                            [/c]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" style="margin-left: auto; position: relative; float: right;" id="${continueId}">`;
        choice += `&lt;&lt Revert`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400, function () {
            var main = $("#main");
            main.scrollTop(main[0].scrollHeight - main.height() - 5); // Fix scrolling
        });
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.result.unset();
            for (var i = 0; i < idsToRemove.length; i++) {
                $("#" + idsToRemove[i]).remove();
            }
            loadNextPart(ctrl.fragments.results);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoVixen.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoNobody.js

/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoNobody(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.NOBODY;
    var reqController = ctrl.result;
    var changeController = ctrl.nobody;

    var nextSceneReady = ctrl.nextSceneReady;
    var nextSceneName = ctrl.nextSceneName;
    var nextFolderName = ctrl.nextFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Nobody buys the kobold. Gloomy mood. Get shoved back into cart.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoNobody.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoSeki.js

/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoSeki(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoResultsChoice.SEKI;
    var reqController = ctrl.result;
    var changeController = ctrl.seki;

    var nextSceneReady = ctrl.sekiSceneReady;
    var nextSceneName = ctrl.sekiSceneName;
    var nextFolderName = ctrl.sekiFolderName;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.boughtBySeki = true;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            "[color=orange]One hundred.[/color]" a gentle, feminine voice rings out.
                            It's the half-naked vixen.
                            She's soon challenged by the goblin, whose stingy pockets seem far deeper than what you'd have imagined.
                            "[color=green]One hundred and twenty![/color]"
                            The kind-looking canine casts a wicked leer towards the small humanoid.
                            "[color=orange]One hundred and fifty. Or would you rather deal with a back-handed [b]greenskin[/b]?[/color]"
                            "[color=green][b]One fifty-one[/b]![/color]"
                        [/p]
                        [p]
                            Bartholomew seems conflicted.
                            For a moment, it feels as though a [b]fight[/b] is brewing between the two interested parties.
                            But then, right as temperatures are about to reach a boiling point, you cry out for your avian friend in the distance,
                            drawing attention from your captors and both the interested parties, effectively [b]defusing[/b] the situation.
                            The owl's head turns towards you.
                            His eyes go wide.
                            As fast as his old legs can carry him, he rushes over to the crowd.
                        [/p]
                        [p]
                            [color=brown][big][b]THREE HUNDRED![/b][/big][/color]
                        [/p]
                        [p]
                            Seki's voice [b]booms[/b] over the rest of the crowd, although he bursts into a coughing fit at the end of his shout.
                            "[color=gblue]Sold to the senile bird![/color]" Fenrir instantly jumps in.
                            The goblin and the vixen both grumble and complain, but the wolf's decision is final.
                            The crowd parts and money exchanges hands.
                        [/p]
                        [p]
                            While Barto attempts to chat with Seki, your avian protector seems more interested in getting you the hell out of there.
                            The elderly man held up for a few minutes out of sheer courtesy, Fenrir approaches you.
                            "[color=gblue]Well, ${name}, you're his now.
                            Next time we meet, you can thank me for not letting that [b]filthy[/b] goblin have you.
                            He'd have matched the old coot's offer if I hadn't stepped in, you know.
                            Either way, good luck out there.
                            You're going to need it.[/color]"
                        [/p]
                        [p]
                            Having said his farewells, the big wolf pushes you forwards, nudging you off of the small stage, towards your new [i]master[/i].
                            The deal concluded, the human and the lupine walk back to the carriages, bickering on how to split their profits.
                            Your old friend approaches you, leaning down to closely inspect your body.
                            "[color=brown]Thank goodness, you're not hurt. You [b]scared[/b] me, ${name}.[/color]"
                            Bringing a key to your neck, he takes off your slave collar, and angrily hurls it down the well.
                            "[color=brown]A money transport?
                            I thought I taught you better!
                            [b]Never[/b] go after high-profile targets![/color]"
                        [/p]
                        [p]
                            Noticing the prying eyes of a few lingering locals, Seki quite literally takes you under his wing.
                            [color=brown]Come now.
                            We'll talk more once we get inside.[/color]"
                            Those words said, the two of you walk towards his workshop, just a few steps away.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(nextSceneName, nextFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        if (!nextSceneReady) {
            part += `<span class="todo">There is no content beyond this point.</span>`;
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        if (nextSceneReady) {
            registerContinueListener();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoSeki.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoResults.js

/**
 * Result section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoResults(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preResult;
    var subController = ctrl.result;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";

    var firstNext = new SlaveNoonTwoNobody(ctrl);
    var secondNext = new SlaveNoonTwoSeki(ctrl);
    var thirdNext = new SlaveNoonTwoFarmer(ctrl);
    var fourthNext = new SlaveNoonTwoVixen(ctrl);

    var firstChoice = SlaveNoonTwoResultsChoice.NOBODY;
    var secondChoice = SlaveNoonTwoResultsChoice.SEKI;
    var thirdChoice = SlaveNoonTwoResultsChoice.FARMER;
    var fourthChoice = SlaveNoonTwoResultsChoice.VIXEN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        if (!ctrl.resultComplianceStorage.has()) {
            ctrl.resultComplianceStorage.set(
                    global.kobold.history.shared.enslavement.totalComplianceRating()
                    + ctrl.resultBodyMisc.boobs()
                    - ctrl.resultBodyMisc.dick());
        }

        var bartoOnStage = ctrl.stage.get() === SlaveNoonTwoStageChoice.REFUSE;

        var toReturn = `[p]
                            ${bartoOnStage ? `The caravan master hops off the stage.` : ``}
                            The bidding begins, at a price obviously [b]far[/b] too low according to Bartholomew.
                            "[color=purple]Ten coins![/color]" one of the horses offers.
                            "[color=green]Fifteen![/color]" the goblin counters.
                            "[color=purple]Oh yeah? Well...[/color]" reaching into his pocket, one of the equines produces an extra pair of shiny coins.
                            "[color=purple][b]Seventeen![/b][/color]" he proudly exlaims.
                            The goblin grumbles.
                            "[color=green]Twenty![/color]" comes his offer.
                        [/p]
                        [p]
                            Barto sighs.
                            Realizing this is going [b]nowhere[/b] fast,
                            the human puts an end to the [i]paltry[/i] bidding war.
                            "[color=brown][b]Serious[/b] offers [b]only[/b]!
                            Bidding starts at [b]fifty[/b] gold, and not a coin less.[/color]"
                            His bold statement immediately puts a damper on the crowd's enthusiasm.
                            Still, more than a few of the people gathered are still [b]very[/b] interested in [i]acquiring[/i] a kobold slave of their own.
                        [/p]
                        [p]
                            Right as you thought all hope was lost, a door opens at the far end of the hamlet.
                            It's [b]Seki[/b], emerging from his workshop!
                            He doesn't seem to pay the gathering around the stage any mind.
                            He never was one to support slavery.
                            If you can draw his attention, he [i]might[/i] be able to rescue you!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        disabled = "disabled";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 190px;">Nobody</button>`;

        var tooltip = global.parser.parse(`The caravan master's not going to like this. [todo]Unavailable[/todo]`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var fail = ctrl.gag.get();
        var disabled = subController.has() || fail ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 190px;">Seki</button>`;

        var tooltip = global.parser.parse(`Call out to the elderly bird.`);
        if (fail) {
            tooltip = global.parser.parse(`You are gagged, and can not call for help.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, `width: 1${fail ? `6` : `9`}0px;`);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var succeed = ctrl.resultComplianceStorage.get() > 15;
        var disabled = subController.has() || !succeed ? "disabled" : "";
        disabled = "disabled";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 190px;">A farmer</button>`;

        var tooltip = global.parser.parse(`The farmer's son looks fit to nag his father until he relents to buying you. [todo]Unavailable[/todo]`);
        if (!succeed) {
            tooltip = global.parser.parse(`The farmer is looking for a good girl. You don't interest him a lot.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var succeed = ctrl.resultComplianceStorage.get() < 8;
        var disabled = subController.has() || !succeed ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 190px;">The vixen</button>`;

        var tooltip = global.parser.parse(`That female fox has a wicked grin on her face. You don't like it one bit.`);
        if (!succeed) {
            tooltip = global.parser.parse(`The female fox is looking for a bad boy. You don't interest her a lot.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, `width: 1${succeed ? `6` : `7`}0px;`);
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You are bought by:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildThirdChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFourthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
    };
}

var SlaveNoonTwoResultsChoice = {
    NOBODY: 1,
    SEKI: 2,
    FARMER: 3,
    VIXEN: 4
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\results\SlaveNoonTwoResults.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoPose.js

/**
 * Stage section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoPose(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoStageChoice.POSE;
    var reqController = ctrl.stage;
    var subController = ctrl.preResult;
    var changeController = ctrl.pose;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.results;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.stagePosed = true;
        var breasts = ctrl.misc.boobs();
        var injected = ctrl.gag.has();
        var analVirgin = ctrl.misc.analVirgin();
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            Smile?
                            You can do better than that.
                            Time to give these people a show.
                        [/p]
                        [p]
                            First, you lean forwards, and wink to your audience,
                            ${breasts ? `using both your hands to push your breasts together, ` : ``}
                            opening your mouth as wide as it'll go,
                            ${injected ? `[b]proudly[/b] showcasing your
                            ${global.kobold.inventory.createItemWithTooltip(new UnderwearGag(), true)}.` : `
                            showcasing how long your tapered tongue is by lolling it out obscenely.`}
                            ${injected ? `A mixed response from the crowd.` : `The crowd seems to [b]love[/b] it, especially the young bird boy.`}
                            That's not the only trick you have up your sleeve.
                        [/p]
                        [p]
                            Time to bring out the big guns.
                            Turning around, you lewdly bend over, lifting your tail up high, exposing your hindquarters to your potential [i]buyers[/i].
                            As if that wasn't enough, you spread your buttcheeks using your hands,
                            giving [b]everyone[/b] a good look at your ${analVirgin ? `virginal ass` : `recently fucked ass`}.
                            To entice the crowd further, you teasingly run a trace a single finger along the length of your ${dick ? `cock` : ``}slit.
                        [/p]
                        [p]
                            Turning to face your onlookers once more,
                            you decide to give them one [b]final[/b] gesture,
                            to push them over the edge, to [b]ensure[/b] you'll be [b]bought[/b].
                            You grab your tail, and suggestively stroke your hand along its tip.
                            The teenaged avian in the audience can [b]barely[/b] refrain from touching himself at the sight,
                            his human mother scolding him with a quick slap to the back of his head.
                            You'd like to think you did well.
                            At least the caravan master can't say you didn't try.
                            He [b]looks[/b] pleased, at least.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoPose.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoRefuse.js

/**
 * Stage section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoStageChoice.REFUSE;
    var reqController = ctrl.stage;
    var subController = ctrl.preResult;
    var changeController = ctrl.refuse;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.results;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Smile?
                            Hell no.
                            You have [b]no[/b] reason whatsoever to smile.
                            You have been [b]enslaved[/b] and are now being [b]sold[/b] to the highest bidder like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Instead of smiling, you cast an angry glare towards Bartholomew.
                            The human doesn't appreciate your lack of cooperation.
                            His rage just about boiling over, he strides atop the wooden stage,
                            and before you even know what's going on,
                            he roughly [b]grabs[/b] you by your throat,
                            squeezing your windpipe shut while lifting you up high enough to come face-to-face with him.
                        [/p]
                        [p]
                            "[color=brown][b]Normally,[/b][/color]" the human speaks, addressing the crowd without looking at them,
                            glaring into your eyes with an intense look of pure [b]hatred[/b] on his face.
                            "[color=brown]I'd beat the [b]shit[/b] out of this little [b]cretin[/b] for disobeying me.[/color]"
                            You squirm around in Barto's grasp, running slightly low on air, weakly batting at his arm to [b]let go[/b].
                            "[color=brown]But, today, I'll leave that pleasure to [b]you[/b], the people.[/color]"
                            With his free hand, he points towards the crowd to accentuate his speech.
                        [/p]
                        [p]
                            Then, his hand curls into a fist, one which he [b]painfully[/b] rams into your gut with all of his might,
                            knocking what little air remained out of your lungs, while simultaneously letting go of your throat,
                            letting you drop down to the ground.
                            Your legs unable to carry you, you crumple to the floor, curling up into a tiny little ball,
                            clutching your battered stomach.
                            It [b]hurts[/b].
                            The crowd [b]laughs[/b].
                            Your pain is their [b]amusement[/b].
                            You burst out into tears.
                        [/p]
                        [p]
                            [big][color=brown][b]On your feet, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The caravan master rears his foot backwards, threatening to [b]kick[/b] you lest you comply with his demand.
                            Fearing more [b]beatings[/b], you fearfully scramble to your feet,
                            visibly shaken from the human's sudden outburst of anger.
                            "[color=brown]See? If you [b]hurt[/b] it enough, it'll start listening [b]eventually[/b].
                            And if not, you'll have had the pleasure of killing a [b]criminal[/b].[/color]"
                            More crude laughter.
                            More tears.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoRefuse.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoSmile.js

/**
 * Stage section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoSmile(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoStageChoice.SMILE;
    var reqController = ctrl.stage;
    var subController = ctrl.preResult;
    var changeController = ctrl.smile;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.results;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.stageSmiled = true;
        var injected = ctrl.gag.has();
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var toReturn = `[p]
                            Smile?
                            For these [i]oafs[/i] that, after having been riled up by Bartholomew, pretty much want you [b]dead[/b]?
                            ${eager ? `Well, it would probably make Fenrir happy` : `Well, it [b]will[/b] up your odds of being [i]sold[/i]`},
                            and showing off how [i]nice[/i] you are [b]might[/b] make whoever ends up buying you just a little bit less inclined to [b]cave your head in[/b].
                            If you [b]really[/b] have to, out of sheer self-preservation, you think you [i]might[/i] be able to force out a weak happy look.
                        [/p]
                        [p]
                            ${injected ? `Even with the hefty gag in your mouth,
                            you still manage to form something remotely managing a smile.` : `Slowly, a small, obviously forced smile forms on your face.`}
                            In order to [i]accentuate[/i] your [i]happiness[/i] further, you form the fingers of both your hands into peace signs.
                            "[color=brown]You see?
                            Totally compliant![/color]"
                            Bartholomew comments, the onlookers nodding contently, some more pleased than others.
                            The father of the family with the avian son, in particular, seems happy with your actions.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\actions\SlaveNoonTwoSmile.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\SlaveNoonTwoStage.js

/**
 * Stage section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoStage(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preStage;
    var subController = ctrl.stage;
    var changeController = ctrl.stage;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new SlaveNoonTwoRefuse(ctrl);
    var secondNext = new SlaveNoonTwoSmile(ctrl);
    var thirdNext = new SlaveNoonTwoPose(ctrl);

    var firstChoice = SlaveNoonTwoStageChoice.REFUSE;
    var secondChoice = SlaveNoonTwoStageChoice.SMILE;
    var thirdChoice = SlaveNoonTwoStageChoice.POSE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var name = ctrl.misc.name();
        var dick = ctrl.misc.dick();
        var injected = ctrl.gag.has();
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var toReturn = `[p]
                            Seemingly directing his anger for the lupine towards you,
                            the caravan master grabs you by the collar, pulling you along as he strides towards the wooden stage.
                            You can only [b]barely[/b] keep up with his upset pace, but fortunately the podium isn't too far off.
                            "[color=brown]Come, people, gather 'round!
                            The main event is about to begin![/color]"
                            The human announces, addressing the people on the streets.
                            You have a [b]bad[/b] feeling about this.
                        [/p]
                        [p]
                            A small crowd slowly forms in front of the stage, numbering more than a dozen heads.
                            This must be at least half the people that live here, if not more!
                            No sign of Seki, though.
                            Most of them are talking amongst themselves, taking the occasion as a big social gathering,
                            which doesn't seem to amuse the already annoyed caravan master very much.
                            "[color=brown]Hear ye, hear ye!
                            [b]Settle down![/b]
                            [small]Filthy peasants.[/small][/color]"
                            That last part was naught but a whisper, one you [b]hope[/b] only [b]you[/b] heard, lest this [i]auction[/i] turns into a [b]lynching[/b].
                        [/p]
                        [p]
                            The mob slowly goes silent, their attention snagged by the authoratively dressed human and your naked frame besides him.
                            You shyly try to conceal your nudity by standing [i]behind[/i] the caravan master, but he [b]firmly[/b] yanks you back into place at his side.
                            Worse yet, as the [b]show[/b] is about to start, he crudely picks you up,
                            effortlessly lifts you off the ground, and practically [b]throws[/b] you on top of the wooden stage.
                            You quickly rise to your feet atop the podium, using your hands and your tail both to cover your [i]private parts[/i].
                        [/p]
                        [p]
                            With nowhere to run and nowhere to hide, you are at the mercy of the crowd's leering stares.
                            You can feel them [b]inspecting[/b] you, [b]judging[/b] you, estimating your worth in gold,
                            whispering to one another to comment on your [i]humble[/i] appearance, or to share how much they're willing to bid for your [b]body[/b].
                        [/p]
                        [p]
                            Amongst the onlookers, a few stick out the most.
                            There's a voluptuous vixen dressed in naught but a black shirt, a cowboy hat and some spurred, leather boots.
                            The blouse barely covers her loins.
                            You wonder if she's wearing anything [i]underneath[/i].
                            Next to her, there are a pair of muscular anthro horses.
                            Probably farmers.
                            They look like siblings.
                            Brothers or twins or something, maybe?
                            You don't know.
                            A lot of horses look alike to you.
                        [/p]
                        [p]
                            To the side, there stands an odd family.
                            A human mother and father, with a distinctly [b]avian[/b] son.
                            You don't know much about birds, but you think he's an [b]eagle[/b].
                            He looks kind of like one of Seki's relatives that you met a long time ago.
                            You briefly wonder how a bird and human could [i]mix[/i], but you decide not to linger on it for too long.
                            A final person of note, standing amidst a few of the more common farmers, is a single [b]goblin[/b].
                            You don't think he's from around here.
                            Behind the rabble, Fenrir is leaning slickly against the side of a building,
                            now dressed and eager to see the auction play out.
                        [/p]
                        [p]
                            With the crowd reduced to whispers, the caravan master begins to address them.
                            "[color=brown]I am [b]Bartholomew Grabgold[/b], royal tax collector,
                            appointed by the [b]king[/b] himself, currently serving the baron-regent.
                            But make no mistake, today I am [b]not[/b] here to [b]take[/b] your money.[/color]"
                            The chubby man chuckles, trying to lighten his own mood.
                            "[color=brown]That doesn't mean I intend to leave here empty-handed, though.[/color]"
                            A small, awkward pause.
                            The farmers don't seem to understand the joke.
                            Heck, you're not sure if [b]you[/b] get it.
                        [/p]
                        [p]
                            Disdain and frustration a bit more clear in his voice, [i]Bartholomew[/i] extends his arm towards you,
                            directing attention to your naked form before continuing.
                            "[color=brown]Today, I have come before you with a [b]slave[/b] to sell.
                            And not just [b]any[/b] slave.
                            You see, this kobold was [b]stupid[/b] enough to attempt to [b]steal[/b] from an imperial money transport.
                            It wanted to take gold to be used for the betterment of [b]all[/b] of mankind, to use for its own [b]selfish[/b] needs.[/color]"
                            You can almost [b]feel[/b] the crowd grow more [i]hostile[/i] towards you.
                        [/p]
                        [p]
                            "[color=brown]Not the smartest thing, is it?
                            Don't worry, the dumb lizard can still be used for simple, menial labor.
                            But you shouldn't buy this slave only to make it clean your house or work the fields.
                            No, instead, you should spend your coin on little ${name} here to [b]punish[/b] ${dick ? `him` : `her`}.
                            To make an [b]example[/b] out of ${dick ? `him` : `her`}.
                            To show ${dick ? `him` : `her`}, and indeed, [b]all[/b] kobolds,
                            that [b]any[/b] transgressions against their [b]superiors[/b] is a one-way ticket to [b]hell[/b] on earth.[/color]"
                        [/p]
                        [p]
                            The human has the crowd eating out of his hand.
                            Still, these people are but simple farmers.
                            You doubt many -- if any -- of them have the [b]means[/b] to [i]buy[/i] you.
                            Being relatively [i]poor[/i], surely they won't spend a bunch of money only to [b]torture[/b] or outright [b]kill[/b] you, would they?
                        [/p]
                        [p]
                            "[color=brown]${injected ? `As you can tell by the gag in its mouth, this lizard is ill-mannered and plain-out [b]rude[/b].
                            Buy it to teach it a [b]lesson[/b].
                            Whip it until it passed out.
                            ${fucked ? `Make it wish it was never even born.` : `Take its virginity.`}
                            Fuck it until it can no longer walk.
                            Break all of its limbs, and then slice its throat.
                            Make it [b]suffer[/b] until its very last breath.
                            ` : `While not the sharpest tool in the shed, this lizard has proven to be a bit more [b]cooperative[/b] than the others.
                            Perfect for all you [b]lonely men[/b] out there.
                            I can't ensure it won't [b]bite[/b], but there's two other holes for you to [b]fuck[/b] if you don't want to risk it.
                            Or you can pull out its teeth for maximum security.
                            ${fucked ? `One of its holes might still be virginal.
                            Find out which one after the auction.` : `Did I mention it's a virgin?
                            [b]Extra tight[/b] on the first go-around.
                            Guaranteed to be a [i]suitable[/i] fit for even a child.
                            A perfect gift for your firstborn son.`}`}[/color]"
                        [/p]
                        [p]
                            The crowd seems [b]very[/b] enticed.
                            [b]Barto[/b] appears to have a silver tongue when it comes to selling things.
                            His audience excited, the human turns to you.
                            "[color=brown][b]Smile, slave![/b][/color]" comes the simple command.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Refuse</button>`;

        var tooltip = global.parser.parse(`You aren't happy. Why would you pretend to be?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Smile</button>`;

        var tooltip = global.parser.parse(`You don't want to get hurt. Do as he says.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Pose</button>`;

        var tooltip = global.parser.parse(`Go above and beyond what is requested of you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var SlaveNoonTwoStageChoice = {
    REFUSE: 1,
    SMILE: 2,
    POSE: 3
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\stage\SlaveNoonTwoStage.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuseGood.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideRefuseGood(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.refuseGood;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.goodRefuse = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            Do you really have to wash up in the [b]middle[/b] of the hamlet, with all these people watching?
                            In a shallow [b]trough[/b] used by beasts of burden to slake their thirst?
                            You ${injected ? `sigh internally` : `let out another sigh`}.
                            You'd rather have some [b]privacy[/b] and the comfort of [b]running[/b] or at least [b]fresh[/b] water,
                            instead of this stale puddle of [b]animal spit[/b].
                        [/p]
                        [p]
                            It may be too late for the two of you to head for the river,
                            but that doesn't mean you're going to [b]wallow[/b] in animal grool for the bandit's amusement.
                            ${fucked ? `${eager ? `You wear Fenrir's dried spunk with pride,
                            and you don't want it washed off.` : `While you're eager to rid yourself of Fenrir's dried spunk,
                            you're not going to degrade yourself to wash it off.`}` : `It would be nice to wash off all the dirt from the chase,
                            but you're not going to degrade yourself for it.`}
                            Besides, it's a watering trough.
                            If you clean yourself in it, where will all the animals drink from?
                            Plus, your captor said the auction was starting soon.
                            You won't be able to dry yourself in time if you [i]take a dip[/i].
                        [/p]
                        [p]
                            Tilting your head upwards, you meet the wolf's determined gaze with a resolute stare of your own.
                            Your nerves steeled, you ${injected ? `firmly shake your head no` : `boldly refuse his request for you to bathe`}.
                            "[color=gblue]We [b]don't[/b] have time for this.
                            [b]Get in the tub.[/b][/color]"
                            Like a young child refusing to take an order from its parents, you hold your ground, stubbornly denying the canine.
                            Fenrir lets out an exasperated groan.
                            "[color=gblue]Listen, I'm not going to force you to wash up.
                            The caravan master's going to be [b]pissed[/b] that you're still covered in ${fucked ? `jizz` : `dirt`}, but so be it.
                            I'll take the flak for you this [b]one[/b] time, just because I like you.
                            [b]Don't[/b] get used to-[/color]"
                            Suddenly, a booming voice interrupts the bandit.
                        [/p]
                        [p]
                            [big][color=brown][b]Fenrir!![/b][/color][/big]
                        [/p]
                        [p]
                            It's the caravan master!
                            He's approaching the two of you rapidly.
                            "[color=brown]What the [b]hell[/b] are you doing, standing around?!
                            I thought I told you to get the slave cleaned?![/color]"
                            The chubby man walks up to the wolf.
                            Despite the lupine being nearly an entire foot taller,
                            the human assumes a crude, threatening posture, as if looking for a fight.
                            You [i]want[/i] to come between the two to explain what happened, yet you fail to find the courage to do so.
                            ${injected ? `Besides, you can't speak through your ${global.kobold.inventory.createItemWithTooltip(new UnderwearGag())}` : ``}
                        [/p]
                        [p]
                            "[color=gblue]Kobold's clean enough to be sold.
                            Now [b]back off[/b].[/color]"
                            Your captor's calm, collected response only serves to anger his [sneak]temporary[/sneak] superior further.
                            "[color=brown]Back off?!
                            I asked [b]one[/b] simple thing of you!
                            But then again, you couldn't even guard the transport in the first place![/color]"
                        [/p]
                        [p]
                            The wolf tries, but fails to come up with an apt response.
                            Sighing discontently, he submissively takes a step backwards.
                            For a moment there, you thought this was going to end in a fight.
                            "[color=brown]That's right.
                            Know your place, [b]mutt[/b].
                            Now quit acting like the [b]animal[/b] you are, and go get dressed.[/color]"
                            After an intense stare-down, Fenrir finally turns around.
                            Audibly grumbling, he begins to make his way back to the wagons, leaving you alone with the human, who harrumphs angrily.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuseGood.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuseBad.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideRefuseBad(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.refuseBad;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.badRefuse = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            Do you really have to wash up in the [b]middle[/b] of the hamlet, with all these people watching?
                            In a shallow [b]trough[/b] used by beasts of burden to slake their thirst?
                            You ${injected ? `sigh internally` : `let out another sigh`}.
                            You'd rather have some [b]privacy[/b] and the comfort of [b]running[/b] or at least [b]fresh[/b] water,
                            instead of this stale puddle of [b]animal spit[/b].
                        [/p]
                        [p]
                            It may be too late for the two of you to head for the river,
                            but that doesn't mean you're going to [b]wallow[/b] in animal grool for the bandit's amusement.
                            ${fucked ? `${eager ? `You wear Fenrir's dried spunk with pride,
                            and you don't want it washed off.` : `While you're eager to rid yourself of Fenrir's dried spunk,
                            you're not going to degrade yourself to wash it off.`}` : `It would be nice to wash off all the dirt from the chase,
                            but you're not going to degrade yourself for it.`}
                            Besides, it's a watering trough.
                            If you clean yourself in it, where will all the animals drink from?
                            Plus, your captor said the auction was starting soon.
                            You won't be able to dry yourself in time if you [i]take a dip[/i].
                        [/p]
                        [p]
                            Tilting your head upwards, you meet the wolf's determined gaze with a resolute stare of your own.
                            Your nerves steeled, you ${injected ? `firmly shake your head no` : `boldly refuse his request for you to bathe`}.
                            "[color=gblue]We [b]don't[/b] have time for this.
                            [b]Get in the tub.[/b][/color]"
                            Like a young child refusing to take an order from its parents, you hold your ground, stubbornly denying the canine.
                            Fenrir's growing angry.
                            He bares his fangs, growling loudly.
                            "[color=gblue]Get [b]the fuck[/b] in, ${name}.
                            Final warning.[/color]"
                        [/p]
                        [p]
                            The wolf's furred hand slowly raises up high, poised to [b]strike[/b].
                            Not just a slap, either.
                            His claws are fully extended.
                            You are more than a little intimidated, but you don't back down.
                            You drop into a combat stance, bracing yourself for his strike.
                            He's bluffing.
                            He won't hit you.
                            Will he?
                            Suddenly, a booming voice interrupts your impending fight.
                        [/p]
                        [p]
                            [big][color=brown][b]Fenrir!![/b][/color][/big]
                        [/p]
                        [p]
                            It's the caravan master!
                            He's approaching the two of you rapidly.
                            "[color=brown]What the [b]hell[/b] are you doing?![/color]"
                            The chubby human crudely pushes the wolf away, stepping in between the two of you.
                            You immediately snap out of your combat stance, bringing out your best [i]puppy eyes[/i] to look as [b]innocent[/b] as possible.
                            "[color=gblue]Get out of my way, human.[/color]"
                            Your captor's response only serves to anger his [sneak]temporary[/sneak] superior further.
                            "[color=brown]Get out of your way?!
                            Half the bloody village is watching!
                            We're trying to [b]sell[/b] to these people,
                            and you [b]threatening[/b] our [i]merchandise[/i] in front of them [b]isn't[/b] helping.[/color]"
                        [/p]
                        [p]
                            The wolf tries, but fails to come up with an apt response.
                            Sighing discontently, he shifts out of his threatening posture.
                            For a moment there, you thought he was going to hit the caravan master.
                            "[color=brown]That's more like it.
                            Now quit acting like the [b]animal[/b] you are, and go get dressed.[/color]"
                            After an intense stare-down, Fenrir finally backs off.
                            Audibly grumbling, he begins to make his way back to the wagons, leaving you alone with the human, who harrumphs angrily.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuseBad.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuse.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOutsideChoice.REFUSE;
    var reqController = ctrl.outside;

    var toFail = new SlaveNoonTwoOutsideRefuseBad(ctrl);
    var toSuccess = new SlaveNoonTwoOutsideRefuseGood(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        if (!ctrl.outsideComplianceStorage.has()) {
            ctrl.outsideComplianceStorage.set(global.kobold.history.shared.enslavement.totalComplianceRating());
        }
        return ctrl.outsideComplianceStorage.get() > 8;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\refuse\SlaveNoonTwoOutsideRefuse.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrinkGood.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideDrinkGood(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.drinkGood;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.goodDrink = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Washing up is the last thing on your mind right now.
                            If anything, the sight of nourishing liquid reminds you that your throat is [b]parched[/b].
                            You haven't had a drink since long before stealing from the money transport yesterday.
                            Since then, you've ran, you've hidden,
                            then you ran some more${fucked ? `, got fucked` : ``},
                            spent the night imprisoned${kissedBalls ? `, kissed the wolf's dry balls` : ``}${injected ? `, got the wolf's dry underwear shoved into your mouth` : ``}
                            and all of this without a single drop of water.
                            No wonder you woke up with a headache.
                            You're dehydrated to heck and back.
                        [/p]
                        [p]
                            Even as thirsty as you are, the water before you looks unappetizing.
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            You'd have had something [b]fresh[/b] to drink in relative [b]privacy[/b],
                            instead of being forced to lap stale [b]slobber[/b] from a trough in public.
                        [/p]
                        [p]
                            Still, you [b]need[/b] something, [b]anything[/b] to drink.
                            However disgusting the liquid may be, it'll have to do.
                            You drop to your knees, the foul scent of feral horse spit only now reaching your nose fully.
                            It [b]stinks[/b].
                            Gross!
                            Are you [b]really[/b] going to do this?
                        [/p]
                        [p]
                            Yes.
                            Yes you are.
                            You feel like you'll [b]die[/b] if you don't get any moisture in you.
                            Under Fenrir's watchful eye,
                            you lower your head into the trough, hovering your muzzle directly above the water's surface.
                            The [b]stench[/b] is nearly unbearable.
                            Out of [b]necessity[/b],
                            you snake your tongue out of your mouth,
                            ${injected ? `scraping the prehensile appendage against the underwear in your mouth in the process,` : ``}
                            and lap at the fetid fluid that was once water.
                        [/p]`;

        if (injected) {
            toReturn += `[p]
                            It's [b]thick[/b].
                            It's [b]warm[/b].
                            It's not even anything [b]remotely[/b] like water.
                            The top layer of the trough, in which your tongue dipped, is pure, fresh [b]equine saliva[/b].
                            You retch even [b]before[/b] you manage to get the slimey goop into your mouth.
                            Worse yet, as your tongue retracts into your muzzle, it [b]soaks[/b] into your underwear-gag,
                            washing out an entire new [b]wave[/b] of dirt and filth concealed within the fabric,
                            the horrid taste of animal drool overshadowed by the absolutely [b]abhorrent[/b] flavor of wolf groin-grime.
                        [/p]
                        [p]
                            Your stomach churns, barely able to hold its contents.
                            But you're not nearly done.
                            Despite being outright [b]sickening[/b] in flavor, a lot warmer and far more [b]viscous[/b] than you would have liked,
                            the slop you licked up [i]did[/i] end up [b]refreshing[/b] the dry front-end of your mouth.
                            You need [b]more[/b].
                            However much it [b]revolts[/b] you,
                            you need to [b]keep licking[/b] until the underwear becomes so soaked that some much-needed liquid can make its way to your throat.
                        [/p]
                        [p]
                            Trying to think of [b]anything[/b] but the vomit-inducing taste of the feral spit,
                            you lap again and again at the layer of stale saliva,
                            taking more and more of it into your muzzle,
                            letting it [b]soak[/b] into the briefs lodged into the back of your mouth.
                            Once finally [b]saturated[/b] with packbeast-dribble,
                            you tilt your head backwards and bite down on the garment,
                            [b]squeezing[/b] the repulsive liquid from it,
                            letting the drool, along with more filth rinsed from the wolf's underwear,
                            ooze down your throat into your stomach.
                        [/p]
                        [p]
                            While it doesn't nearly manage to quench your thirst,
                            the lukewarm fluid sticks to your gums and to the walls of your esophagus,
                            slickening the back of your mouth, leaving a lingering, unpleasant yet somewhat [i]reinvigorating[/i] feeling.
                            At least the permeating [b]dryness[/b] onset by canine briefs is gone.
                            And, pleasantly enough, the underwear filters out most of the [i]fur[/i] and [i]grass[/i] contained within the goop.
                        [/p]
                        [p]
                            While still dehydrated, you doubt drinking more of the spittle will help.
                            You don't think you can [b]stomach[/b] any more of it, regardless.
                            Removing your head from the trough, you notice Fenrir staring at you with a disapproving gaze.
                        [/p]
                        [p]
                            "[color=gblue]If I wanted my underpants cleaned, I'd have taken you to the river instead.[/color]"
                            How ironic.
                            You cast a glare the canine's way.
                            "[color=gblue]Hey, now, I didn't force you to drink that stuff.
                            That's on [b]you[/b].[/color]"
                            He's right.
                            But that doesn't prevent you from being upset.
                            Suddenly, a voice rings throughout the hamlet, interrupting your uppity streak.
                        [/p]`;
        } else {
            toReturn += `[p]
                            It's [b]thick[/b].
                            It's [b]warm[/b].
                            It's not even anything [b]remotely[/b] like water.
                            The top layer of the trough, in which your tongue dipped, is pure [b]equine saliva[/b].
                            You retch even [b]before[/b] you manage to get the slimey goop into your mouth.
                            As your tongue retracts into your muzzle, the horrid taste of animal drool spreads throughout your mouth.
                            You swallow the stuff as quickly as you can, but the taste lingers.
                        [/p]
                        [p]
                            Your stomach churns, barely able to hold its fresh contents.
                            But you're not nearly done.
                            Despite being outright [b]sickening[/b] in flavor, a lot warmer and far more [b]viscous[/b] than you would have liked,
                            the slop you licked up [i]did[/i] end up [b]refreshing[/b] your dry mouth.
                            You need [b]more[/b].
                            However much it [b]revolts[/b] you,
                            you need to [b]keep drinking[/b] until you've taken in enough to survive.
                        [/p]
                        [p]
                            Trying to think of [b]anything[/b] but the vomit-inducing taste of the feral spit,
                            you lap again and again at the layer of stale saliva,
                            taking more and more of it into your muzzle,
                            letting it pool up before swallowing entire mouthfuls at a time.
                            You almost [b]throw up[/b] on the spot, as you accidentally lap up a clump of fur,
                            immediately followed by some chewed grass.
                            Luckily, you manage to refrain from vomiting,
                            as that would only serve to make the trough's contents even [b]less[/b] bearable to drink.
                        [/p]
                        [p]
                            While it doesn't nearly manage to quench your thirst,
                            the lukewarm fluid sticks to your gums and to the walls of your esophagus,
                            slickening your mouth, leaving a lingering, unpleasant yet somewhat [i]refreshing[/i] feeling.
                            You'll undoubtedly have bad breath for days to come.
                        [/p]
                        [p]
                            While still dehydrated, you doubt drinking more of the spittle will help.
                            You don't think you can [b]stomach[/b] any more of it, regardless.
                            Removing your head from the trough, you notice Fenrir staring at you with a disapproving gaze.
                        [/p]
                        [p]
                            "[color=gblue]You know, I'd have fetched some water from the well, if you'd asked.[/color]"
                            How ironic.
                            You cast a glare the canine's way.
                            "[color=gblue]Hey, now, I didn't force you to drink that stuff.
                            That's on [b]you[/b].[/color]"
                            He's right.
                            But that doesn't prevent you from being upset.
                            Suddenly, a voice rings throughout the hamlet, interrupting your uppity streak.
                        [/p]`;
        }

        toReturn += `   [p]
                            [big][color=brown][b]Fenrir!![/b][/color][/big]
                        [/p]
                        [p]
                            It's the caravan master!
                            He's approaching the two of you rapidly.
                            "[color=brown]What the [b]hell[/b] are you doing, standing around?!
                            I thought I told you to get the slave cleaned?![/color]"
                            The chubby man walks up to the wolf.
                            Despite the lupine being nearly an entire foot taller,
                            the human assumes a crude, threatening posture, as if looking for a fight.
                            You [i]want[/i] to come between the two to explain what happened, yet you fail to find the courage to do so.
                            ${injected ? `Besides, you can't speak through your ${global.kobold.inventory.createItemWithTooltip(new UnderwearGag())}` : ``}
                        [/p]
                        [p]
                            "[color=gblue]Kobold was thirsty.
                            Besides, it's clean enough to be sold.
                            Now [b]back off[/b].[/color]"
                            Your captor's calm, collected response only serves to anger his [sneak]temporary[/sneak] superior further.
                            "[color=brown]Back off?!
                            I asked [b]one[/b] simple thing of you!
                            But then again, you couldn't even guard the transport in the first place![/color]"
                        [/p]
                        [p]
                            The wolf tries, but fails to come up with an apt response.
                            Sighing discontently, he submissively takes a step backwards.
                            For a moment there, you thought this was going to end in a fight.
                            "[color=brown]That's right.
                            Know your place, [b]mutt[/b].
                            Now quit acting like the [b]animal[/b] you are, and go get dressed.[/color]"
                            After an intense stare-down, Fenrir finally turns around.
                            Audibly grumbling, he begins to make his way back to the wagons, leaving you alone with the human, who harrumphs angrily.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrinkGood.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrinkBad.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideDrinkBad(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.drinkBad;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.badDrink = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Washing up is the last thing on your mind right now.
                            If anything, the sight of nourishing liquid reminds you that your throat is [b]parched[/b].
                            You haven't had a drink since long before stealing from the money transport yesterday.
                            Since then, you've ran, you've hidden,
                            then you ran some more${fucked ? `, got fucked` : ``},
                            spent the night imprisoned${kissedBalls ? `, kissed the wolf's dry balls` : ``}${injected ? `, got the wolf's dry underwear shoved into your mouth` : ``}
                            and all of this without a single drop of water.
                            No wonder you woke up with a headache.
                            You're dehydrated to heck and back.
                        [/p]
                        [p]
                            Even as thirsty as you are, the water before you looks unappetizing.
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            You'd have had something [b]fresh[/b] to drink in relative [b]privacy[/b],
                            instead of being forced to lap stale [b]slobber[/b] from a trough in public.
                        [/p]
                        [p]
                            Still, you [b]need[/b] something, [b]anything[/b] to drink.
                            However disgusting the liquid may be, it'll have to do.
                            You drop to your knees, the foul scent of feral horse spit only now reaching your nose fully.
                            It [b]stinks[/b].
                            Gross!
                            Are you [b]really[/b] going to do this?
                        [/p]
                        [p]
                            Yes.
                            Yes you are.
                            You feel like you'll [b]die[/b] if you don't get any moisture in you.
                            Under Fenrir's watchful eye,
                            you lower your head into the trough, hovering your muzzle directly above the water's surface.
                            The [b]stench[/b] is nearly unbearable.
                            Out of [b]necessity[/b],
                            you snake your tongue out of your mouth,
                            ${injected ? `scraping the prehensile appendage against the underwear in your mouth in the process,` : ``}
                            and lap at the fetid fluid that was once water.
                        [/p]`;

        if (injected) {
            toReturn += `[p]
                            It's [b]thick[/b].
                            It's [b]warm[/b].
                            It's not even anything [b]remotely[/b] like water.
                            The top layer of the trough, in which your tongue dipped, is pure, fresh [b]equine saliva[/b].
                            You retch even [b]before[/b] you manage to get the slimey goop into your mouth.
                            Worse yet, as your tongue retracts into your muzzle, it [b]soaks[/b] into your underwear-gag,
                            washing out an entire new [b]wave[/b] of dirt and filth concealed within the fabric,
                            the horrid taste of animal drool overshadowed by the absolutely [b]abhorrent[/b] flavor of wolf groin-grime.
                        [/p]
                        [p]
                            Your stomach churns, barely able to hold its contents.
                            But you're not nearly done.
                            Despite being outright [b]sickening[/b] in flavor, a lot warmer and far more [b]viscous[/b] than you would have liked,
                            the slop you licked up [i]did[/i] end up [b]refreshing[/b] the dry front-end of your mouth.
                            You need [b]more[/b].
                            However much it [b]revolts[/b] you,
                            you need to [b]keep licking[/b] until the underwear becomes so soaked that some much-needed liquid can make its way to your throat.
                        [/p]
                        [p]
                            Trying to think of [b]anything[/b] but the vomit-inducing taste of the feral spit,
                            you lap again and again at the layer of stale saliva,
                            taking more and more of it into your muzzle,
                            letting it [b]soak[/b] into the briefs lodged into the back of your mouth.
                            Once finally [b]saturated[/b] with packbeast-dribble,
                            you tilt your head backwards and bite down on the garment,
                            [b]squeezing[/b] the repulsive liquid from it,
                            letting the drool, along with more filth rinsed from the wolf's underwear,
                            ooze down your throat into your stomach.
                        [/p]
                        [p]
                            While it doesn't nearly manage to quench your thirst,
                            the lukewarm fluid sticks to your gums and to the walls of your esophagus,
                            slickening the back of your mouth, leaving a lingering, unpleasant yet somewhat [i]reinvigorating[/i] feeling.
                            At least the permeating [b]dryness[/b] onset by canine briefs is gone.
                            And, pleasantly enough, the underwear filters out most of the [i]fur[/i] and [i]grass[/i] contained within the goop.
                        [/p]
                        [p]
                            You notice Fenrir shifting around behind you.
                            Before you even have a chance to pull back and see what's up,
                            he painfully [b]kicks[/b] your rear, sending you flying forwards into the trough.
                            Your head momentarily dips underwater, spit-laced goop [b]flooding[/b] into your open mouth.
                            Luckily, the lupine's underwear prevents you from swallowing most of the vile stuff.
                            You resurface, spitting out as much of it as you can,
                            before turning your attention towards your captor, casting an angry [b]glare[/b] at him.
                        [/p]
                        [p]
                            "[color=gblue]I told you to [b]wash up[/b], not to [b]drink[/b].
                            You can be glad that I chose to kick your ass instead of [b]crushing[/b] your head.
                            Next time you disobey me-[/color]"
                            Suddenly, a booming voice interrupts the bandit.
                        [/p]`;
        } else {
            toReturn += `[p]
                            It's [b]thick[/b].
                            It's [b]warm[/b].
                            It's not even anything [b]remotely[/b] like water.
                            The top layer of the trough, in which your tongue dipped, is pure [b]equine saliva[/b].
                            You retch even [b]before[/b] you manage to get the slimey goop into your mouth.
                            As your tongue retracts into your muzzle, the horrid taste of animal drool spreads throughout your mouth.
                            You swallow the stuff as quickly as you can, but the taste lingers.
                        [/p]
                        [p]
                            Your stomach churns, barely able to hold its fresh contents.
                            But you're not nearly done.
                            Despite being outright [b]sickening[/b] in flavor, a lot warmer and far more [b]viscous[/b] than you would have liked,
                            the slop you licked up [i]did[/i] end up [b]refreshing[/b] your dry mouth.
                            You need [b]more[/b].
                            However much it [b]revolts[/b] you,
                            you need to [b]keep drinking[/b] until you've taken in enough to survive.
                        [/p]
                        [p]
                            Trying to think of [b]anything[/b] but the vomit-inducing taste of the feral spit,
                            you lap again and again at the layer of stale saliva,
                            taking more and more of it into your muzzle,
                            letting it pool up before swallowing entire mouthfuls at a time.
                            You almost [b]throw up[/b] on the spot, as you accidentally lap up a clump of fur,
                            immediately followed by some chewed grass.
                            Luckily, you manage to refrain from vomiting,
                            as that would only serve to make the trough's contents even [b]less[/b] bearable to drink.
                        [/p]
                        [p]
                            While it doesn't nearly manage to quench your thirst,
                            the lukewarm fluid sticks to your gums and to the walls of your esophagus,
                            slickening your mouth, leaving a lingering, unpleasant yet somewhat [i]refreshing[/i] feeling.
                            You'll undoubtedly have bad breath for days to come.
                        [/p]
                        [p]
                            You notice Fenrir shifting around behind you.
                            Before you even have a chance to pull back and see what's up,
                            he painfully [b]kicks[/b] your rear, sending you flying forwards into the trough.
                            Your head momentarily dips underwater, spit-laced goop [b]flooding[/b] into your open mouth.
                            Surprised, you swallow more than a little of the vile stuff,
                            including a thick wad of what you can only presume to be [b]animal phlegm[/b].
                            You resurface, spitting out as much of it as you can, retching and heaving
                            before turning your attention towards your captor, casting an angry [b]glare[/b] at him.
                        [/p]
                        [p]
                            "[color=gblue]I told you to [b]wash up[/b], not to [b]drink[/b].
                            You can be glad that I chose to kick your ass instead of [b]crushing[/b] your head.
                            Next time you disobey me-[/color]"
                            Suddenly, a booming voice interrupts the bandit.
                        [/p]`;
        }

        toReturn += `   [p]
                            [big][color=brown][b]Fenrir!![/b][/color][/big]
                        [/p]
                        [p]
                            It's the caravan master!
                            He's approaching the two of you rapidly.
                            "[color=brown]What the [b]hell[/b] are you doing to the slave?![/color]"
                            The chubby human crudely pushes the wolf to the side.
                            You immediately crawl out of the trough, rising to your feet and scraping as much of the spit off as possible.
                            "[color=gblue]Relax, I'm just getting it cleaned like you told me to.[/color]"
                            Your captor's response only serves to anger his [sneak]temporary[/sneak] superior further.
                            "[color=brown][b]Relax?![/b]
                            Half the bloody village is watching you!
                            We're trying to [b]sell[/b] to these people,
                            and you [b]kicking[/b] our [i]merchandise[/i] in front of them [b]isn't[/b] helping.[/color]"
                        [/p]
                        [p]
                            The wolf tries, but fails to come up with an apt response.
                            He sighs discontently, muttering a half-meant apology.
                            "[color=brown]That's more like it.
                            Now quit acting like the [b]animal[/b] you are, and go get dressed.[/color]"
                            After an intense stare-down, Fenrir finally backs off.
                            Audibly grumbling, he begins to make his way back to the wagons, leaving you alone with the caravan master.
                            The human harrumphs angrily.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrinkBad.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrink.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideDrink(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOutsideChoice.DRINK;
    var reqController = ctrl.outside;

    var toFail = new SlaveNoonTwoOutsideDrinkBad(ctrl);
    var toSuccess = new SlaveNoonTwoOutsideDrinkGood(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        if (!ctrl.outsideComplianceStorage.has()) {
            ctrl.outsideComplianceStorage.set(global.kobold.history.shared.enslavement.totalComplianceRating());
        }
        return ctrl.outsideComplianceStorage.get() > 8;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\drink\SlaveNoonTwoOutsideDrink.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBatheGood.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideBatheGood(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.batheGood;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.goodBathe = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            Do you really have to wash up in the [b]middle[/b] of the hamlet, with all these people watching?
                            In a shallow [b]trough[/b] used by beasts of burden to slake their thirst?
                            You ${injected ? `sigh internally` : `let out another sigh`}.
                            You'd rather have some [b]privacy[/b] and the comfort of [b]running[/b] or at least [b]fresh[/b] water,
                            instead of this stale puddle of [b]animal spit[/b].
                        [/p]
                        [p]
                            But you don't get a say in the matter.
                            Either you wash up here, or not at all.
                            ${fucked ? `${eager ? `While you wear Fenrir's dried spunk with pride,
                            it would still be nice to clean off the rest of the dirt.` : `You're eager to rid yourself of
                            Fenrir's dried spunk.`}` : `It would be nice to clean off all the dirt from the chase.`}
                            Besides, it's a drinking trough.
                            You're probably [i]overreacting[/i].
                            There'll certainly be plenty of fresh, cool water underneath the filthy [i]top layer[/i].
                            Either way, you doubt the canine will change his mind on forcing you to bathe here,
                            especially considering the [i]auction[/i] is supposed to start soon.
                        [/p]
                        [p]
                            Reluctantly, you lift your foot off the ground, move it towards the trough, and dip it into the liquid.
                            The fluid feels [b]thick[/b], [b]warm[/b] and [b]sticky[/b], not just on the surface, but for at least an entire [b]inch[/b] deep.
                            Like a whole [b]layer[/b] of revolting animal drool coating your foot.
                            While appalled, you're in too far to back down now.
                            You press on, planting your sole on the wooden bottom of the trough.
                            At least the water is a [i]bit[/i] less [b]viscous[/b] and a hint [b]cooler[/b] near the bottom.
                        [/p]
                        [p]
                            Disgust visible on your face, you gingerly place your second foot into the makeshift tub.
                            A faint, unpleasant smell wafts forth from the fluid at your feet.
                            You look back at Fenrir, wordlessly pleading with him.
                            Do you [b]really[/b] have to do this?
                            The wolf's stern glare is unrelenting.
                            "[color=gblue]Hurry up. People are waiting.[/color]"
                        [/p]
                        [p]
                            With great hesitation, you lower your body into the water, your bare butt sinking through the slimy spit to the bottom of the trough.
                            You can feel the sickening feral saliva clinging to your loins, even when submerged into the clear part of the water,
                            along with more than a few mushy bits of half-digested grass.
                            Wanting to get this over with as fast as possible, if only to sate the wolf,
                            you dip your hands into the liquid, reaching as low as possible to collect as much of the [i]actual[/i] water as you can.
                            Still, you scoop up more [b]drool[/b] and [b]fur[/b] than anything else.
                        [/p]
                        [p]
                            Your stomach is churning, but you endure, smearing the slimy goop along your arms, [i]washing[/i] yourself with horse slobber.
                            You look behind you.
                            Fenrir seems pleased.
                            "[color=gblue]Carry on.
                            I'm going to leave you to it while I put on some clothes.
                            Try to run, if you [b]dare[/b].
                            We'll find you before you manage to reach the city [b]or[/b] the forest.
                            And when we do, the only thing we'll be selling'll be your [b]dried meat[/b].[/color]"
                        [/p]
                        [p]
                            With those words, the wolf turns tail, and casually begins to walk away.
                            Before he turns the corner back to the caravan, he lingers for a bit to stare at you, signalling for you to continue washing.
                            Dumbstruck, you gather more spit-water, and splatter it over your chest.
                            The saliva-ridden fluid is thick enough for you to [b]smear[/b] it over your body.
                            The act seems to satisfy the canine's lax suspicions.
                            He returns to the caravan, leaving you all to yourself, sitting naked in a watering trough in the middle of the hamlet.
                        [/p]
                        [p]
                            In a weird way, it's like Fenrir somewhat [i]trusts[/i] you not to try to run away or something.
                            Then again, he's right.
                            You have no way to escape.
                            If the farmers leering at you don't stop you themselves,
                            then they'll surely be able to tell the [b]bandits[/b] that'll be chasing after you where you went.
                        [/p]
                        [p]
                            Even [i]if[/i] you managed to make it past the farmers,
                            there's little cover between here and the city.
                            A few patches of woodland, none big enough to hide you for long.
                            Unless you fancy swimming across the wide river, there's only three ways to get back to the forest,
                            all three of which they'll undoubtedly guard.
                            If it were summer, at least you'd be able to conceal yourself in the growing grain.
                            But it's winter.
                            The fields are barren.
                        [/p]
                        [p]
                            You can't outrun them, as the wolf demonstrated yesterday, and there's nowhere to hide around here.
                            Fleeing would be a bad idea.
                            But that doesn't mean you have to sit here in this [i]slop[/i].
                            To make sure Fenrir can't say you didn't at least [i]try[/i] to clean yourself,
                            you slather some of the saliva-mixture onto your back, then you rise to your feet as quickly as you can, and you step out of the tub.
                        [/p]
                        [p]
                            Spit slowly oozes from your body, the viscous liquid inching its way down your scales, onto the ground.
                            To your surprise, it's actually quite [i]efficient[/i] at removing the dried up dirt${fucked ? `, dust and cum` : ` and dust`} from your body.
                            Even the bits of grass and fur get swept away.
                            The smell of the stuff, sadly, lingers on your scales, but it's mild enough to be passed off as [i]body odor[/i].
                            While it was one of the most unpleasant things you've ever done,
                            ${injected ? `surpassed only by taking the wolf's filthy underwear into your mouth,` : ``}
                            you've actually managed to get out of the slobber-rich drinking trough slightly more clean than you were before.
                        [/p]
                        [p]
                            Contemplating your next move, a familiar figure suddenly rushes towards you.
                            The caravan master.
                            "[color=brown]Ah, there you are, slave.
                            I was beginning to fear Fenrir had run off with you.
                            Where the hell is that mangy pooch anyway?
                            Did he leave you all alone?![/color]"
                            The human harrumphs angrily.
                            You don't dare interrupt him.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBatheGood.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBatheBad.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideBatheBad(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preStage;
    var changeController = ctrl.batheBad;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.stage;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.badBathe = true;
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Judging by the look on Fenrir's face, you have a choice between either getting in the tub, or being [b]forced[/b] into it.
                            While you [b]really[/b] don't want to do this, if you [b]absolutely[/b] have to, then you'd prefer to do so on your own terms.
                        [/p]
                        [p]
                            Darnit.
                            Why couldn't the wolf have brought you to the river instead?!
                            Washing up in the [b]middle[/b] of the hamlet, with all these people watching, is more than a little degrading.
                            In a shallow [b]trough[/b] used by beasts of burden to slake their thirst, no less.
                            You ${injected ? `sigh internally` : `let out another sigh`}.
                            You'd rather have some [b]privacy[/b] and the comfort of [b]running[/b] or at least [b]fresh[/b] water,
                            instead of this stale puddle of [b]animal spit[/b].
                        [/p]
                        [p]
                            But you don't get a say in the matter.
                            ${fucked ? `${eager ? `While you wear Fenrir's dried spunk with pride,
                            it [i]would[/i] be kind of nice to clean off the rest of the dirt.` : `While you don't let it show,
                            you kind of appreciate that you get to 
                            rid yourself of Fenrir's dried spunk.`}` : `It's actually kind of nice of Fenrir,
                            to allow you to clean off all the dirt from the chase.`}
                            Besides, it's a drinking trough.
                            You're probably [i]overreacting[/i].
                            There'll certainly be plenty of fresh, cool water underneath the filthy [i]top layer[/i].
                            Either way, the canine looks about ready to [b]toss[/b] you in if you don't get moving.
                        [/p]
                        [p]
                            Reluctantly, you lift your foot off the ground, move it towards the trough, and dip it into the liquid.
                            The fluid feels [b]thick[/b], [b]warm[/b] and [b]sticky[/b], not just on the surface, but for at least an entire [b]inch[/b] deep.
                            Like a whole [b]layer[/b] of revolting animal drool coating your foot.
                            While appalled, you're in too far to back down now.
                            You press on, planting your sole on the wooden bottom of the trough.
                            At least the water is a [i]bit[/i] less [b]viscous[/b] and a hint [b]cooler[/b] near the bottom.
                        [/p]
                        [p]
                            Disgust visible on your face, you gingerly place your second foot into the makeshift tub.
                            A faint, unpleasant smell wafts forth from the fluid at your feet.
                            You look back at Fenrir, wordlessly pleading with him.
                            Do you [b]really[/b] have to do this?
                            The wolf's stern glare is unrelenting.
                            "[color=gblue]Hurry up, slave. People are waiting.[/color]"
                        [/p]
                        [p]
                            With great hesitation, you lower your body into the water, your bare butt sinking through the slimy spit to the bottom of the trough.
                            You can feel the sickening feral saliva clinging to your loins, even when submerged into the clear part of the water,
                            along with more than a few mushy bits of half-digested grass.
                            Wanting to get this over with as fast as possible, if only to sate the wolf,
                            you dip your hands into the liquid, reaching as low as possible to collect as much of the [i]actual[/i] water as you can.
                            Still, you scoop up more [b]drool[/b] and [b]fur[/b] than anything else.
                        [/p]
                        [p]
                            Your stomach is churning, but you endure, smearing the slimy goop along your arms, [i]washing[/i] yourself with horse slobber.
                            You look behind you,
                            only to find the wolf fondling his groin, enticing the tapered tip of his canine member from its sheath.
                            Is he [b]getting off[/b] to this?!
                            Outraged, you try to scramble to your feet,
                            but the big lupine places his free hand on your shoulder, easily keeping you pinned down.
                            "[color=gblue]Keep going, [b]slave[/b].
                            Don't make me ask again.[/color]"
                        [/p]
                        [p]
                            He squeezes your tender frame tightly, threatening to puncture your scales with his sharp claws.
                            Fearfully, you gather more spit-water, and splatter it over your chest.
                            The saliva-ridden fluid is thick enough for you to [b]smear[/b] it over your body.
                            "[color=gblue]That's it.
                            [b]Lather up.[/b]
                            I'll be able to [b]smell[/b] you from [b]miles[/b] away.[/color]"
                            Fenrir has begun to outright [b]stroke[/b] his length.
                            A droplet of precum drops directly from the tip into the trough, splashing down right behind you.
                        [/p]
                        [p]
                            What kind of [b]freak[/b] would even jerk off to a kobold bathing in spit?!
                            What's he getting a rise out of?
                            Is it the power he holds over you?
                            The control?
                            The washing itself?
                            The humiliation?
                            Or the [b]stench[/b]?
                            The canine growls loudly.
                            His claws dig deep enough to almost draw blood.
                            "[color=gblue]I said: [b]keep going[/b].[/color]"
                            Almost reduced to tears,
                            you half-heartedly slather some of the saliva-mixture onto your back.
                            It is quickly joined by another squirt of pre, this time hitting the back of your neck.
                            Suddenly, a booming voice rings out from behind, saving you from further indignation at the hands of the lupine.
                        [/p]
                        [p]
                            [big][color=brown][b]Fenrir!![/b][/color][/big]
                        [/p]
                        [p]
                            It's the caravan master!
                            He's approaching the two of you rapidly.
                            "[color=brown]What the [b]hell[/b] are you doing to the slave?![/color]"
                            The chubby human crudely pushes the wolf to the side.
                            You immediately crawl out of the trough, rising to your feet and scraping as much of the spit off as possible.
                            "[color=gblue]Relax, I'm just having some [b]fun[/b].[/color]"
                            Your captor's response only serves to anger his [sneak]temporary[/sneak] superior further.
                            "[color=brown][b]Fun?![/b]
                            Half the bloody village is watching you!
                            We're trying to [b]sell[/b] to these people, and you jerking your dick in front of them [b]isn't[/b] helping.[/color]"
                        [/p]
                        [p]
                            The wolf tries, but fails to come up with an apt response.
                            Sighing discontently, he lets go of his half-erect cock.
                            "[color=brown]That's more like it.
                            Now quit acting like the [b]animal[/b] you are, and go get dressed.[/color]"
                            After an intense stare-down, Fenrir finally backs off.
                            Audibly grumbling, he begins to make his way back to the wagons, leaving you alone with the caravan master.
                            The human harrumphs angrily.
                            "[color=brown]The baron will hear of this.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBatheBad.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBathe.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutsideBathe(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOutsideChoice.BATHE;
    var reqController = ctrl.outside;

    var toFail = new SlaveNoonTwoOutsideBatheBad(ctrl);
    var toSuccess = new SlaveNoonTwoOutsideBatheGood(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        if (!ctrl.outsideComplianceStorage.has()) {
            ctrl.outsideComplianceStorage.set(global.kobold.history.shared.enslavement.totalComplianceRating());
        }
        return ctrl.outsideComplianceStorage.get() > 8;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\bathe\SlaveNoonTwoOutsideBathe.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\SlaveNoonTwoOutside.js

/**
 * Outside section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoOutside(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preOutside;
    var subController = ctrl.outside;
    var changeController = ctrl.outside;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new SlaveNoonTwoOutsideRefuse(ctrl);
    var secondNext = new SlaveNoonTwoOutsideDrink(ctrl);
    var thirdNext = new SlaveNoonTwoOutsideBathe(ctrl);

    var firstChoice = SlaveNoonTwoOutsideChoice.REFUSE;
    var secondChoice = SlaveNoonTwoOutsideChoice.DRINK;
    var thirdChoice = SlaveNoonTwoOutsideChoice.BATHE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var injected = ctrl.gag.has();
        var neither = ctrl.potion.get() === SlaveNoonTwoGoodPotionChoice.NEITHER;
        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var kissedBalls = global.kobold.history.shared.enslavement.noonTwo.kissedBalls || eager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            With your body ${injected ? `forcibly altered` : `${neither ? `left unaltered` : `changed for the better`}`},
                            Fenrir takes hold of the collar around your neck.
                            His [i]slave[/i] in tow, he proudly strides away from the caravan, into town.
                            While not a whole lot of people call the hamlet home, there's still quite a few farmers loitering about.
                            Probably getting some lunch, or just taking a break from work for a bit.
                            Perhaps they've [i]heard[/i] of the [b]slave auction[/b] about to take place.
                            The moment the two of you come into view, all of their eyes instantly shift towards the bandit and his prize.
                        [/p]
                        [p]
                            You can't tell who's drawing more attention: the naked wolf or you yourself.
                            While you'd [b]hoped[/b] that the both of you being nude would somewhat [b]lessen[/b] your shame,
                            it has quite the opposite effect.
                            It's as if the canine is broadcasting his ownership to the entire village,
                            strutting about the fact that
                            ${fucked ? `he fucked you yesterday` : `${kissedBalls ? `you just kissed his nuts` : `he's about to sell you`}`}.
                            ${eager ? `You can't help but admire his dominant attitude.` : `You [b]hate[/b] how he thinks he [b]owns[/b] you.`}
                        [/p]
                        [p]
                            Despite Fenrir catching some of their glares,
                            you can't help but feel the farmers' eyes staring at you, inpecting your body,
                            ${eager ? `envisioning you in every lewd situation imaginable` : `judging you ability to work as their maid,
                            their cook or their farmhand`}.
                            Being [b]paraded[/b] around like this is shameful, to say the least${eager ? `, but also kind of arousing` : ``}.
                            You can't help but wonder what other kind of ${eager ? `alluring` : `degrading`} things the lupine has in store for you.
                        [/p]
                        [p]
                            Walking over to one of the buildings, your captor suddenly comes to a halt.
                            Stepping besides him, you notice he's stopped in front of a wide, long wooden animal drinking trough.
                            You can immediately tell it's been [b]thoroughly[/b] used, [b]very[/b] recently.
                            The water is slightly murky, bits of fur and leaves of chewed grass floating at the surface, alongside a great amount of undiluted [b]spit[/b],
                            so much of the stuff that you're starting to wonder how [i]little[/i] of the liquid left is actual [b]water[/b].
                            But then again, the feral saliva might just be a [i]surface layer[/i] of sorts.
                        [/p]
                        [p]
                            "[color=gblue]Here we are, ${injected ? `slave` : name}.
                            Time to [b]wash up[/b].
                            You need to look presentable.
                            ${fucked ? `Can't have you go on stage with cum splatters on your thighs` : `
                            Can't have you go on stage all dirty from running through the forest the other day`}.[/color]"
                            Stage?
                            Casting your gaze to the crossroads at the center of the hamlet,
                            you notice a small wooden podium built right besides the well.
                            ${eager ? `` : `[i]Oh no[/i].`}
                            They're going to make a [b]big deal[/b] out of this, aren't they?
                        [/p]
                        [p]
                            ${eager ? `` : `You sigh loudly.`}
                            ${injected ? `Your mouth still gagged, you give Fenrir a small nod,
                            followed by an inquisitive gaze.` : `You tell Fenrir that you'll gladly accept the opportunity to wash up.`}
                            Did he bring a tub, or is he going to draw water from the well?
                            "[color=gblue]${injected ? `What are you waiting for?
                            Get in.` : `A tub?
                            You're staring at it, dumbass.`}[/color]"
                            Wait, the trough?
                            He has to be kidding.
                            "[color=gblue]If it's good enough for our pack animals to drink from,
                            then it's also good enough for a kobold like you to clean yourself in.
                            Now get started.
                            There's only a couple of minutes left before the auction's supposed to begin.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Refuse</button>`;

        var tooltip = global.parser.parse(`You are [b]not[/b] going to wash up in a trough full of [b]slobber[/b].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 205px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Drink</button>`;

        var tooltip = global.parser.parse(`It may be filthy, but it's the only water you've seen in more than a day.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Bathe</button>`;

        var tooltip = global.parser.parse(`Disgusting or not, you need to be clean if you want to get [i]bought[/i].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var SlaveNoonTwoOutsideChoice = {
    REFUSE: 1,
    DRINK: 2,
    BATHE: 3
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\outside\SlaveNoonTwoOutside.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\inject\SlaveNoonTwoBadInject.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadInject(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preInject;
    var subController = ctrl.preOutside;
    var changeController = ctrl.inject;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.outside;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.injected = true;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            Fenrir lets you get [i]acquainted[/i] with your new gag for a minute more,
                            taking in the disgusted look on your face, ensuring he'll remember this moment for the rest of his life.
                            You know [b]you[/b] will.
                            How could you ever forget a taste this [b]foul[/b]?
                            You get the feeling you'll be [b]wishing[/b] you could in the future.
                        [/p]
                        [p]
                            His sadistic voyeurism sated,
                            the wolf crudely grabs you by the wrist, and begins to tug you towards the cart's open entryway.
                            "[color=gblue]While I could watch you [b]pout[/b] all day long,
                            you and I have business to attend to.
                            In case you hadn't realized yet: you're being [b]sold[/b].
                            [b]Today[/b].
                            And it's [b]my[/b] job to ensure you look at least [i]somewhat[/i] presentable.[/color]"
                        [/p]
                        [p]
                            He's not taking [i]no[/i] for an answer,
                            yanking you forwards hard enough to nearly pull your arm off.
                            Already having been [i]punished[/i] once, you don't resist much,
                            lest he decide to shove a sock up your ass next.
                            A few steps and a small hop later, you find yourself in the outside world once more.
                        [/p]`;

        if (ctrl.arrival.get() !== SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            You recognize this area.
                            You've been here before.
                            It's a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]`;
        }

        toReturn += `   [p]
                            Luckily, the caravan stopped at the outskirts of the settlement,
                            your nudity and improper gag not made public quite yet.
                            And, if it's any [i]consolation[/i], your captor is every bit as naked as you are.
                            Walking alongside your prison carriage's exterior,
                            whilst dragging you with him, the canine comes to an unexpected halt,
                            your face ending up unpleasantly [i]bumping[/i] into his bare rear.
                            Reaching down, he fetches a small, brown satchel, conveniently concealed directly underneath the cart.
                        [/p]
                        [p]
                            "[color=gblue]I almost forgot.
                            I [i]had[/i] prepared a treat for you,
                            should you have chosen to [b]behave[/b].
                            But you were a bad ${dick ? `boy` : `girl`}.
                            And bad ${dick ? `boy` : `girl`}s don't [b]deserve[/b] any treats.[/color]"
                        [/p]
                        [p]
                            Rummaging through the tiny bag, Fenrir produces a pair of oddly shaped bottles, along with a large, ominous-looking syringe.
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}
                            and ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}.
                            Seki makes that sort of stuff.
                            "[color=gblue]It feels like such a [b]waste[/b] to let these go unused, though.
                            What do you think, slave?
                            Should I pick one for you?[/color]"
                        [/p]
                        [p]
                            The wolf wants to [b]inject[/b] you with body-altering [b]drugs[/b]?!
                            No way!
                            Knowing him, he'll probably pick the [b]worst one[/b]!
                            You wildly shake your head no, while audibly complaining through your underwear-gag.
                            Your muffled shouts for him to put the vials back in the bag seem to have persuaded the lupine.
                        [/p]
                        [p]
                            "[color=gblue]Alright, alright.
                            I'll put'em back.[/color]"
                            Fenrir turns his rear to you,
                            seemingly messing around with the fragile, glass containers.
                            Probably making sure they don't [i]break[/i] while returning them to the satchel.
                        [/p]
                        [p]
                            Suddenly, your captor turns to face you once more.
                            In one of his furred hands: a filled syringe.
                            Before you even know what's going on,
                            the burly canine [b]rams[/b] the needle into your upper arm,
                            the sharp piece of hollow metal [b]piercing[/b] your scales with ease.
                            While firmly holding you in place with his free hand,
                            he begins to lower the plunger with his thumb,
                            forcing the syringe's contents into your veins.
                        [/p]
                        [p]
                            You yelp out in pain, immediately starting to struggle and squirm,
                            trying your best to get away from the bandit's grasp [b]before[/b] he can inject the entirety of the potion into your body.
                            "[color=gblue]Stand [b]the fuck[/b] still!
                            Do you [b]want[/b] the needle to [b]break off[/b]?![/color]"
                            You fail to heed the wicked man's warnings, continuing your fierce resistance,
                            yet his grasp is far stronger than every muscle in your body combined.
                        [/p]`;

        if (ctrl.misc.dick()) {
            global.kobold.history.shared.enslavement.noonTwo.tookMPlus = true;
            toReturn += `[p]
                            Fenrir easily manages to keep you put while administering the drug.
                            You can already feel its effects starting to kick in.
                            Your members stirs within your loins, tangibly growing larger,
                            your cockslit becoming a lot more [b]cramped[/b].
                            Luckily, as the last of the liquid is squirted into your bloodstream, the effects swiftly come to a halt.
                        [/p]
                        [p]
                            [c]
                                [b]You have grown more masculine.[/b]
                            [/c]
                        [/p]
                        [p]
                            "[color=gblue]There you go.[/color]" the wolf speaks, retracting the needle from your arm,
                            before tossing it to the ground, breaking it.
                            You glare at him, with all the hatred and anger that you can muster.
                            He [b]changed[/b] your [b]body[/b] without your consent.
                            A [b]major[/b] crime, [i]if[/i] kobolds -- or slaves, for that matter -- had [i]any[/i] legal rights.
                        [/p]
                        [p]
                            "[color=gblue]I figured you could stand to be a bit [i]bigger[/i] where it counts.
                            It'll make you more attractive to the ladies shopping for a little lizard of their own.
                            And before you get all [b]uppity[/b] about not getting your way, remember:
                            [b]you[/b] are the [b]slave[/b] here.
                            I am your [b]master[/b].
                            [b]I[/b] decide what is good for you, and what is not.
                            And [b]your[/b] opinion on the matter is [b]irrelevant[/b].
                            You [b]live[/b] to [b]serve[/b] me, after all.[/color]"
                        [/p]`;
        } else {
            global.kobold.history.shared.enslavement.noonTwo.tookFemPlus = true;
            toReturn += `[p]
                            Fenrir easily manages to keep you put while administering the drug.
                            You can already feel its effects starting to kick in.
                            Your breasts tingle and throb, visibly growing bigger,
                            your upper chest feeling heavier with every passing second.
                            Luckily, as the last of the liquid is squirted into your bloodstream, the effects swiftly come to a halt,
                            leaving your bare tits a single size larger than what they used to be.
                        [/p]
                         [p]
                            [c]
                                [b]You have grown more feminine.[/b]
                            [/c]
                        [/p]
                        [p]
                            "[color=gblue]There you go.[/color]" the wolf speaks, retracting the needle from your arm,
                            before tossing it to the ground, breaking it.
                            You glare at him, with all the hatred and anger that you can muster.
                            He [b]changed[/b] your [b]body[/b] without your consent.
                            A [b]major[/b] crime, [i]if[/i] kobolds -- or slaves, for that matter -- had [i]any[/i] legal rights.
                        [/p]
                        [p]
                            "[color=gblue]I figured you could stand to be a bit [i]bigger[/i] where it counts.
                            It'll make you more attractive to the men shopping for a little lizard of their own.
                            And before you get all [b]uppity[/b] about not being allowed to pick your poison, remember:
                            [b]you[/b] are the [b]slave[/b] here.
                            I am your [b]master[/b].
                            [b]I[/b] decide what is good for you, and what is not.
                            And [b]your[/b] opinion on the matter is [b]irrelevant[/b].
                            You [b]live[/b] to [b]serve[/b] me, after all.[/color]"
                        [/p]`;
        }

        toReturn += `[p]
                        You hate this.
                        You hate [b]everything[/b] about this.
                        How your body is being warped to better suit Fenrir's [i]needs[/i],
                        how he's acting like he's [b]already[/b] your [i]master[/i],
                        how he thinks altering your body would be okay, even [b]if[/b] you were his slave,
                        it all [b]aggrevates[/b] you to no end!
                        And to make matters even worse,
                        you can't even [b]voice[/b] your disdain for what he's doing, due to the sickening [b]worn underpants[/b] gagging your mouth.
                    [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\inject\SlaveNoonTwoBadInject.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGagOpen.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadGagOpen(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoBadGagChoice.OPEN;
    var reqController = ctrl.gag;
    var subController = ctrl.preInject;
    var changeController = ctrl.gagOpen;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new SlaveNoonTwoBadInject(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.gagOpened = true;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            While you loathe the sickening garment being dangled in front of your face,
                            there's no point in resisting what is about to happen.
                            The big wolf would force your mouth open with ease,
                            and ram it in regardless of how much you struggle.
                        [/p]
                        [p]
                            Besides, this is a matter of [b]pride[/b].
                            If you refuse to take your punishment, you'll look like a [b]child[/b].
                            But if you do as he asks, and reluctantly take it like an adult,
                            you'll come off looking a lot better.
                            And you think Fenrir, despite your disagreements, will be able to appreciate that.
                        [/p]
                        [p]
                            Glaring at the canine with hatred in your eyes, you slowly open your muzzle, spreading your jaws as far apart as they'll go.
                            Your captor seems pleasantly surprised.
                            A big grin forms on his face.
                            "[color=gblue]Good ${dick ? `boy` : `girl`}.
                            Suddenly growing obedient, are we?
                            Or maybe you just [b]wanted[/b] to suckle the sweat out of my week-old underwear from the get-go.[/color]"
                        [/p]
                        [p]
                            You resist the urge to tell Fenrir to go fuck himself.
                            It takes every ounce of willpower you can muster [b]not[/b] to go back on your decision to play along.
                            Deciding not to waste any more time with idle banter,
                            the wolf slowly moves the disgusting piece of cloth closer and closer to your mouth, as if to gauge your reaction.
                            A sparkle of hope remaining that this is all just a [b]test[/b],
                            a [b]bluff[/b] to see whether or not you'd try to bite him or something,
                            you remain completely motionless.
                        [/p]
                        [p]
                            As the first bit of the foul garment gets pressed into your open muzzle,
                            you realize this is [b]not[/b] a joke or a trial.
                            Fenrir is actually [b]serious[/b] about gagging you with his rancid underpants!
                            The coarse fabric drags along your tongue, leaving a trail of revolting filth in its wake,
                            its gut-wrenching, absolutely [b]revolting[/b] flavor spread across your tastebuds.
                            You thought the [b]smell[/b] was bad, but the taste is [b]ten times[/b] worse.
                        [/p]
                        [p]
                            On the verge of throwing up, you attempt to close your mouth,
                            to stop the wolf from taking this any further, but it's too late.
                            Too much of his underwear is already in your muzzle, blocking your jaws, preventing you from closing them.
                            And he isn't done yet.
                            The psychopathic bandit pushes his ass-and-crotch-sweat-drenched briefs deeper and deeper into your maw,
                            cramming the entirety of the repulsive loincloth down your face.
                        [/p]
                        [p]
                            Bits of dirt and grime mix with spit at the back of your mouth, rapidly spreading throughout the entirety of your muzzle,
                            tainting every nook and cranny that the unsanitary garment itself failed to reach.
                            Various unidentifiable specks of crud stick to your teeth and to your gums,
                            ensuring the vile taste will linger for [b]hours[/b], if not [b]days[/b] to come,
                            even [b]if[/b] your [i]gag[/i] is removed.
                        [/p]
                        [p]
                            A small patch of filthy grey fur parts from the fabric it was contained in for over a [b]week[/b],
                            only to agonizingly find its way down your throat instead,
                            unpleasantly scraping against the inner walls of your esophagus for its entire trip into your stomach.
                            Luckily, you haven't eaten in quite a while.
                            Otherwise, vomit would join the mixture of nauseating flavors and textures trapped within your muzzle.
                        [/p]
                        [p]
                            The more the underwear gets drenched in your spit,
                            the more prominent the horrifying taste of what you can only assume to be [b]wolf ass[/b] gets.
                            The large amount of stale sweat contained within the cloth is slowly being [b]rinsed out[/b] by your saliva,
                            causing a constant trickle of pungent, age-old canine perspiration to ooze onto your tongue,
                            along with even [b]more[/b] ancient filth, buried and entangled deep within the textile.
                            Has the garment [b]ever[/b] been properly washed?
                            You're starting to think not.
                        [/p]
                        [p]
                            Satisfied with his work, Fenrir retracts his hand from your maw,
                            while using the other to forcibly shut your jaws as best he can,
                            his wretched loincloth preventing them from closing fully.
                            Keeping your mouth firmly sealed over the horrid piece of clothing,
                            he deftly ties his piece of rope around your muzzle, completing your makeshift
                            ${global.kobold.inventory.createItemWithTooltip(new UnderwearGag())}.
                            With a cruel chuckle, the lupine takes a step back to admire his work.
                        [/p]
                        [p]
                            You try your best to ignore Fenrir, and instead focus on attempting to cope with your new [i]restraints[/i].
                            While you manage to force some of the grime out through the front and the sides of your muzzle using your flexible tongue,
                            a lot of it lingers in the back of your mouth, blocked by the big pair of underpants.
                            It can't keep piling up forever, and it has only one way to go.
                            Tears flowing liberally from your eyes,
                            you reluctantly swallow the disgusting, goopy build-up of mixed saliva, sweat and filth,
                            undoubtedly only the first of many such loads before the [i]gag[/i] is removed.
                            You only barely manage to hold it down.
                        [/p]
                        [p]
                            "[color=gblue][b]Hey![/b][/color]" the wolf draws your attention.
                            "[color=gblue]Listen up, [b]slave[/b].
                            You touch that rope around your maw, and you [b]die[/b].
                            Got it?[/color]"
                            Still not able to fully cope with the foul flavour, you half-heartedly give the canine a small nod.
                            You're hardly even listening to him.
                            "[color=gblue]If you're having this much trouble [i]enduring[/i] my underwear,
                            then I hope for your sake that someone's willing to buy your lousy ass.
                            Because if I get my hands on you, a bit of sweat and dirt will be the [b]least[/b] of your concerns.[/color]"
                        [/p]
                        [p]
                            You doubt there's even [b]worse[/b] things he can inflict on you.
                            But then again, this is Fenrir we're talking about.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGagOpen.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGagRefuse.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadGagRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoBadGagChoice.REFUSE;
    var reqController = ctrl.gag;
    var subController = ctrl.preInject;
    var changeController = ctrl.gagRefuse;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new SlaveNoonTwoBadInject(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            You [b]loathe[/b] the sickening garment being dangled in front of your face.
                            There's [b]no way[/b] you're going to let the big wolf shove that thing inside of your mouth.
                            If he wants to get it in, then he's welcome to [b]try[/b].
                            You glare defiantly at Fenrir, your lips firmly sealed.
                            [i]It's on[/i].
                        [/p]
                        [p]
                            "[color=gblue]Why do you have to make things so [b]hard[/b] on yourself?[/color]"
                            comes the canine's melodramatic question.
                            You bluntly tell him to go [b]fuck himself[/b].
                            He doesn't seem to like that.
                            His free hand curls up, and in the flash of an eye, Fenrir [b]rams[/b] his fist into your side,
                            [b]pummeling[/b] your lower back, delivering a fast and [i]cheap[/i] kidney-shot,
                            painful enough to make you [b]shriek[/b] out in agony.
                        [/p]
                        [p]
                            The bandit leader takes advantage of your mouth opening to scream,
                            quickly [b]forcing[/b] the foul garment into your mouth, muffling your pathetic cry,
                            silencing you with his unwashed underpants.
                            The coarse fabric drags along your tongue, leaving a trail of revolting filth in its wake,
                            its gut-wrenching, absolutely [b]revolting[/b] flavor spread across your tastebuds.
                            You thought the [b]smell[/b] was bad, but the taste is [b]ten times[/b] worse.
                            Combined with the pain and the indignation, the sensation is almost strong enough to make you lose consciousness.
                        [/p]
                        [p]
                            On the verge of throwing up, you attempt to close your mouth, to [b]bite down[/b] on Fenrir's hand, but it's too late.
                            Too much of his underwear is already in your muzzle, blocking your jaws, preventing you from closing them.
                            And he isn't done yet.
                            The psychopathic bandit pushes his ass-and-crotch-sweat-drenched briefs deeper and deeper into your maw,
                            cramming the entirety of the repulsive loincloth down your face, making you [b]wish[/b] you actually did pass out.
                        [/p]
                        [p]
                            Bits of dirt and grime mix with spit at the back of your mouth, rapidly spreading throughout the entirety of your muzzle,
                            tainting every nook and cranny that the unsanitary garment itself failed to reach.
                            Various unidentifiable specks of crud stick to your teeth and to your gums,
                            ensuring the vile taste will linger for [b]hours[/b], if not [b]days[/b] to come,
                            even [b]if[/b] your [i]gag[/i] is removed.
                        [/p]
                        [p]
                            A small patch of filthy grey fur parts from the fabric it was contained in for over a [b]week[/b],
                            only to agonizingly find its way down your throat instead,
                            unpleasantly scraping against the inner walls of your esophagus for its entire trip into your stomach.
                            Luckily, you haven't eaten in quite a while.
                            Otherwise, vomit would join the mixture of nauseating flavors and textures trapped within your muzzle.
                        [/p]
                        [p]
                            The more the underwear gets drenched in your spit,
                            the more prominent the horrifying taste of what you can only assume to be [b]wolf ass[/b] gets.
                            The large amount of stale sweat contained within the cloth is slowly being [b]rinsed out[/b] by your saliva,
                            causing a constant trickle of pungent, age-old canine perspiration to ooze onto your tongue,
                            along with even [b]more[/b] ancient filth, buried and entangled deep within the textile.
                            Has the garment [b]ever[/b] been properly washed?
                            You're starting to think not.
                        [/p]
                        [p]
                            Satisfied with his work, Fenrir retracts his hand from your maw,
                            while using the other to forcibly shut your jaws as best he can,
                            his wretched loincloth preventing them from closing fully.
                            Keeping your mouth firmly sealed over the horrid piece of clothing,
                            he deftly ties his piece of rope around your muzzle, completing your makeshift
                            ${global.kobold.inventory.createItemWithTooltip(new UnderwearGag())}.
                            With a cruel chuckle, the lupine takes a step back to admire his work.
                        [/p]
                        [p]
                            You try your best to ignore Fenrir, and instead focus on attempting to cope with your new [i]restraints[/i].
                            While you manage to force some of the grime out through the front and the sides of your muzzle using your flexible tongue,
                            a lot of it lingers in the back of your mouth, blocked by the big pair of underpants.
                            It can't keep piling up forever, and it has only one way to go.
                            Tears flowing liberally from your eyes,
                            you reluctantly swallow the disgusting, goopy build-up of mixed saliva, sweat and filth,
                            undoubtedly only the first of many such loads before the gag is removed.
                            You only barely manage to hold it down.
                        [/p]
                        [p]
                            "[color=gblue][b]Hey![/b][/color]" the wolf draws your attention.
                            "[color=gblue]Listen up, [b]slave[/b].
                            You touch that rope around your maw, and you [b]die[/b].
                            Got it?[/color]"
                            Still not able to fully cope with the foul flavour, you half-heartedly give the canine a small nod.
                            You're hardly even listening to him.
                            "[color=gblue]If you're having this much trouble [i]enduring[/i] my underwear,
                            then I hope for your sake that someone's willing to buy your lousy ass.
                            Because if I get my hands on you, a bit of sweat and dirt will be the [b]least[/b] of your concerns.[/color]"
                        [/p]
                        [p]
                            You doubt there's even [b]worse[/b] things he can inflict on you.
                            But then again, this is Fenrir we're talking about.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGagRefuse.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGag.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadGag(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preGag;
    var subController = ctrl.gag;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new SlaveNoonTwoBadGagRefuse(ctrl);
    var secondNext = new SlaveNoonTwoBadGagOpen(ctrl);

    var firstChoice = SlaveNoonTwoBadGagChoice.REFUSE;
    var secondChoice = SlaveNoonTwoBadGagChoice.OPEN;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.gagged = true;
        var name = ctrl.misc.name();
        var declined = ctrl.blackmail.get() === SlaveNoonTwoOfferChoice.DECLINE;
        var toReturn = `[p]
                            "[color=gblue]Well, ${name}, I'm nothing if not a man of my word.[/color]"
                            The wolf ominously states, taking the piece of rope in one hand, and his underwear in the other.
                            You take a${declined ? `nother` : ``} small step backwards, ending up with your back pressed against the far-end of your cell.
                            Trapped between hard, unyielding, splintery wood and a maniacal canine intent on shoving his dirty laundry down your throat.
                            "[color=gblue]Remember: [b]you[/b] chose this path.
                            Not me.[/color]"
                        [/p]
                        [p]
                            Panic wells up inside of you as Fenrir bridges the gap between the two of you.
                            You consider fleeing, but you doubt you'd get far.
                            Even [i]if[/i] you managed to get past the lupine somehow,
                            either him or his gang would [b]hunt you down[/b] a second time.
                            And you don't think they'll make the mistake of trying to [i]sell[/i] you [b]twice[/b].
                        [/p]
                        [p]
                            Fearing for your very life, you stay still as the big bandit holds his disgusting linen underpants in front of your face.
                            He seems to be getting a cruel kick out of letting you take a [b]good look[/b] at the vile thing he's about to force into your mouth.
                            His briefs are visibly worn, small scraps of fur and many thick, grey hairs intertwined with the sloppily stitched-together fabric.
                            They [b]reek[/b] of stale sweat, and there are many bits of [b]filth[/b] bunched up around the leg-holes and the waistband.
                        [/p]
                        [p]
                            The seams are partially [i]discolored[/i] to a revolting, slightly yellowish tint.
                            And that's just what you can [b]see[/b].
                            You can only [b]imagine[/b] how dirty the insides must be.
                            The [b]stench[/b] alone is making your eyes water.
                            He was wearing this for [b]far[/b] longer than yesterday alone, that much is [b]very[/b] clear.
                            For the entire journey, perhaps, if not even longer.
                            You almost begin to [b]retch[/b], but manage to retain your composure through pride,
                            determination and the [b]will[/b] not to show weakness in front of Fenrir.
                        [/p]
                        [p]
                            "[color=gblue]Don't make this worse for yourself. Open your muzzle.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Refuse</button>`;

        var tooltip = global.parser.parse(`Fenrir can't gag you if you don't open your mouth.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Open up</button>`;

        var tooltip = global.parser.parse(`Don't bother to resist.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var SlaveNoonTwoBadGagChoice = {
    REFUSE: 1,
    OPEN: 2
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\gag\SlaveNoonTwoBadGag.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\eager\SlaveNoonTwoBadEager.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadEager(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.EAGER;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badEager;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to him asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something.
                            And for some reason, that kind of [i]arouses[/i] you.
                        [/p]
                        [p]
                            You never had a problem with Fenrir.
                            It was the caravan master who was acting like a real [b]prick[/b] last night.
                            While you don't want to get [b]killed[/b] by his [i]Furskin Mountain-Crew[/i],
                            as the canine threatened might happen,
                            you figure life with them could still turn out to be quite [i]nice[/i],
                            as long you serve them [b]properly[/b].
                            Surely they'll have no reason to hurt you if you obey their every wish, right?
                        [/p]
                        [p]
                            Becoming the big wolf's [b]plaything[/b] is an alluring prospect by itself.
                            Combined with the equally enticing big, furred orbs swinging underneath his plump sheath,
                            Fenrir's offer is practically [b]irresistible[/b] to you.
                            How could [b]anyone[/b] be faced with such a [b]hunk[/b] of a man,
                            and [b]not[/b] want to submit to him completely?
                            Should you end up not being [i]bought[/i],
                            then you'll get to live a comfortable life with your new lupine [i]master[/i],
                            hopefully far away from the chubby human that accosted you yesterday.
                        [/p]
                        [p]
                            Noticing the bandit growing impatient,
                            you lustily lick your lips and begin to inch your face closer to his balls.
                            The strong scent of canine masculinity intensifies,
                            male pheromones [b]wafting[/b] liberally from Fenrir's loins,
                            [b]clogging[/b] your nostrils, [b]saturating[/b] every breath you take.
                            You greedily huff the olfactory nectar, savoring every lungful,
                            wishing you could keep your face buried in his balls [b]forever[/b].
                        [/p]
                        [p]
                            While your own need is rising, you aren't about to get [i]distracted[/i] by it.
                            You set out to [i]please[/i] your master, and you intend to [b]exceed[/b] his every expectation.
                            As your snout sinks into the grey fur covering the wolf's sack,
                            you pucker your lips, and eagerly begin to plant kiss after kiss atop of his nuts.
                            Taking one of his balls into your mouth slightly, you gently suckle on it, just a little.
                            He groans in delight, his tense, authorative stand visibly relaxing.
                            [b]Excellent[/b].
                        [/p]
                        [p]
                            With Fenrir starting to mellow out, you up the intensity of your loving [b]admiration[/b].
                            Your tongue snakes out of your muzzle, your rampant kissing interrupted by occasional [b]licks[/b].
                            Before long, you find yourself outright [b]lapping[/b] along the coarse surface of the canine's sack,
                            wetting his fur with your saliva, enjoying the salty,
                            undeniably [b]masculine[/b] flavour even [b]despite[/b] the dried up sweat and the small bits of dirt and grime.
                        [/p]
                        [p]
                            The wolf begins to pant, his tail wagging excitedly.
                            Slowly, but surely, you work your way upwards, towards his sheath.
                            Right as you were about to goad his member from its slumber by kissing its resting place directly,
                            Fenrir suddenly presses his palm against your forehead, softly pushing you away.
                        [/p]
                        [p]
                            "[color=gblue]That's enough for now, you little [b]cocktease[/b].
                            Quite the apology.
                            If you were trying to impress me, it's a job well done.
                            Continue to act like that, and I might need to consider buying you myself,
                            to make sure nobody else gets to run off with that lovely muzzle of yours.[/color]"
                            Your captor takes a deep breath, seemingly washing the impure thoughts from his mind.
                            "[color=gblue]There'll be plenty of time for me to fuck your face later.
                            And since you like my balls so much,
                            you'll get to [b]worship[/b] them every single day, once you're finally [b]mine[/b].[/color]"
                            You can hardly wait.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\eager\SlaveNoonTwoBadEager.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\reluctant\SlaveNoonTwoBadReluctant.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadReluctant(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.RELUCTANT;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badReluctant;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.kissedBalls = true;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And while you [b]hate[/b] the idea of becoming his [i]sex toy[/i],
                            right now, relenting seems like a better option than getting his [b]disgusting underpants[/b] lodged in your mouth.
                        [/p]
                        [p]
                            You [b]really[/b] don't want to do this, but the wolf has left you with little choice.
                            You'd rather give his sack a single, quick kiss than have his loincloth soak in your mouth for the rest of the afternoon.
                            Should you end up not being able to escape, and not being [i]bought[/i],
                            then you'd prefer to stay on good terms with Fenrir instead of [i]pissing him off[/i] even further.
                            His threats might [i]sound[/i] a bit exaggerated, but you're fairly certain he's done this kind of thing before,
                            so he might [i]not[/i] be lying about what his men do to slaves.
                            Maybe [b]that's[/b] why he wants [b]you[/b].
                            The mere thought makes your stomach churn.
                        [/p]
                        [p]
                            Noticing the bandit growing impatient, you roll your eyes and let out a defeated sigh.
                            Slowly, but steadily, you inch your face closer to his balls.
                            The strong scent of canine masculinity intensifies,
                            male pheromones [b]wafting[/b] liberally from Fenrir's loins,
                            [b]clogging[/b] your nostrils, [b]saturating[/b] every breath you take.
                            As your snout sinks into the fur covering his sack,
                            you pucker your lips, and plant a single, tender kiss in between the wolf's large, dangling testicles.
                        [/p]
                        [p]
                            As soon as your half of the [i]bargain[/i] is complete,
                            you immediately pull back from Fenrir's groin.
                            You turn your face to the side,
                            deeply breathing in some less [i]heady[/i] air,
                            while wiping your tongue and your snout both, to symbolize your disdain.
                            You consider [i]spitting[/i] for dramatic effect,
                            but you figure you might have to spend another night in this cart,
                            so you'd rather not filthy the floor.
                        [/p]
                        [p]
                            "[color=gblue]Good ${dick ? `boy` : `girl`}.[/color]" he patronizes,
                            his voice heavy with smugness.
                            "[color=gblue]The sooner you get used to that taste, the better.
                            You'll be [b]bathing[/b] my nuts every morning, once you're finally [b]mine[/b].[/color]"
                            Arrogant prick.
                            At least he doesn't have to gag you now, right?
                            You think that goes without saying.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\reluctant\SlaveNoonTwoBadReluctant.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\attack\SlaveNoonTwoBadAttack.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadAttack(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.ATTACK;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badAttack;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.gagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.attacked = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And you don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to [b]kill you[/b] all he'd like.
                            At least that way, you won't have to be his [b]slave[/b] for the rest of your undoubtedly [i]miserable[/i] life.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said he was going to put his underwear into your mouth,
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            Anger wells up inside of you.
                            You aren't backing down.
                            Not this time.
                            In fact, with Fenrir's nude groin so close to your face, you spot an [i]opportunity[/i].
                            You could easily [b]bite down[/b] on his most sensitive bits,
                            and then, while he's writhing in pain, you can make a quick getaway.
                            [i]Excellent idea.[/i]
                        [/p]
                        [p]
                            Staring upwards at the lupine with a mischievous grin on your face,
                            you open your muzzle wide, and slowly approach his hefty balls with your snout.
                            Instead of going in for a kiss, you bring your sharp teeth to bear, 
                            intent on [b]chomping[/b] off a piece of the bandit's nutsack.
                            The wolf is not as ignorant as you believed him to be, however.
                            Or maybe you were too [i]eager[/i] to properly hide your true intentions.
                            Right before your fangs can sink into his loins,
                            he slams your forehead with the flat of his large palm,
                            harshly pushing you backwards, your muzzle snapping shut,
                            catching nothing but [i]air[/i] in between your teeth.                       
                        [/p]
                        [p]
                            Surprised by your plan's failure, you are suddenly filled with rage.
                            You close your eyes and begin to wildly [b]flail around[/b],
                            swinging your claws about every which way, hoping you'll strike a lucky hit.
                            Fenrir keeps you at bay by simply holding you by your forehead,
                            keeping you at arm's length like a parent would its unruly child.
                            That is, after all, what you are acting like: a [b]child[/b],
                            lashing out because it did something bad, one that doesn't [i]want[/i] to face the consequences of its actions.
                        [/p]
                        [p]
                            After nearly half a minute of hitting nothing but air, your angry, impotent rampage slowly comes to an end.
                            You open your eyes once more, a few frustrated tears rolling down your cheeks.
                            All the while, a sadistic grin is plastered across the canine's face.
                            "[color=gblue]You could have just said [i]no[/i], instead of [b]embarrassing[/b] yourself.
                            If you were mine already, I'd beat the [b]shit[/b] out of you for trying to lay a hand on me.
                            Luckily for you, bruises don't sell.
                            Anyway, you've made your choice.
                            The [b]hard way[/b] it is.[/color]"
                            [i]Oh dear.[/i]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\attack\SlaveNoonTwoBadAttack.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\insult\SlaveNoonTwoBadInsult.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadInsult(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.INSULT;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badInsult;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.gagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.insulted = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And you don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to [b]kill you[/b] all he'd like.
                            At least that way, you won't have to be his [b]slave[/b] for the rest of your undoubtedly [i]miserable[/i] life.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said he was going to put his underwear into your mouth,
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            You answer Fenrir's stern gaze with a determined glare of your own.
                            Anger wells up inside of you.
                            You aren't backing down.
                            Not this time.
                            You take in a deep breath, raise your voice, and let loose an angry [b]tirade[/b] of insults.
                            He's a filthy [b]slaver[/b].
                            A pathetic [b]loser[/b] that couldn't carve out an honest life for himself,
                            and is now stuck [b]bullying[/b] innocent kobolds like yourself!
                            You know you're not [i]really[/i] innocent, but it seemed like an [i]apt[/i] choice of words.
                        [/p]
                        [p]
                            Furthermore, he's [b]wrong[/b] about nobody wanting to buy you.
                            You're a [b]good[/b] kobold, and there'll surely be [b]dozens[/b] of people lining up to get a [b]chance[/b] at owning you!
                            You'll [b]never[/b] be [b]his[/b] slave!
                            Heck, you'll never be [b]anyone[/b]'s slave!
                            You're going to escape the first chance you get, and there's [b]nothing[/b] Fenrir can do to stop you.
                            And if the wolf so much as lays a hand on you, you'll tell the caravan master,
                            and the human'll yank the [b]big bitch[/b] that the bandit is back into submission in [b]no time[/b]!
                        [/p]
                        [p]
                            You find yourself panting slightly, your angry tantrum having left you out of breath.
                            The look on the canine's face transitions rapidly from disbelief, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin.
                            "[color=gblue]Is that all?
                            You know, you could have just said [i]no[/i].
                            Anyway, suit yourself.
                            The [b]hard way[/b] it is.[/color]"
                            [i]Oh dear.[/i]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\insult\SlaveNoonTwoBadInsult.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\decline\SlaveNoonTwoBadDecline.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.DECLINE;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badDecline;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.gagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And you don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to [b]kill you[/b] all he'd like.
                            At least that way, you won't have to be his [b]slave[/b] for the rest of your undoubtedly [i]miserable[/i] life.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said he was going to put his underwear into your mouth,
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            Answering Fenrir's stern gaze with a determined glare of your own,
                            you firmly shake your head no, and take a step back.
                            The look on his face transitions rapidly from disbelief, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin.
                            "[color=gblue]Defiant to the very end, huh?
                            Suit yourself.
                            The [b]hard way[/b] it is.[/color]"
                            [i]Oh dear.[/i]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    /**
     * Skips choice generation and immediately continues.
     */
    function skipChoice() {
        subController.continue();
        return "";
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += autoContinue ? skipChoice() : buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued() || autoContinue) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\decline\SlaveNoonTwoBadDecline.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\nothing\SlaveNoonTwoBadNothing.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadNothing(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var reqController = ctrl.blackmail;
    var subController = ctrl.preGag;
    var changeController = ctrl.badNothing;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.gagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, there'll be [b]hell[/b] to pay.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And you don't want that.
                        [/p]
                        [p]
                            You find yourself locked in mental conflict,
                            internally debating on whether or not you should accept the wolf's offer.
                            The question the canine has posed is not an easy one.
                            Ultimately, it boils down to whether you want to live in agony,
                            or accept the sweet mercy of [b]death[/b].
                            Being a kobold, philosophy was never your strong suit.
                            You simply [i]lack[/i] the mental capacity needed to think something like this through.
                        [/p]
                        [p]
                            Why couldn't he have just grabbed your head and shoved you into his nuts?!
                            That would have made things [b]so[/b] much easier.
                            That way, your body and your natural instincts could have made this decision for you.
                            Fenrir seems to be getting impatient, but you haven't reached a conclusion yet.
                            Part of you wants to submit.
                            You're scared of what might happen if you don't.
                            But doing this means forsaking whatever dignity you have left.
                            And you can't do that.
                            Not out of your own volition, at least.
                        [/p]
                        [p]
                            You fail to heed the lupine's request.
                            The look on his face transitions rapidly from boredom, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin.
                            "[color=gblue]Not going to do it, huh?
                            Suit yourself.
                            The [b]hard way[/b] it is.[/color]"
                            [i]Oh dear.[/i]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\nothing\SlaveNoonTwoBadNothing.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\SlaveNoonTwoBadOffer.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoBadOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.blackmail;
    var changeController = ctrl.blackmail;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";
    var fifthId = arguments.callee.name + "ButtonFive";
    var sixthId = arguments.callee.name + "ButtonSix";

    var firstNext = new SlaveNoonTwoBadNothing(ctrl);
    var secondNext = new SlaveNoonTwoBadDecline(ctrl);
    var thirdNext = new SlaveNoonTwoBadInsult(ctrl);
    var fourthNext = new SlaveNoonTwoBadAttack(ctrl);
    var fifthNext = new SlaveNoonTwoBadReluctant(ctrl);
    var sixthNext = new SlaveNoonTwoBadEager(ctrl);

    var firstChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var secondChoice = SlaveNoonTwoOfferChoice.DECLINE;
    var thirdChoice = SlaveNoonTwoOfferChoice.INSULT;
    var fourthChoice = SlaveNoonTwoOfferChoice.ATTACK;
    var fifthChoice = SlaveNoonTwoOfferChoice.RELUCTANT;
    var sixthChoice = SlaveNoonTwoOfferChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.blackmailed = true;

        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var enjoyed = global.kobold.history.shared.enslavement.captureEnjoyed;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;
        var nameKnown = global.kobold.history.shared.enslavement.nightOne.nameStated;
        var dick = ctrl.misc.dick();
        var name = ctrl.misc.name();

        var toReturn = ``;

        if (ctrl.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            After grumbling something about how they should really make these carts a bit bigger, a smirk forms on his muzzle.
                            "[color=gblue]Already up and about, are you?
                            ${!bindings ? `[i]Impressive[/i].` : `[i]Good[/i].`}
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            "[color=gblue]Face away, slave.
                            Let me get that rope off of you.[/color]"
                            While you don't really [i]want[/i] to [b]turn around[/b] for the fully naked lupine,
                            the premise of having your hands freed sounds too good to pass up.
                            Besides, he's clearly [i]not[/i] aroused, so you doubt he'll [i]abuse[/i] the situation.
                        [/p]
                        [p]
                            Keeping your wary eyes on the wolf for as long as you can manage, you slowly turn your back towards him.
                            With a few heavy steps, the canine approaches you from behind, the wood creaking underneath his broad footpaws.
                            He comes to a halt directly behind you, but is nice enough to leave half a foot orso in between your body and his.
                            The bandit chief reaches for your wrists, still bound behind your back, and with a simple [b]slice[/b] of a single claw,
                            he severs the cord keeping your hands together.
                        [/p]
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After giving you a moment to enjoy your newfound freedom, the well-built man grabs your shoulder,
                            and turns your body around once more, your muzzle ending up mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            I assumed he caved your head in because he [b]felt[/b] like it.
                            I know I sure did, after last night.[/color]"
                            You frown at the thought of being beaten by the bandit.
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most valuable[/i] little slave, now didn't he?[/color]"
                        [/p]
                        [p]
                            You can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let's have a look.[/color]"
                            the canine continues, crossing the distance between you with a few heavy steps, coming to rest about half a foot away from you,
                            your muzzle mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Acting like it's no big deal, he grabs your head and tilts it downwards,
                            nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }

        } else {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            He casts his gaze downwards, staring at you like a disgruntled parent would at their child.
                            After grumbling something about how they should really make these carts a bit bigger, a faint smirk forms on his muzzle.
                            "[color=gblue]Rough night, huh?[/color]"
                            A rhetorical question.
                        [/p]
                        [p]
                            With a few heavy steps, the canine approaches your downed frame, the wood creaking underneath his broad footpaws.
                            Grabbing you by the back of your neck, he hoists you upright.
                            ${bindings ? `Reaching behind you, the wolf then speedily snaps the length of rope binding your hands together.` : ``}
                            "[color=gblue]On your feet.
                            There we go.
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After enjoying your newfound freedom for a moment, you tilt your muzzle upwards,
                            only to find yourself mere inches away from the lupine's naked groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            I assumed he caved your head in because he [b]felt[/b] like it.
                            I know I sure did, after last night.[/color]"
                            You frown at the thought of a remorseless bandit hitting you [i]for fun[/i].
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most valuable[/i] little slave, now didn't he?[/color]"
                        [/p]
                        [p]
                            While you hate the way it was worded, you can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let's have a look.[/color]"
                            the canine continues.
                            Acting like it's no big deal, he grabs your head and tilts it downwards once more,
                            tugging you a little closer, nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }
        }

        if (!nameKnown) {
            toReturn += `[p]
                            "[color=gblue]I had a few of my men ask around during the night.
                            The forest has loose lips, if you know where to pry.[/color]"
                            Huh?
                            He sent out [i]spies[/i]?
                            "[color=gblue]${name}.
                            That's your name, right?[/color]"
                            You stare up at the lupine in amazement and disbelief.
                            Barely [b]anyone[/b] around here knows your name.
                            He chuckles.
                            "[color=gblue]It fits you.[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            The wolf moves one of his hands to his groin.
                            He boldly, brazenly and crudely cups the hefty, furred nuts that swing underneath his thick sheath,
                            propping them forwards as if to [i]entice[/i] you.
                            "[color=gblue]Look, ${name}, you acted like a real [b]pest[/b] yesterday.
                            ${fucked ? `In the forest, ${enjoyed ? `you sounded like you'd make a good slave,
                            but then when we got to the camp, you showed your true colors.` : `I had to [b]force[/b] myself upon you,
                            and then when we got back to camp, you acted all uppity.`}` : `First you blueballed me in the forest,
                            and then you failed to obey some simple commands in front of the caravan master.`}
                            You embarrassed me in front of that [b]moronic human[/b].
                            And that's not something I can appreciate.[/color]"
                        [/p]
                        [p]
                            You become aware that, in his free hand, the canine is holding a rope, and something you can't quite make out.
                            Some kind of [i]fabric[/i]?
                            "[color=gblue]From the moment you ran away,
                            I [b]knew[/b] you were different from all the other kobolds.
                            Instead of being [b]meek[/b] and [b]compliant[/b], you're [b]rebellious[/b] and [b]uncooperative[/b].
                            You remind me of my son.
                            But unlike him, I [i]can[/i] wring [b]your[/b] neck without repercussions.[/color]"
                        [/p]
                        [p]
                            Starting to think that Fenrir came here to [b]hang[/b] you with that rope,
                            you somewhat begin to panic.
                            "[color=gblue]I can make your life [b]a lot[/b] easier, you know.
                            I can bring you some leftovers to eat at night,
                            I can tell the gang not to inflict too much [i]permanent[/i] damage on you,
                            I might even be able to convince them that you'd be better off [b]keeping[/b] your teeth.[/color]"
                        [/p]
                        [p]
                            Hardly reassuring benefits, but you're [b]very[/b] certain that even those small [i]favors[/i] have a [b]price[/b].
                            Bandits like the wolf never hand out [i]freebies[/i].
                            "[color=gblue]Let's face the facts here.
                            That [b]fat fuck[/b] thinks he can [i]sell[/i] you.
                            But both you and me know that there's [b]plenty[/b] of slaves to go around.
                            It's an [i]oversaturated[/i] market.[/color]"
                            Fancy words, for a brigand.
                            Then again, he [i]is[/i] their leader.
                            "[color=gblue]You aren't the best product around, either.
                            People would much rather have a well-trained servant than an uppity [b]${dick ? `jerk` : `cunt`}[/b].
                            And, as you've no-doubt overheard, the caravan master only has two tries to auction you off.
                            After that, you'll be [b]mine[/b].[/color]"
                        [/p]
                        [p]
                            You repress the urge to ask the lupine about the rope.
                            You sense that he's slowly getting to that.
                            "[color=gblue]I won't lie.
                            You're going to be fucked, gangbanged, spitroasted and ran a train on by every single last member of my group.
                            Including the dog.
                            We're going to beat you, defile you in every way possible,
                            and make sure that nobody else will even [b]want[/b] you after we're done.
                            This [b]is[/b] going to happen, whether you like it or not.
                            But if you play along, then things don't [b]need[/b] to get [i]out of hand[/i].
                            If you stay unwilling, well...
                            Let's just say you won't be leaving our company alive.
                            And it won't be a pretty death, either.[/color]"
                        [/p]
                        [p]
                            You get the feeling he's not kidding about that threat.
                            In fact, Fenrir seems [b]dead serious[/b] about all of this.
                            He stares into your eyes, probing your reaction,
                            giving you a moment to process all of this, before resuming his long-winded speech.
                            "[color=gblue]On top of all of this,
                            since you acted so piss-poorly yesterday,
                            the caravan master has instructed me to gag your pretty little mouth,
                            so you don't go insulting buyers during the auction.[/color]"
                        [/p]
                        [p]
                            The wolf unfurls his hand, revealing that the thing he was clutching was a garment.
                            Underwear?
                            "[color=gblue]We don't carry any ballgags,
                            and the dog didn't want to let go of its favorite toy, so yeah.
                            This is the pair I wore yesterday, when [b]you[/b] made me run halfway through the forest.
                            ${fucked ? `Still has the dried spunk on it from when I fucked your tight little ${dick ? `ass` : `slit`}, even.` : ``}[/color]"
                        [/p]
                        [p]
                            Wait a minute, he isn't [i]actually[/i] considering using his sweaty briefs as a gag, is he?
                            He [b]must[/b] be bluffing, right?
                            "[color=gblue]I'm going to put this as simple as I can,
                            so even a dumb kobold like yourself can understand.
                            I want you to [b]submit[/b] to me.
                            If you don't, I'm going to make your life a living [b]hell[/b] from now on.
                            And I'll start by [b]shoving[/b] my well-worn underwear so far down your throat you'll barely be able to [b]breathe[/b].
                            Understand?[/color]"
                        [/p]
                        [p]
                            Awestruck and more than a little terrified of the consequences, you give Fenrir a small nod.
                            "[color=gblue]Good.
                            All I want is for you to recognize me as your new master.
                            I won't make you say it.
                            I know you're far too [i]proud[/i] for that.
                            Instead, just give my balls a single [b]good morning kiss[/b],
                            and then we can forget all about this whole gag thing.[/color]"
                        [/p]
                        [p]
                            As if to accentuate his statement, the wolf taps his furred nuts,
                            rolling his hips forwards ever so slightly to hold them a little closer to your mouth.
                            Part of your mind is honestly [i]considering[/i] Fenrir's offer.
                            Should both the auctions fail, at least you won't end up [b]dead[/b].
                            But then again, you plan on escaping long before you become the lupine's property.
                        [/p]
                        [p] 
                            "[color=gblue]Nobody has to know.
                            This'll be between [b]you[/b] and [b]me[/b].
                            A small peck is all I ask for.
                            A simple [b]sign[/b] of [b]submission[/b].
                            So what'll it be, slave?
                            Are we going to do this the [i]easy[/i] way, or the [b]hard[/b] way?[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 190px;">Do nothing</button>`;

        var tooltip = global.parser.parse(`Remain in place. Do not act. If you don't do anything, you can't do something wrong.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 190px;">Decline</button>`;

        var tooltip = global.parser.parse(`You don't want to get anywhere [b]near[/b] the wolf's loins.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 190px;">Insult</button>`;

        var tooltip = global.parser.parse(`Who the hell does Fenrir think he is?! Tell him to fuck off.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 190px;">Attack</button>`;

        var tooltip = global.parser.parse(`Charge the wolf! Freedom or death!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 145px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFifthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fifthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fifthId}" ${disabled} style="width: 190px;">Reluctantly kiss</button>`;

        var tooltip = global.parser.parse(`Ugh. Do you [i]really[/i] have to do this?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSixthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === sixthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${sixthId}" ${disabled} style="width: 190px;">Eagerly kiss</button>`;

        var tooltip = global.parser.parse(`Sweaty wolf nuts are to die for!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 225px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildFourthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFifthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSixthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId), $("#" + fifthId), $("#" + sixthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFifthListener() {
        $("#" + fifthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fifthChoice);
            loadNextPart(fifthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSixthListener() {
        $("#" + sixthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(sixthChoice);
            loadNextPart(sixthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        part += fifthNext.build();
        part += sixthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();
        fifthNext.registerListeners();
        sixthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
        registerFifthListener();
        registerSixthListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\bad\SlaveNoonTwoBadOffer.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodFemPlus.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodFemPlus(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoGoodPotionChoice.FEMPLUS;
    var reqController = ctrl.potion;
    var subController = ctrl.preOutside;
    var changeController = ctrl.femPlus;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.outside;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.tookFemPlus = true;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            You've steered clear of [i]body-altering[/i] drugs so far,
                            partly because you like yourself the way you are,
                            and partly because you've never really had the [i]money[/i] to buy one.
                            Now that an opportunity is presenting itself, however,
                            you can't say you're not a teensy bit [i]interested[/i].
                            You might like your body even [b]better[/b] with a few [i]enhancements[/i].
                            And you doubt you'll ever get a chance like this again.
                        [/p]
                        [p]
                            After a bit of mental deliberation, you gingerly reach out for the [color=pink][b]pink[/b][/color] bottle.
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}.
                            This should make you more of a [i]woman[/i]${dick ? `, if at the cost of some masculinity` : ``}.
                            "[color=gblue]Girl juice, huh? Good choice. Drink up.[/color]"
                        [/p]
                        [p]
                            You've thought about this plenty.
                            Perhaps even considered it once or twice.
                            But you never would have believed that the opportunity would have presented itself so [i]casually[/i].
                            You didn't have to [b]steal[/b] the potion, or [b]beg[/b] Seki for one.
                            While Fenrir may or may not realize it, this [i]present[/i] means a lot more to you than he thinks.
                            Plus you know these concoctions don't come cheap.
                            Maybe he's not that bad of a person after all.
                            Or perhaps he hopes it'll make you [b]sell[/b] for more.
                        [/p]
                        [p]
                            You pop the lid off the potion, and gulp down its contents.
                            The rather watery liquid tastes like an odd mixture of strawberries and milk.
                            The moment you swallow the first mouthful, you can already feel the stuff beginning to affect your body.
                        `;
        if (dick) {
            toReturn += `   Your member stirs within your loins, tangibly growing smaller,
                            your cockslit becoming a lot more [b]roomy[/b].
                            After a few satisfying seconds, the effects come to an end.`;
        } else {
            toReturn += `   Your breasts tingle and throb, visibly growing bigger.
                            Your upper chest feels heavier with every passing second, until finally,
                            after a few satisfying seconds, the effects to an end.`;
        }

        toReturn += `   [/p]
                        [p]
                            [c]
                                [b]You have grown more feminine.[/b]
                            [/c]
                        [/p]
                        [p]
                            "[color=gblue]You look a lot better already.[/color]" comments the wolf.
                            You can't help but [i]blush[/i] a little.
                            You [b]do[/b] look [i]prettier[/i] than before.
                            And it's all thanks to Fenrir.
                            ${eager ? `You are going to [b]love[/b] being his slave.` : `The two of you may not see eye to eye,
                            but maybe being his [i]slave[/i] won't be so bad after all.
                            Then again, this might have all been a [b]trick[/b] to get you to trust him more.
                            With bandits, you can never know for sure.`}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodFemPlus.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodMPlus.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodMPlus(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoGoodPotionChoice.MPLUS;
    var reqController = ctrl.potion;
    var subController = ctrl.preOutside;
    var changeController = ctrl.mPlus;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.outside;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.tookMPlus = true;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            You've steered clear of [i]body-altering[/i] drugs so far,
                            partly because you like yourself the way you are,
                            and partly because you've never really had the [i]money[/i] to buy one.
                            Now that an opportunity is presenting itself, however,
                            you can't say you're not a teensy bit [i]interested[/i].
                            You might like your body even [b]better[/b] with a few [i]enhancements[/i].
                            And you doubt you'll ever get a chance like this again.
                        [/p]
                        [p]
                            After a bit of mental deliberation, you gingerly reach out for the [color=blue][b]blue[/b][/color] bottle.
                            ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}.
                            This should make you more of a [i]man[/i]${dick ? `` : `, if at the cost of some femininity`}.
                            "[color=gblue]Boy juice, huh? Good choice. Drink up.[/color]"
                        [/p]
                        [p]
                            You've thought about this plenty.
                            Perhaps even considered it once or twice.
                            But you never would have believed that the opportunity would have presented itself so [i]casually[/i].
                            You didn't have to [b]steal[/b] the potion, or [b]beg[/b] Seki for one.
                            While Fenrir may or may not realize it, this [i]present[/i] means a lot more to you than he thinks.
                            Plus you know these concoctions don't come cheap.
                            Maybe he's not that bad of a person after all.
                            Or perhaps he hopes it'll make you [b]sell[/b] for more.
                        [/p]
                        [p]
                            You pop the lid off the potion, and gulp down its contents.
                            The rather watery liquid tastes like blueberries.
                            The moment you swallow the first mouthful, you can already feel the stuff beginning to affect your body.
                        `;
        if (dick) {
            toReturn += `   Your member stirs within your loins, tangibly growing larger,
                            your cockslit becoming a lot more [b]cramped[/b].
                            After a few satisfying seconds, the effects come to an end.`;
        } else {
            toReturn += `   Your breasts tingle and throb, retracting into your chest, visibly growing smaller.
                            Your upper chest feels lighter with every passing second, until finally,
                            after a few satisfying seconds, the effects to an end.`;
        }

        toReturn += `   [/p]
                        [p]
                            [c]
                                [b]You have grown more masculine.[/b]
                            [/c]
                        [/p]
                        [p]
                            "[color=gblue]You look a lot better already.[/color]" comments the wolf.
                            You can't help but [i]blush[/i] a little.
                            You [b]do[/b] look a bit more [i]handsome[/i] than before.
                            And it's all thanks to Fenrir.
                            ${eager ? `You are going to [b]love[/b] being his slave.` : `The two of you may not see eye to eye,
                            but maybe being his [i]slave[/i] won't be so bad after all.
                            Then again, this might have all been a [b]trick[/b] to get you to trust him more.
                            With bandits, you can never know for sure.`}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodMPlus.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodNeither.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodNeither(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoGoodPotionChoice.NEITHER;
    var reqController = ctrl.potion;
    var subController = ctrl.preOutside;
    var changeController = ctrl.neither;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.outside;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var knockedOut = global.kobold.history.shared.enslavement.nightOne.knockedOut;
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var toReturn = `[p]
                            You've steered clear of [i]body-altering[/i] drugs so far,
                            partly because you like yourself the way you are,
                            and partly because you've never really had the [i]money[/i] to buy one.
                            Now that an opportunity is presenting itself, however,
                            you can't say you're not a teensy bit [i]interested[/i].
                            You might like your body even [b]better[/b] with a few [i]enhancements[/i].
                            But that's a [b]dangerous[/b] road to go down.
                        [/p]
                        [p]
                            You've thought about this plenty.
                            Perhaps even considered it once or twice.
                            But now that the opportunity has presented itself,
                            you somehow don't feel very inclined to take it.
                            Besides, you're not even sure that's [i]actually[/i]
                            ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}
                            and 
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}
                            in those bottles.
                            Who knows what the wolf put in them?
                        [/p]
                        [p]
                            After a bit of mental deliberation, you decide not to take either potion.
                            You give Fenrir an unhappy look, and shake your head no.
                            "[color=gblue]Neither?
                            Picky little thing, aren't you?
                            Well, suit yourself.
                            Don't expect me to hang on to these until you change your mind, though.[/color]"
                        [/p]
                        [p]
                            While you didn't end up [i]accepting[/i] his gift,
                            you can't help but feel slightly [i]grateful[/i] for the canine to offer it in the first place.
                            You know those concoctions don't come cheap, and you assume he went out of his way to get them for you.
                            A nice gesture, although he could have [b]asked[/b] you first.
                            But you [b]do[/b] suppose you were ${knockedOut ? `unconscious` : `asleep`} until not too long ago.
                            ${eager ? `` : `Then again, this entire ordeal might have all been a [b]trick[/b] to get you to trust him more.
                            With bandits, you can never know for sure.`}
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodNeither.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodPotion.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodPotion(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preGag;
    var subController = ctrl.potion;
    var changeController = false;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstNext = new SlaveNoonTwoGoodNeither(ctrl);
    var secondNext = new SlaveNoonTwoGoodMPlus(ctrl);
    var thirdNext = new SlaveNoonTwoGoodFemPlus(ctrl);

    var firstChoice = SlaveNoonTwoGoodPotionChoice.NEITHER;
    var secondChoice = SlaveNoonTwoGoodPotionChoice.MPLUS;
    var thirdChoice = SlaveNoonTwoGoodPotionChoice.FEMPLUS;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var eager = global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager;
        var name = ctrl.misc.name();
        var toReturn = `[p]
                            Your private business concluded,
                            the wolf crudely grabs you by the wrist, and begins to tug you towards the cart's open entryway.
                            "[color=gblue]You and I have business to attend to.
                            In case you hadn't realized yet: you're being [b]sold[/b].
                            [b]Today[/b].
                            And it's [b]my[/b] job to ensure you look at least [i]somewhat[/i] presentable.[/color]"
                        [/p]
                        [p]
                            He's not taking [i]no[/i] for an answer,
                            yanking you forwards hard enough to nearly pull your arm off.
                            Guess he's in a rush, despite wasting time with his [i]proposition[/i].
                            You don't resist much, instead trying to keep up with his pace as best you can.
                            A few steps and a small hop later, you find yourself in the outside world once more.
                        [/p]`;

        if (ctrl.arrival.get() !== SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            You recognize this area.
                            You've been here before.
                            It's a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]`;
        }

        toReturn += `   [p]
                            Luckily, the caravan stopped at the outskirts of the settlement,
                            your nudity not made public quite yet.
                            If it's any [i]consolation[/i], your captor is every bit as naked as you are.
                            Walking alongside your prison carriage's exterior,
                            whilst dragging you with him, the canine comes to an unexpected halt,
                            your face ending up unpleasantly [i]bumping[/i] into his bare rear.
                            Reaching down, he fetches a small, brown satchel, conveniently concealed directly underneath the cart.
                        [/p]
                        [p]
                            "[color=gblue]I almost forgot.
                            I've prepared a [i]treat[/i] for you.
                            A little [b]present[/b], to help your odds at the auction.
                            I have no doubt you'll be making back every coin I spent on these and more.[/color]"
                            You don't know whether you should feel [i]flattered[/i], or [b]insulted[/b].
                            "[color=gblue]If not through being auctioned off,
                            then through all the gold I'll be saving from fucking you instead of visiting a brothel.[/color]"
                            Definitely [b]${eager ? `flattered` : `insulted`}[/b].
                        [/p]
                        [p]
                            Rummaging through the tiny bag, Fenrir produces a pair of oddly shaped bottles, along with a large, ominous-looking syringe.
                            ${global.kobold.inventory.createItemWithTooltip(new FemPlus(), true)}
                            and ${global.kobold.inventory.createItemWithTooltip(new mPlus(), true)}.
                            Seki makes that sort of stuff.
                            "[color=gblue]Well, here they are.
                            These things are expensive,
                            so you only get [b]one[/b].
                            Well, ${name}, which'll it be?
                            The blue one, or the pink one?[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Neither</button>`;

        var tooltip = global.parser.parse(`You don't need to change.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>mPlus</button>`;

        var tooltip = global.parser.parse(`Maybe you could stand to be a bit more [i]masculine[/i].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>FemPlus</button>`;

        var tooltip = global.parser.parse(`The more girly, the better.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var SlaveNoonTwoGoodPotionChoice = {
    NEITHER: 1,
    MPLUS: 2,
    FEMPLUS: 3
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\potion\SlaveNoonTwoGoodPotion.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\eager\SlaveNoonTwoGoodEager.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodEager(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.EAGER;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodEager;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.kissedBallsEager = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to him asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something.
                            And for some reason, that kind of [i]arouses[/i] you.
                        [/p]
                        [p]
                            Becoming the big wolf's [b]plaything[/b] is an alluring prospect by itself.
                            Combined with his tempting proposition,
                            and the equally enticing big, furred orbs swinging underneath his plump sheath,
                            Fenrir's offer is practically [b]irresistible[/b] to you.
                            How could [b]anyone[/b] be faced with such a [b]hunk[/b] of a man,
                            and [b]not[/b] want to submit to him completely?
                            Should you end up not being [i]bought[/i],
                            then you'll get to live a comfortable life with your new lupine [i]master[/i],
                            and his group.
                        [/p]
                        [p]
                            Noticing the bandit growing impatient,
                            you lustily lick your lips and begin to inch your face closer to his balls.
                            The strong scent of canine masculinity intensifies,
                            male pheromones [b]wafting[/b] liberally from Fenrir's loins,
                            [b]clogging[/b] your nostrils, [b]saturating[/b] every breath you take.
                            You greedily huff the olfactory nectar, savoring every lungful,
                            wishing you could keep your face buried in his balls [b]forever[/b].
                        [/p]
                        [p]
                            While your own need is rising, you aren't about to get [i]distracted[/i] by it.
                            You set out to [i]please[/i] your master, and you intend to [b]exceed[/b] his every expectation.
                            As your snout sinks into the grey fur covering the wolf's sack,
                            you pucker your lips, and eagerly begin to plant kiss after kiss atop of his nuts.
                            Taking one of his balls into your mouth slightly, you gently suckle on it, just a little.
                            He groans in delight, his tense, authorative stand visibly relaxing.
                            [b]Excellent[/b].
                        [/p]
                        [p]
                            With Fenrir starting to mellow out, you up the intensity of your loving [b]admiration[/b].
                            Your tongue snakes out of your muzzle, your rampant kissing interrupted by occasional [b]licks[/b].
                            Before long, you find yourself outright [b]lapping[/b] along the coarse surface of the canine's sack,
                            wetting his fur with your saliva, enjoying the salty,
                            undeniably [b]masculine[/b] flavour even [b]despite[/b] the dried up sweat and the small bits of dirt and grime.
                        [/p]
                        [p]
                            The wolf begins to pant, his tail wagging excitedly.
                            Slowly, but surely, you work your way upwards, towards his sheath.
                            Right as you were about to goad his member from its slumber by kissing its resting place directly,
                            Fenrir suddenly presses his palm against your forehead, softly pushing you away.
                        [/p]
                        [p]
                            "[color=gblue]That's enough for now, you little [b]cocktease[/b].
                            Continue to act like that, and I might need to consider buying you myself,
                            to make sure nobody else gets to run off with that lovely muzzle of yours.[/color]"
                            Your captor takes a deep breath, seemingly washing the impure thoughts from his mind.
                            "[color=gblue]There'll be plenty of time for me to fuck your face later.
                            And since you like my balls so much,
                            you'll get to [b]worship[/b] them every single day, once you're finally [b]mine[/b].[/color]"
                            You can hardly wait.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\eager\SlaveNoonTwoGoodEager.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\reluctant\SlaveNoonTwoGoodReluctant.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodReluctant(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.RELUCTANT;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodReluctant;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.kissedBalls = true;
        var dick = ctrl.misc.dick();
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to him asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            And while you don't particularly enjoy the idea of becoming his [i]sex toy[/i],
                            right now, the long term benefits seem to [b]far[/b] outweigh the indignance of kissing his nuts a single time.
                        [/p]
                        [p]
                            You [b]really[/b] don't want to do this, but the wolf's offer is way too tempting to pass up on.
                            You'd rather give his sack a single, quick kiss,
                            than face the possibility of getting abused by his men for the rest of your life.
                            Should you end up not being able to escape, and not being [i]bought[/i],
                            then you'd prefer to stay on good terms with Fenrir instead of [i]upsetting him[/i].
                        [/p]
                        [p]
                            Noticing the bandit growing impatient, you roll your eyes and let out a defeated sigh.
                            Slowly, but steadily, you inch your face closer to his balls.
                            The strong scent of canine masculinity intensifies,
                            male pheromones [b]wafting[/b] liberally from Fenrir's loins,
                            [b]clogging[/b] your nostrils, [b]saturating[/b] every breath you take.
                            As your snout sinks into the fur covering his sack,
                            you pucker your lips, and plant a single, tender kiss right in between the wolf's large, dangling testicles.
                        [/p]
                        [p]
                            As soon as your half of the [i]bargain[/i] is complete,
                            you immediately pull back from Fenrir's groin.
                            You turn your face to the side,
                            deeply breathing in some less [i]heady[/i] air,
                            while wiping your tongue and your snout both, to symbolize your disdain.
                            You consider [i]spitting[/i] for dramatic effect,
                            but you figure you might have to spend another night in this cart,
                            so you'd rather not filthy the floor.
                        [/p]
                        [p]
                            "[color=gblue]Good ${dick ? `boy` : `girl`}.[/color]" he patronizes,
                            his voice heavy with smugness.
                            "[color=gblue]The sooner you get used to that taste, the better.
                            You'll be [b]kissing[/b] my [b]nuts[/b] every morning, once you're finally [b]mine[/b].[/color]"
                            Arrogant prick.
                            But, while you didn't enjoy it one bit, at least the lupine seems somewhat [i]pleased[/i] with your reluctant compliance.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\reluctant\SlaveNoonTwoGoodReluctant.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\attack\SlaveNoonTwoGoodAttack.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodAttack(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.ATTACK;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodAttack;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.attacked = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to have his men [b]violate[/b] you all he'd like.
                            At least that way, you won't have to be his [b]personal[/b] fucktoy.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said that thing about the [i]dog[/i],
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            Anger wells up inside of you.
                            You aren't backing down.
                            Not this time.
                            In fact, with Fenrir's nude groin so close to your face, you spot an [i]opportunity[/i].
                            You could easily [b]bite down[/b] on his most sensitive bits,
                            and then, while he's writhing in pain, you can make a quick getaway.
                            [i]Excellent idea.[/i]
                        [/p]
                        [p]
                            Staring upwards at the lupine with a mischievous grin on your face,
                            you open your muzzle wide, and slowly approach his hefty balls with your snout.
                            Instead of going in for a kiss, you bring your sharp teeth to bear, 
                            intent on [b]chomping[/b] off a piece of the bandit's nutsack.
                            The wolf is not as ignorant as you believed him to be, however.
                            Or maybe you were too [i]eager[/i] to properly hide your true intentions.
                            Right before your fangs can sink into his loins,
                            he slams your forehead with the flat of his large palm,
                            harshly pushing you backwards, your muzzle snapping shut,
                            catching nothing but [i]air[/i] in between your teeth.                       
                        [/p]
                        [p]
                            Surprised by your plan's failure, you are suddenly filled with rage.
                            You close your eyes and begin to wildly [b]flail around[/b],
                            swinging your claws about every which way, hoping you'll strike a lucky hit.
                            Fenrir keeps you at bay by simply holding you by your forehead,
                            keeping you at arm's length like a parent would its unruly child.
                            That is, after all, what you are acting like: a [b]child[/b],
                            lashing out because it did something bad, one that doesn't [i]want[/i] to face the consequences of its actions.
                        [/p]
                        [p]
                            After nearly half a minute of hitting nothing but air, your angry, impotent rampage slowly comes to an end.
                            You open your eyes once more, a few frustrated tears rolling down your cheeks.
                            All the while, a sadistic grin is plastered across the canine's face.
                            "[color=gblue]You could have just said [i]no[/i], instead of [b]embarrassing[/b] yourself.
                            I'll let it slip this time, because you're new to being a slave and all.
                            Try to hurt me again, though, I'll return the favor.
                            And I can assure you [b]my[/b] fangs are [b]much[/b] sharper than yours.
                            Anyway, you've made your choice.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\attack\SlaveNoonTwoGoodAttack.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\insult\SlaveNoonTwoGoodInsult.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodInsult(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.INSULT;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodInsult;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.insulted = true;
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to have his men [b]violate[/b] you all he'd like.
                            At least that way, you won't have to be his [b]personal[/b] fucktoy.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said that thing about the [i]dog[/i],
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            You answer Fenrir's gaze with a determined glare of your own.
                            Anger wells up inside of you.
                            You aren't backing down.
                            Not this time.
                            What gives [b]him[/b] the right to push you around?!
                            You take in a deep breath, raise your voice, and let loose an angry [b]tirade[/b] of insults.
                            He's a filthy [b]slaver[/b].
                            A pathetic [b]loser[/b] that couldn't carve out an honest life for himself,
                            and is now stuck [b]bullying[/b] innocent kobolds like yourself!
                            You know you're not [i]really[/i] innocent, but it seemed like an [i]apt[/i] choice of words.
                        [/p]
                        [p]
                            Furthermore, he's [b]wrong[/b] about nobody wanting to buy you.
                            You're a [b]good[/b] kobold, and there'll surely be [b]dozens[/b] of people lining up to get a [b]chance[/b] at owning you!
                            You'll [b]never[/b] be [b]his[/b] slave!
                            Heck, you'll never be [b]anyone[/b]'s slave!
                            You're going to escape the first chance you get, and there's [b]nothing[/b] Fenrir can do to stop you.
                            And if the wolf so much as lays a hand on you, you'll tell the caravan master,
                            and the human'll yank the [b]big bitch[/b] that the bandit is back into submission in [b]no time[/b]!
                        [/p]
                        [p]
                            You find yourself panting slightly, your angry tantrum having left you out of breath.
                            The look on the canine's face transitions rapidly from disbelief, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin, probably trying to hide his true feelings.
                            "[color=gblue]You could have just said [i]no[/i].
                            This was a one time offer, and a good one at that.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.
                            And you better start watching your mouth.
                            [b]Or else[/b].[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\insult\SlaveNoonTwoGoodInsult.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\decline\SlaveNoonTwoGoodDecline.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodDecline(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.DECLINE;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodDecline;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll just lead to Fenrir asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            Consequences be damned, you're [b]not[/b] doing this.
                            He can threaten to have his men [b]violate[/b] you all he'd like.
                            At least that way, you won't have to be his [b]personal[/b] fucktoy.
                            While you [i]are[/i] sort of still frightened of what his gang might do to you,
                            and you [b]definitely[/b] hope he was [b]bluffing[/b] when he said that thing about the [i]dog[/i],
                            you think you've found the courage to stand up to the big, imposing predator.
                        [/p]
                        [p]
                            Answering Fenrir's stern gaze with a determined glare of your own,
                            you firmly shake your head no, and take a step back.
                            The look on his face transitions rapidly from disbelief, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin, probably trying to hide his true feelings.
                            "[color=gblue]Not going to do it, huh?
                            Suit yourself.
                            This was a one time offer, and a good one at that.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\decline\SlaveNoonTwoGoodDecline.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\nothing\SlaveNoonTwoGoodNothing.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodNothing(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var reqController = ctrl.offer;
    var subController = ctrl.preGag;
    var changeController = ctrl.goodNothing;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.notGagged;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            A million thoughts run through your head.
                            If you decline, you won't gain the wolf's favor.
                            But you are [b]very[/b] certain that [i]if[/i] you do this,
                            it'll undoubtedly lead to him asking [b]more[/b] and [b]more[/b] of you.
                            If you give in now, he'll keep pushing and pushing until you're his personal [b]concubine[/b] or something equally distasteful.
                            You don't want that.
                        [/p]
                        [p]
                            You find yourself locked in mental conflict,
                            internally debating on whether or not you should accept the wolf's offer.
                            The question the canine has posed is not an easy one.
                            Ultimately, it boils down to whether you want to please him,
                            and keep him as a friend,
                            or if you'd rather take your chances going at this alone.
                            The thing is: you don't know whether or not you [i]want[/i] a friend like Fenrir.
                            Especially not at the cost of your own pride.
                        [/p]
                        [p]
                            Why couldn't he have just grabbed your head and shoved you into his nuts?!
                            That would have made things [b]so[/b] much easier.
                            That way, your body and your natural instincts could have made this decision for you.
                            Fenrir seems to be getting impatient, but you haven't reached a conclusion yet.
                            Part of you wants to submit.
                            You're scared of what might happen if you don't.
                            But doing this means forsaking whatever dignity you have left.
                            And you can't do that.
                            Not out of your own volition, at least.
                        [/p]
                        [p]
                            You fail to heed the lupine's request.
                            The look on his face transitions rapidly from boredom, to anger, to something resembling a lack of understanding.
                            Finally, he settles on a sadistic grin, probably trying to hide his true feelings.
                            "[color=gblue]Not going to do it, huh?
                            Suit yourself.
                            This was a one time offer, and a good one at that.
                            If you're [b]lucky[/b], I might see fit to ask you again later.
                            But a little [i]kiss[/i] won't suffice next time.[/color]"
                            His words worry you far more than they should.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\nothing\SlaveNoonTwoGoodNothing.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoSimpleOffer.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoSimpleOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.offer;
    var changeController = ctrl.offer;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";
    var fifthId = arguments.callee.name + "ButtonFive";
    var sixthId = arguments.callee.name + "ButtonSix";

    var firstNext = new SlaveNoonTwoGoodNothing(ctrl);
    var secondNext = new SlaveNoonTwoGoodDecline(ctrl);
    var thirdNext = new SlaveNoonTwoGoodInsult(ctrl);
    var fourthNext = new SlaveNoonTwoGoodAttack(ctrl);
    var fifthNext = new SlaveNoonTwoGoodReluctant(ctrl);
    var sixthNext = new SlaveNoonTwoGoodEager(ctrl);

    var firstChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var secondChoice = SlaveNoonTwoOfferChoice.DECLINE;
    var thirdChoice = SlaveNoonTwoOfferChoice.INSULT;
    var fourthChoice = SlaveNoonTwoOfferChoice.ATTACK;
    var fifthChoice = SlaveNoonTwoOfferChoice.RELUCTANT;
    var sixthChoice = SlaveNoonTwoOfferChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.simpleOffer = true;

        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;
        var nameKnown = global.kobold.history.shared.enslavement.nightOne.nameStated;
        var dick = ctrl.misc.dick();
        var name = ctrl.misc.name();

        var toReturn = ``;

        if (ctrl.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            After grumbling something about how they should really make these carts a bit bigger, a smirk forms on his muzzle.
                            "[color=gblue]Already up and about, are you?
                            ${!bindings ? `[i]Impressive[/i].` : `[i]Good[/i].`}
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            "[color=gblue]Face away for a second.
                            Let me get that rope off of you.[/color]"
                            While you don't really [i]want[/i] to [b]turn around[/b] for the fully naked lupine,
                            the premise of having your hands freed sounds too good to pass up.
                            Besides, he's clearly [i]not[/i] aroused, so you doubt he'll [i]abuse[/i] the situation.
                        [/p]
                        [p]
                            Keeping your wary eyes on the wolf for as long as you can manage, you slowly turn your back towards him.
                            With a few heavy steps, the canine approaches you from behind, the wood creaking underneath his broad footpaws.
                            He comes to a halt directly behind you, but is nice enough to leave half a foot orso in between your body and his.
                            The bandit chief reaches for your wrists, still bound behind your back, and with a simple [b]slice[/b] of a single claw,
                            he severs the cord keeping your hands together.
                        [/p]
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After giving you a moment to enjoy your newfound freedom, the well-built man grabs your shoulder,
                            and turns your body around once more, your muzzle ending up mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            Heh.
                            I assumed he caved your head in because he [b]felt[/b] like it.[/color]"
                            You frown at the thought of a remorseless bandit hitting you [i]for fun[/i].
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most precious[/i] little lizard, now didn't he?[/color]"
                        [/p]
                        [p]
                            You can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let me have a look.[/color]"
                            the canine continues, crossing the distance between you with a few heavy steps, coming to rest about half a foot away from you,
                            your muzzle mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Acting like it's no big deal, he grabs your head and tilts it downwards,
                            nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }

        } else {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            He casts his gaze downwards, staring at you like a disgruntled parent would at their child.
                            After grumbling something about how they should really make these carts a bit bigger, a faint smirk forms on his muzzle.
                            "[color=gblue]Rough night, huh?[/color]"
                            A rhetorical question.
                        [/p]
                        [p]
                            With a few heavy steps, the canine approaches your downed frame, the wood creaking underneath his broad footpaws.
                            Grabbing you by the back of your neck, he hoists you upright.
                            ${bindings ? `Reaching behind you, the wolf then speedily snaps the length of rope binding your hands together.` : ``}
                            "[color=gblue]On your feet.
                            There we go.
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After enjoying your newfound freedom for a moment, you tilt your muzzle upwards,
                            only to find yourself mere inches away from the lupine's naked groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            Heh.
                            I assumed he caved your head in because he [b]felt[/b] like it.[/color]"
                            You frown at the thought of a remorseless bandit hitting you [i]for fun[/i].
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most precious[/i] little lizard, now didn't he?[/color]"
                        [/p]
                        [p]
                            You can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let me have a look.[/color]"
                            the canine continues.
                            Acting like it's no big deal, he grabs your head and tilts it downwards once more,
                            tugging you a little closer, nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }
        }

        if (!nameKnown) {
            toReturn += `[p]
                            "[color=gblue]I had a few of my men ask around during the night.
                            The forest has loose lips, if you know where to pry.[/color]"
                            Huh?
                            He sent out [i]spies[/i]?
                            "[color=gblue]${name}.
                            That's your name, right?[/color]"
                            You stare up at the lupine in amazement and disbelief.
                            Barely [b]anyone[/b] around here knows your name.
                            He chuckles.
                            "[color=gblue]It fits you.[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            The wolf moves one of his hands to his groin.
                            He boldly, brazenly and crudely cups the hefty, furred nuts that swing underneath his thick sheath,
                            propping them forwards as if to [i]entice[/i] you.
                            "[color=gblue]You've been a good ${dick ? `boy` : `girl`} so far, haven't you, ${name}?
                            At first, when I caught you, I thought you'd turn out to be a little [i]troublemaker[/i].
                            But you've proven me more than wrong.
                            I like that.[/color]"
                        [/p]
                        [p]
                            The canine licks his lips lustfully.
                            You hope he [b]isn't[/b] going to ask you to do what you [b]think[/b] he's going to ask of you.
                            "[color=gblue]From the moment ${fucked ? `I took your virginity` : `you told me you were a virgin`},
                            I [b]knew[/b] you were different from all the other kobolds.
                            Unlike the others, you are a [b]reasonable[/b] little creature.
                            You understand that not [i]all[/i] of life's problems can be solved through [b]violence[/b],
                            or by acting [b]uppity[/b] and [b]crying[/b] until you get your way.
                            I can respect that.[/color]"
                        [/p]
                        [p]
                            Oh boy.
                            You can [i]already[/i] tell where this is going, but your mind doesn't want to hear it.
                            You'd prefer to be blissfully ignorant until the words spill from Fenrir's own mouth.
                            "[color=gblue]I can make life [b]very[/b] easy for you, you know.
                            I can bring you some of the [b]good[/b] food at night,
                            I can tell the gang to [i]take it easy[/i] on you,
                            I can even make sure that [b]filthy[/b] human,
                            who I am [b]temporarily[/b] [i]indentured[/i] to,
                            won't lay even a [b]single[/b] hand on you.[/color]"
                        [/p]
                        [p]
                            A lot of benefits, but you're [b]very[/b] certain that all of this has a [b]price[/b].
                            Bandits like the wolf never hand out favors for [b]free[/b].
                            "[color=gblue]Let's face the facts here.
                            That [b]fat fuck[/b] thinks he can [i]sell[/i] you.
                            But both you and me know that there's [b]plenty[/b] of slaves to go around.
                            It's an [i]oversaturated[/i] market.[/color]"
                            Fancy words, for a brigand.
                            Then again, he [i]is[/i] their leader.
                            "[color=gblue]And, as you've no-doubt overheard, he only has two tries to auction you off.
                            After that, you'll be [b]mine[/b].[/color]"
                        [/p]
                        [p]
                            You repress the urge to tell the lupine to get to the point already.
                            It seems you've [i]placated[/i] him, and you'd hate to break his good demeanor by telling him to rush things along.
                            "[color=gblue]I won't lie.
                            You're going to be fucked, gangbanged, spitroasted and ran a train on by every single last member of my group.
                            Including the dog.
                            But that doesn't need to be a [i]bad[/i] thing.
                            If you play along, if you keep on being as nice as you've been thus far, then none of us will have any reason to treat you poorly.
                            And besides keeping us pleased, you won't have a thing in the world to worry about.
                            If you prove your worth, I might even see fit to [i]eventually[/i] consider [b]recruiting[/b] you, somewhere down the road.
                            Make you a [b]proper[/b] part of our band.[/color]"
                        [/p]
                        [p]
                            You don't get it.
                            Is Fenrir offering you a [i]job[/i]?
                            "[color=gblue]The Furskin Mountain-Crew could use a small and nimble thief like yourself.
                            And by the time we're [i]done[/i] with you, you'll be a [b]master[/b] of seduction and other [i]less common[/i] talents.[/color]"
                            You don't like the sound of that last part.
                            "[color=gblue]All I ask in return, is a simple sign of subservience.
                            You won't [i]officially[/i] be [b]my[/b] slave until the second auction fails,
                            but that doesn't mean we can't start our [i]friendship[/i] a little [i]early[/i], now does it?[/color]"
                        [/p]
                        [p]
                            You knew it.
                            The wolf may use fancy words and beat around the bush a lot, but in the end he's no better than a simple highwayman,
                            only instead of coercing money out of you, he's trying to extort your very [i]diginity[/i] itself.
                            "[color=gblue]So how about it, [b]friend[/b]?
                            All I want is a little good morning kiss.
                            Right on top of the balls that
                            ${fucked ? `squirted their contents all over your body` : `you denied release`} yesterday.[/color]"
                        [/p]
                        [p]
                            As if to accentuate his statement, the wolf taps his furred nuts,
                            rolling his hips forwards ever so slightly to hold them a little closer to your mouth.
                            Part of your mind is honestly [i]considering[/i] Fenrir's offer.
                            A life without worries [i]does[/i] seem [b]compelling[/b], to say the least.
                            And you [b]really[/b] don't want that human to get anywhere close to you.
                            But then again, you don't want to degrade yourself any more than you already have.
                            Besides, you plan on escaping long before you become the lupine's property.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 190px;">Do nothing</button>`;

        var tooltip = global.parser.parse(`Remain in place. Do not act. Let the canine draw his own conclusions.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 190px;">Decline</button>`;

        var tooltip = global.parser.parse(`You don't want to be anywhere [b]near[/b] the wolf's loins.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 190px;">Insult</button>`;

        var tooltip = global.parser.parse(`Who the hell does Fenrir think he is?! Tell him to get lost.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 190px;">Attack</button>`;

        var tooltip = global.parser.parse(`Fight the wolf. Freedom or death!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 145px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFifthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fifthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fifthId}" ${disabled} style="width: 190px;">Reluctantly kiss</button>`;

        var tooltip = global.parser.parse(`Ugh. Do you [i]really[/i] have to do this?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSixthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === sixthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${sixthId}" ${disabled} style="width: 190px;">Eagerly kiss</button>`;

        var tooltip = global.parser.parse(`You get to kiss sweaty wolf nuts and live a life of nonstop sex? You wish you'd met him earlier!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 225px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildFourthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFifthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSixthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId), $("#" + fifthId), $("#" + sixthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFifthListener() {
        $("#" + fifthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fifthChoice);
            loadNextPart(fifthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSixthListener() {
        $("#" + sixthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(sixthChoice);
            loadNextPart(sixthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        part += fifthNext.build();
        part += sixthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();
        fifthNext.registerListeners();
        sixthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
        registerFifthListener();
        registerSixthListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoSimpleOffer.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoMakeUpOffer.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoMakeUpOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.offer;
    var changeController = ctrl.offer;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";
    var fifthId = arguments.callee.name + "ButtonFive";
    var sixthId = arguments.callee.name + "ButtonSix";

    var firstNext = new SlaveNoonTwoGoodNothing(ctrl);
    var secondNext = new SlaveNoonTwoGoodDecline(ctrl);
    var thirdNext = new SlaveNoonTwoGoodInsult(ctrl);
    var fourthNext = new SlaveNoonTwoGoodAttack(ctrl);
    var fifthNext = new SlaveNoonTwoGoodReluctant(ctrl);
    var sixthNext = new SlaveNoonTwoGoodEager(ctrl);

    var firstChoice = SlaveNoonTwoOfferChoice.NOTHING;
    var secondChoice = SlaveNoonTwoOfferChoice.DECLINE;
    var thirdChoice = SlaveNoonTwoOfferChoice.INSULT;
    var fourthChoice = SlaveNoonTwoOfferChoice.ATTACK;
    var fifthChoice = SlaveNoonTwoOfferChoice.RELUCTANT;
    var sixthChoice = SlaveNoonTwoOfferChoice.EAGER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.noonTwo.makeUpOffer = true;

        var fucked = global.kobold.history.shared.enslavement.captureFucked;
        var enjoyed = global.kobold.history.shared.enslavement.captureEnjoyed;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;
        var nameKnown = global.kobold.history.shared.enslavement.nightOne.nameStated;
        var dick = ctrl.misc.dick();
        var name = ctrl.misc.name();

        var toReturn = ``;

        if (ctrl.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            After grumbling something about how they should really make these carts a bit bigger, a smirk forms on his muzzle.
                            "[color=gblue]Already up and about, are you?
                            ${!bindings ? `[i]Impressive[/i].` : `[i]Good[/i].`}
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            "[color=gblue]Face away for a second.
                            Let me get that rope off of you.[/color]"
                            While you don't really [i]want[/i] to [b]turn around[/b] for the fully naked lupine,
                            the premise of having your hands freed sounds too good to pass up.
                            Besides, he's clearly [i]not[/i] aroused, so you doubt he'll [i]abuse[/i] the situation.
                        [/p]
                        [p]
                            Keeping your wary eyes on the wolf for as long as you can manage, you slowly turn your back towards him.
                            With a few heavy steps, the canine approaches you from behind, the wood creaking underneath his broad footpaws.
                            He comes to a halt directly behind you, but is nice enough to leave half a foot orso in between your body and his.
                            The bandit chief reaches for your wrists, still bound behind your back, and with a simple [b]slice[/b] of a single claw,
                            he severs the cord keeping your hands together.
                        [/p]
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After giving you a moment to enjoy your newfound freedom, the well-built man grabs your shoulder,
                            and turns your body around once more, your muzzle ending up mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            Heh.
                            I assumed he caved your head in because he [b]felt[/b] like it.[/color]"
                            You frown at the thought of a remorseless bandit hitting you [i]for fun[/i].
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most precious[/i] little lizard, now didn't he?[/color]"
                        [/p]
                        [p]
                            You can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let me have a look.[/color]"
                            the canine continues, crossing the distance between you with a few heavy steps, coming to rest about half a foot away from you,
                            your muzzle mere inches away from his bare groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Acting like it's no big deal, he grabs your head and tilts it downwards,
                            nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }

        } else {
            toReturn += `[p]
                            The big wolf struggles to stand fully upright inside of your cell,
                            his head bumping against the ceiling.
                            He casts his gaze downwards, staring at you like a disgruntled parent would at their child.
                            After grumbling something about how they should really make these carts a bit bigger, a faint smirk forms on his muzzle.
                            "[color=gblue]Rough night, huh?[/color]"
                            A rhetorical question.
                        [/p]
                        [p]
                            With a few heavy steps, the canine approaches your downed frame, the wood creaking underneath his broad footpaws.
                            Grabbing you by the back of your neck, he hoists you upright.
                            ${bindings ? `Reaching behind you, the wolf then speedily snaps the length of rope binding your hands together.` : ``}
                            "[color=gblue]On your feet.
                            There we go.
                            You have a big day ahead of you.[/color]"
                        [/p]`;
            if (bindings) {
                toReturn += `
                        [p]
                            You clutch each of your wrists in turn, rubbing them to ease the minor ropeburn.
                            After enjoying your newfound freedom for a moment, you tilt your muzzle upwards,
                            only to find yourself mere inches away from the lupine's naked groin,
                            a whiff of its potent scent already reaching your nostrils.
                            Fenrir stares down at you, a lecherous look on his face.
                        [/p]`;
            } else {
                toReturn += `
                        [p]
                            "[color=gblue]So Guilliman [i]wasn't[/i] lying about you escaping your bindings.
                            Heh.
                            I assumed he caved your head in because he [b]felt[/b] like it.[/color]"
                            You frown at the thought of a remorseless bandit hitting you [i]for fun[/i].
                            "[color=gblue]Oh well.
                            It's not like he [b]needs[/b] full pay.
                            His family back home is rich as fuck.
                            Figure he's [i]rebelling[/i] against'em or something.
                            And he [b]did[/b] still damage my [i]most precious[/i] little lizard, now didn't he?[/color]"
                        [/p]
                        [p]
                            You can't help but sort of [i]agree[/i] with Fenrir on that last point.
                            There was absolutely [b]no[/b] reason for that horse to hit you.
                            Sure, you were planning to escape,
                            and you'd have bolted past him or tackled him or tried to [b]maim[/b] him if you hadn't frozen up,
                            but still.
                            What he did was plain [b]rude[/b].
                            He could have easily overpowered you [i]without[/i] using his club.
                        [/p]
                        [p]
                            "[color=gblue]Let me have a look.[/color]"
                            the canine continues.
                            Acting like it's no big deal, he grabs your head and tilts it downwards once more,
                            tugging you a little closer, nearly shoving your face into his crotch in the process.
                        [/p]
                        [p]
                            "[color=gblue]It's only a small [i]bruise[/i].
                            At worst, it'll swell up a bit.
                            If any of the buyers ask, tell them that's how you were captured.[/color]"
                        [/p]
                        [p]
                            His inspection finished, the wolf lets go of your cranium.
                            You quickly pull yourself away from his loins, expecting him to depart.
                            Fenrir, however, seems to have something else in mind.
                            He stares down at you, with a lecherous look on his face.
                        [/p]`;
            }
        }

        if (!nameKnown) {
            toReturn += `[p]
                            "[color=gblue]I had a few of my men ask around during the night.
                            The forest has loose lips, if you know where to pry.[/color]"
                            Huh?
                            He sent out [i]spies[/i]?
                            "[color=gblue]${name}.
                            That's your name, right?[/color]"
                            You stare up at the lupine in amazement and disbelief.
                            Barely [b]anyone[/b] around here knows your name.
                            He chuckles.
                            "[color=gblue]It fits you.[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            The wolf moves one of his hands to his groin.
                            He boldly, brazenly and crudely cups the hefty, furred nuts that swing underneath his thick sheath,
                            propping them forwards as if to [i]entice[/i] you.
                            "[color=gblue]Look, ${name}, I know we got off on a bad start.
                            ${fucked ? `In the forest, ${enjoyed ? `you sounded like you'd make a good slave,
                            but then when we got to the camp, your enthusiasm vanished.` : `I had to [b]force[/b] myself upon you,
                            and then when we got back to camp, you refused to follow even the simplest of commands.`}` : `First you blueballed me in the forest,
                            and then you failed to obey some simple commands in front of the caravan master.`}
                            Granted, you're not [i]as[/i] bad as I first made you out to be, but still, you embarrassed me in front of that [b]moronic human[/b].
                            And that's not something I can appreciate.[/color]"
                        [/p]
                        [p]
                            The canine licks his lips lustfully, his stern glare contrasting sharply with his body language.
                            For a moment, you ${enjoyed ? `reckon` : `fear`} he might try to force himself on you again,
                            but you don't know.
                            He's sending you some seriously mixed signals.
                            "[color=gblue]From the moment ${fucked ? `I took your virginity` : `you told me you were a virgin`},
                            I [b]knew[/b] you were different from all the other kobolds.
                            Unlike the others, you understand that not [i]all[/i] of life's problems can be solved through [b]violence[/b],
                            or by [b]crying[/b] until you get your way.
                            But being [b]uppity[/b] and [b]refusing[/b] to cooperate is [i]almost[/i] every bit as bad.[/color]"
                        [/p]
                        [p]
                            You don't understand.
                            Are you being scolded, or is he about to ask you to suck his dick or something?
                            "[color=gblue]I can make life [b]a lot[/b] easier for you, you know.
                            I can bring you some [i]actual[/i] food at night,
                            I can tell the gang to [i]take it easy[/i] on you,
                            I can even ask that [b]filthy[/b] human,
                            who I am [b]temporarily[/b] [i]indentured[/i] to,
                            to keep things relatively [i]tame[/i] with you.[/color]"
                        [/p]
                        [p]
                            A bunch of benefits, but you're [b]very[/b] certain that all of this has a [b]price[/b].
                            Bandits like the wolf never hand out favors for [b]free[/b].
                            "[color=gblue]Let's face the facts here.
                            That [b]fat fuck[/b] thinks he can [i]sell[/i] you.
                            But both you and me know that there's [b]plenty[/b] of slaves to go around.
                            It's an [i]oversaturated[/i] market.[/color]"
                            Fancy words, for a brigand.
                            Then again, he [i]is[/i] their leader.
                            "[color=gblue]You aren't the best product around, either.
                            People would much rather have a well-trained servant than an uppity [b]${dick ? `jerk` : `cunt`}[/b].
                            And, as you've no-doubt overheard, the caravan master only has two tries to auction you off.
                            After that, you'll be [b]mine[/b].[/color]"
                        [/p]
                        [p]
                            You repress the urge to tell the lupine to get to the point already.
                            It seems you've [i]irked[/i] him, and you'd hate to upset him further.
                            "[color=gblue]I won't lie.
                            You're going to be fucked, gangbanged, spitroasted and ran a train on by every single last member of my group.
                            Including the dog.
                            This [b]is[/b] going to happen, whether you like it or not.
                            But if you play along, then none of us will have any reason to treat you poorly.
                            If you don't, well...
                            Let's just say we could always use a punching bag for training on.[/color]"
                        [/p]
                        [p]
                            You get the feeling he's not kidding about that threat.
                            "[color=gblue]The Furskin Mountain-Crew will treat you fairly, for a kobold.
                            You'll be fed scraps, you'll have a tent or a cart or at worst a dog-house to sleep in,
                            and you'll be kept safe [i]for the most part[/i].[/color]"
                            You don't like the sound of that last bit.
                            "[color=gblue]All I ask in return, is a simple sign of subservience.
                            You won't [i]officially[/i] be [b]my[/b] slave until the second auction fails.
                            Consider this your [i]probational[/i] period.[/color]"
                        [/p]
                        [p]
                            You knew it.
                            The wolf may use fancy words and beat around the bush a lot, but in the end he's no better than a simple highwayman,
                            only instead of coercing money out of you, he's trying to extort your very [i]diginity[/i] itself.
                            "[color=gblue]So how about it, [b]slave[/b]?
                            All I want is a little good morning kiss.
                            Right on top of the balls that
                            ${fucked ? `squirted their contents all over your body` : `you denied release`} yesterday.[/color]"
                        [/p]
                        [p]
                            As if to accentuate his statement, the wolf taps his furred nuts,
                            rolling his hips forwards ever so slightly to hold them a little closer to your mouth.
                            Part of your mind is honestly [i]considering[/i] Fenrir's offer.
                            Should both the auctions fail, at least you won't end up as a [i]training dummy[/i].
                            And it's just a simple kiss.
                            But then again, you don't want to degrade yourself any more than you already have.
                            Besides, you plan on escaping long before you become the lupine's property.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width: 190px;">Do nothing</button>`;

        var tooltip = global.parser.parse(`Remain in place. Do not act. Let the canine draw his own conclusions.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width: 190px;">Decline</button>`;

        var tooltip = global.parser.parse(`You don't want to be anywhere [b]near[/b] the wolf's loins.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width: 190px;">Insult</button>`;

        var tooltip = global.parser.parse(`Who the hell does Fenrir think he is?! Tell him to get lost.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }
    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width: 190px;">Attack</button>`;

        var tooltip = global.parser.parse(`Fight the wolf. Freedom or death!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 145px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFifthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fifthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fifthId}" ${disabled} style="width: 190px;">Reluctantly kiss</button>`;

        var tooltip = global.parser.parse(`Ugh. Do you [i]really[/i] have to do this?`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSixthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === sixthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${sixthId}" ${disabled} style="width: 190px;">Eagerly kiss</button>`;

        var tooltip = global.parser.parse(`You really don't want to get on this guy's bad side. Better show him you mean it.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 225px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildFourthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFifthChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSixthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId), $("#" + fifthId), $("#" + sixthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFifthListener() {
        $("#" + fifthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fifthChoice);
            loadNextPart(fifthNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSixthListener() {
        $("#" + sixthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(sixthChoice);
            loadNextPart(sixthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        part += fifthNext.build();
        part += sixthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();
        fifthNext.registerListeners();
        sixthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
        registerFifthListener();
        registerSixthListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoMakeUpOffer.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoGoodOffer.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoGoodOffer(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;

    var toFail = new SlaveNoonTwoMakeUpOffer(ctrl);
    var toSuccess = new SlaveNoonTwoSimpleOffer(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return global.kobold.history.shared.enslavement.nightOne.complianceRating > 6;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\good\SlaveNoonTwoGoodOffer.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\SlaveNoonTwoProposition.js

/**
 * Proposition section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoProposition(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = ctrl.preBlackmail;

    var toFail = new SlaveNoonTwoBadOffer(ctrl);
    var toSuccess = new SlaveNoonTwoGoodOffer(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Checks whether the choice succeeded or failed.
     */
    function successCheck() {
        return global.kobold.history.shared.enslavement.nightOne.complianceRating > 3;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (successCheck()) {
            part += toSuccess.build();
        } else {
            part += toFail.build();
        }
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (successCheck()) {
            toSuccess.registerListeners();
        } else {
            toFail.registerListeners();
        }
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\proposition\SlaveNoonTwoProposition.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoLookOut.js

/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoLookOut(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoArrivalChoice.LOOKOUT;
    var reqController = ctrl.arrival;
    var subController = ctrl.preBlackmail;
    var changeController = ctrl.preBlackmail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.proposition;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            ${bindings ? `You try to cover your eyes with your hands,
                            but find them still bound from the night before.
                            Instead, you roll over onto your side,
                            hiding your visage from the beaming sunlight,
                            letting it warm your back instead.` : `You cover your eyes with your hands,
                            protecting your delicate sight from the beaming sunlight.`}
                        [/p]
                        [p]
                            Despite having been out for what you can only presume to be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet,
                            but since you're awake, you might as well start trying to figure out where you are,
                            and more importantly: how you're going to [b]escape[/b].
                        [/p]
                        [p]
                            Your heavy eyelids slowly open.
                            ${bindings ? `You wish you could wipe some of the crud from your eyes.` : `You wipe some of the crud from your eyes.`}
                            Your vision is blurry, but it rapidly sharpens.
                            Despite not feeling like you're ready to face the light,
                            you decide to give it a go anyway.
                        [/p]
                        [p]
                            ${bindings ? `Rolling onto your back once again` : `Removing your hands from your head`},
                            you accidentally stare directly into the sun,
                            scorching your retinas for a couple of milliseconds before you manage to avert your gaze.
                            Your eyes hurt.
                            Your headache flares up.
                            This was a mistake.
                        [/p]
                        [p]
                            Keeping your eyelids closed, you slowly scramble to your feet${bindings ? `, hindered, but not stopped by your bindings` : ``}.
                            After resting against the side of the cart for a moment, you slowly open your eyes once again.
                            Stepping on your tippy-toes, you peer through the iron bars lining the wooden walls.
                        [/p]
                        [p]
                            The brightly lit outside world is painful to look at, but not nearly as harmful as the sun itself.
                            You see a few shabby houses alongside a dirt road, followed by large stretches of farmland in their backyards.
                            You recognize this area.
                            You've been here before.
                            It's a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]
                        [p]
                            A subtle [i]click[/i] resonates throughout your cell.
                            The door swings open widly, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your killer headache.
                            Turning to face the entryway, you witness Fenrir, the wolf that caught you the other day,
                            entering the jail-like carriage.
                            He is completely [b]naked[/b].
                        [/p]
                        [p]
                            "[color=gblue]Good morning, [b]lizard[/b]![/color]" the wolf booms,
                            his loud voice unknowingly [b]torturing[/b] your sleep-deprived brain.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        } else {
            toReturn += `[p]
                            You try to cover your eyes with your hands,
                            but find them still bound from the night before.
                            Instead, you roll over onto your side,
                            hiding your visage from the beaming sunlight,
                            letting it warm your back instead.
                        [/p]
                        [p]
                            Despite having slept for what you can only presume be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] your nap.
                            You could use a few extra hours of peace and quiet,
                            but since you're already awake, you might as well start trying to figure out where you are,
                            and more importantly: how you're going to [b]escape[/b].
                        [/p]
                        [p]
                            Your heavy eyelids slowly open.
                            You wish you could wipe some of the crud from your eyes.
                            Your vision is blurry, but it rapidly sharpens.
                            Despite not feeling like you're ready to face the light,
                            you decide to give it a go anyway.
                        [/p]
                        [p]
                            Rolling onto your back once again,
                            you accidentally stare directly into the sun,
                            scorching your retinas for a couple of milliseconds before you manage to avert your gaze,
                            hurting your eyes.
                            Your budding headache flares up.
                            This was a mistake.
                        [/p]
                        [p]
                            Keeping your eyelids closed, you slowly scramble to your feet, hindered, but not stopped by your bindings.
                            After resting against the side of the cart for a moment, you slowly open your eyes once again.
                            Stepping on your tippy-toes, you gaze through the iron bars lining the wooden walls.
                        [/p]
                        [p]
                            The brightly lit outside world is painful to look at, but not nearly as harmful as the sun itself.
                            You see a few shabby houses alongside a dirt road, followed by large stretches of farmland in their backyards.
                            You recognize this place.
                            You've been here before.
                            While asleep, you were taken to a place known simply as [i]the hamlet[/i],
                            a small village close to the human capital of Varanar.
                        [/p]
                        [p]
                            An old friend of yours lives here.
                            Seki, the alchemist-owl, who also happens to happily buy whatever stolen goods you bring him.
                            Besides being your [i]fence[/i], he's also the closest thing to a [i]father[/i] you've ever had.
                            Maybe [b]he[/b] can help you get out of this [b]mess[/b].
                        [/p]
                        [p]
                            A subtle [i]click[/i] resonates throughout your cell.
                            The door swings open widly, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your headache.
                            Turning to face the entryway, you witness Fenrir, the wolf that caught you the other day,
                            entering the jail-like carriage.
                            He is completely [b]naked[/b].
                        [/p]
                        [p]
                            "[color=gblue]Good morning, [b]lizard[/b]![/color]" the wolf booms,
                            his loud voice unknowingly [b]torturing[/b] your sleep-deprived brain.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoLookOut.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoRest.js

/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoRest(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = SlaveNoonTwoArrivalChoice.REST;
    var reqController = ctrl.arrival;
    var subController = ctrl.preBlackmail;
    var changeController = ctrl.preBlackmail;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.proposition;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;
        var bindings = !global.kobold.history.shared.enslavement.nightOne.escapedBindings;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            You wearily roll over onto your side, hiding your visage from the beaming sunlight, letting it warm your back instead.
                            Despite having been out for what you can only presume to be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet.
                            You can worry about escaping this cell later.
                        [/p]
                        [p]
                            Right as you could feel reality starting to slip away once again,
                            a subtle [i]click[/i] resonates throughout your cell.
                            The wooden door widly swings open, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] sinking into your skull, worsening your killer headache.
                            Footsteps.
                            Your half-conscious mind distantly realizes someone is entering the cart.
                        [/p]
                        [p]
                            [big][color=gblue][b]Rise and shine, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The booming voice is [b]agonizingly[/b] loud,
                            your head feeling like it's about to [b]burst[/b].
                            ${bindings ? `You instinctively try to move your hands to your forehead,
                            but find them still bound from the night before.` : `You instinctively move your hands to your forehead
                            to [b]try[/b] to cope with the horrible sensation.`}
                            Your heavy eyelids slowly open.
                            In your blurry vision you can see a pair of grey-furred feet standing in the doorway.
                            You slept so poorly, you almost feel like you have a bad hangover.
                        [/p]
                        [p]
                            You try to [b]beg[/b] for just a few more minutes of rest, but nothing intelligent escapes your muzzle.
                            Instead, you let out a mixture between a whine, a groan and a growl.
                            "[color=gblue]I said [b]get up[/b], lizard.[/color]" the wolf repeats.
                            In an effort to force you awake, he repeatedly bangs his foot against the floor,
                            unknowingly [b]torturing[/b] your sleep-deprived brain.
                        [/p]
                        [p]
                            Almost reduced to tears from the intense pain, your aching mind snaps to life.
                            While your sight is still hazy, you open your eyes further, and tilt your gaze up to meet his.
                            Fenrir.
                            That was his name.
                            The wolf that caught you the other day.
                            And he's [i]naked[/i], this time around.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        } else {
            toReturn += `[p]
                            You wearily roll over onto your side, hiding your visage from the beaming sunlight, letting it warm your back instead.
                            Despite having slept for what you can only presume be over half a day,
                            you still don't feel very refreshed.
                            In fact, you feel more drained than [i]before[/i] you passed out.
                            You could use a few extra hours of peace and quiet.
                            You can worry about escaping this cell later.
                        [/p]
                        [p]
                            Right as you could feel reality starting to slip away once again,
                            a subtle [i]click[/i] resonates throughout your cell.
                            The wooden door widly swings open, banging against the exterior wall,
                            the loud noise like a [b]dagger[/b] piercing your unconsciousness, worsening your headache.
                            Footsteps.
                            Your half-asleep mind distantly realizes someone is entering the cart.
                        [/p]
                        [p]
                            [big][color=gblue][b]Rise and shine, slave![/b][/color][/big]
                        [/p]
                        [p]
                            The booming voice is [b]agonizingly[/b] loud,
                            your head feeling like worse with every passing second.
                            You instinctively try to move your hands to your forehead,
                            but find them still bound from the night before.
                            Your heavy eyelids slowly open.
                            In your blurry vision you can see a pair of grey-furred feet standing in the doorway.
                            You slept so poorly, you almost feel like you have a hangover.
                        [/p]
                        [p]
                            You try to [b]beg[/b] for just a few more minutes of rest, but nothing intelligent escapes your muzzle.
                            Instead, you let out a mixture between a whine, a groan and a growl.
                            "[color=gblue]I said [b]get up[/b], lizard.[/color]" the wolf repeats.
                            In an effort to force you awake, he repeatedly bangs his foot against the floor,
                            unknowingly [b]torturing[/b] your sleep-deprived brain.
                        [/p]
                        [p]
                            Almost reduced to tears from the intensifying pain, your aching mind snaps to life.
                            While your sight is still hazy, you open your eyes a further, and tilt your gaze up to meet his.
                            Fenrir.
                            That was his name.
                            The wolf that caught you the other day.
                            And he's [i]naked[/i], this time around.
                            You sigh internally.
                            You wish [b]all[/b] of yesterday had been part of your nightmare.
                            But alas, no such luck.
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoRest.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoArrival.js

/**
 * Arrival section of Enslavement, Noon Two.
 * @param {SlaveNoonTwoController} controller The Enslavement, Noon Two controller.
 */
function SlaveNoonTwoArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = ctrl.arrival;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new SlaveNoonTwoLookOut(ctrl);
    var secondNext = new SlaveNoonTwoRest(ctrl);

    var firstChoice = SlaveNoonTwoArrivalChoice.LOOKOUT;
    var secondChoice = SlaveNoonTwoArrivalChoice.REST;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = ``;

        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            toReturn += `[p]
                            After getting knocked out, you find yourself trapped in ever-more-troubled slumber.
                            Bad dreams come and go,
                            some of the nightmares [i]lifelike[/i] enough to make you toss and tumble around the floor of your wooden cell.
                            The distant sensation of the caravan [i]moving[/i] isn't helping either.
                            Like an insidious poison, it seeps into your mind to corrupt and twist your feverish near-hallucinations further.
                        [/p]
                        [p]
                            The slow, rhythmic clopping of hooves,
                            the slight creaking of wood,
                            the clattering of the accompanying guards' armor,
                            and the lively sounds of the awakening forest,
                            all of these make your brain think back to the act that got you into this situation in the first place.
                            Robbing the transport.
                            That's where it all went wrong.
                        [/p]
                        [p]
                            You dream of how much [b]worse[/b] things could have gone.
                            How the ruffians protecting the transport could have seen you and killed you on the spot.
                            How they might have [b]tortured[/b] you to [b]death[/b].
                            Every scene seems more lifelike than the last.
                            Getting impaled by a spear.
                            Having your loins [b]mutilated[/b] and your tail cut off.
                            Them flaying your scales and feeding your flesh to their dog.
                            Luckily, right as the imaginary caravan master is about to bring a knife to bear on your forcibly held-open eyes,
                            one of the wheels of the cart you are in hits a rock, and the bump is enough to tear you from your hellish imagination.
                        [/p]
                        [p]
                            You let out an exasperated groan.
                            Your head [b]hurts[/b].
                            Your mind slowly rouses from unconsciousness.
                            A bright light is shining into your still-closed eyes, worsening your heavy migraine.
                            The sun?
                            Feels hot enough to be [b]noon[/b].
                            Is it [b]that[/b] late?
                        [/p]`;
        } else {
            toReturn += `[p]
                            Drifting asleep, you find yourself trapped in ever-more-troubled slumber.
                            Bad dreams come and go,
                            some of the nightmares [i]lifelike[/i] enough to make you toss and tumble around the floor of your wooden cell.
                            The distant sensation of the caravan [i]moving[/i] isn't helping either.
                            Like an insidious poison, it seeps into your mind to corrupt and twist your feverish near-hallucinations further.
                        [/p]
                        [p]
                            The slow, rhythmic clopping of hooves,
                            the slight creaking of wood,
                            the clattering of the accompanying guards' armor,
                            and the lively sounds of the awakening forest,
                            all of these make your brain think back to the act that got you into this situation in the first place.
                            Robbing the transport.
                            That's where it all went wrong.
                        [/p]
                        [p]
                            You dream of how much [b]worse[/b] things could have gone.
                            How the ruffians protecting the transport could have seen you and killed you on the spot.
                            How they might have [b]tortured[/b] you to [b]death[/b].
                            Every scene seems more lifelike than the last.
                            Getting impaled by a spear.
                            Having your loins [b]mutilated[/b] and your tail cut off.
                            Them flaying your scales and feeding your flesh to their dog.
                            Luckily, right as the imaginary caravan master is about to bring a knife to bear on your forcibly held-open eyes,
                            one of the wheels of the cart you are in hits a rock, and the bump is enough to tear you from your hellish imagination.
                        [/p]
                        [p]
                            You let out an exasperated groan.
                            You have a slight headache.
                            Your mind slowly rouses from unconsciousness.
                            A bright light is shining into your still-closed eyes, worsening your budding migraine.
                            The sun?
                            Feels hot enough to be [b]noon[/b].
                            Is it [b]that[/b] late?
                        [/p]`;
        }

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Look outside</button>`;

        var tooltip = global.parser.parse(`Rise and shine. Find out where you are.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Rest more</button>`;

        var tooltip = global.parser.parse(`It's too early. You need some more sleep.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var SlaveNoonTwoArrivalChoice = {
    LOOKOUT: 1,
    REST: 2
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\arrival\SlaveNoonTwoArrival.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\SlaveNoonTwoController.js

/**
 * Controller for the Enslavement, Noon Two scene.
 * @param {string} sceneId The id of the scene.
 */
function SlaveNoonTwoController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "SlaveAfternoonTwo";
    this.nextFolderName = "Enslavement/DayTwo";

    this.sekiSceneReady = true;
    this.sekiSceneName = "SekiWorkshop";
    this.sekiFolderName = "HamletDay2";

    this.farmerSceneReady = false;
    this.farmerSceneName = "FarmerSlave";
    this.farmerFolderName = "Enslavement";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChangeController(id, "arrival", function () {
        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            global.kobold.status.physical.increase(4, "Troubled sleep");
            global.kobold.status.mental.decrease(8, "Nightmares");
            global.kobold.status.stamina.increase(6, "Troubled sleep");
        } else {
            global.kobold.status.physical.increase(4, "Troubled sleep");
            global.kobold.status.mental.increase(4, "Nightmares");
            global.kobold.status.stamina.increase(6, "Troubled sleep");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            return global.ui.change.buildNotification([
                new Change("Troubled sleep", "Health", +4),
                new Change("Long unconsciousness", "Sanity", -4),
                new Change("Nightmares", "Sanity", -4),
                new Change("Meagre rest", "Stamina", +6)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Troubled sleep", "Health", +4),
                new Change("Slept", "Sanity", +8),
                new Change("Nightmares", "Sanity", -4),
                new Change("Meagre rest", "Stamina", +6)
            ]);
        }
    });

    this.preBlackmail = new ChangeController(id, "preBlackmail", function () {
        if (that.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                global.kobold.status.physical.decrease(7, "Killer headache");
                global.kobold.status.mental.decrease(2, "Woke up early");
            } else {
                global.kobold.status.physical.decrease(5, "Headache");
                global.kobold.status.mental.decrease(2, "Woke up early");
            }
        } else {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                global.kobold.status.physical.decrease(5, "Killer headache");
                global.kobold.status.mental.decrease(4, "Crude awakening");
            } else {
                global.kobold.status.physical.decrease(3, "Headache");
                global.kobold.status.mental.decrease(4, "Crude awakening");
            }
        }
    }, function () {
        if (that.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                return global.ui.change.buildNotification([
                    new Change("Stared into the sun", "Health", -2),
                    new Change("Killer headache", "Health", -5),
                    new Change("Waking up early", "Sanity", -2)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Stared into the sun", "Health", -2),
                    new Change("Headache", "Health", -3),
                    new Change("Waking up early", "Sanity", -2)
                ]);
            }
        } else {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                return global.ui.change.buildNotification([
                    new Change("Killer headache", "Health", -5),
                    new Change("Crude awakening", "Sanity", -4)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Headache", "Health", -3),
                    new Change("Crude awakening", "Sanity", -4)
                ]);
            }
        }
    });

    this.offer = new ChangeController(id, "offer", function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            global.kobold.status.mental.decrease(2, "Indecent proposal");
        } else {
            global.kobold.status.mental.increase(2, "Indecent proposal");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            return global.ui.change.buildNotification([
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Hands freed", "Sanity", +4),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        }
    });

    this.blackmail = new ChangeController(id, "blackmail", function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            global.kobold.status.mental.decrease(5, "Indecent proposal");
        } else {
            global.kobold.status.mental.decrease(1, "Indecent proposal");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            return global.ui.change.buildNotification([
                new Change("Grim future", "Sanity", -3),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Hands freed", "Sanity", +4),
                new Change("Grim future", "Sanity", -3),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        }
    });

    this.goodNothing = new ChangeController(id, "goodNothing", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+4);
        global.kobold.status.mental.decrease(2, "Inability to decide");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Inability to decide", "Sanity", -2)
        ]);
    });

    this.goodDecline = new ChangeController(id, "goodDecline", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+3);
        global.kobold.status.mental.increase(5, "Stood up for yourself");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5)
        ]);
    });

    this.goodInsult = new ChangeController(id, "goodInsult", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.mental.increase(4, "Stood up for yourself");
        global.kobold.status.stamina.decrease(2, "Excessive insulting");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Went a little overboard", "Sanity", -1),
            new Change("Excessive insulting", "Stamina", -2)
        ]);
    });

    this.goodAttack = new ChangeController(id, "goodAttack", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.mental.increase(1, "Blind rage");
        global.kobold.status.stamina.decrease(5, "Wild flailing");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Resorted to violence", "Sanity", -2),
            new Change("Blind rage", "Sanity", -2),
            new Change("Wild flailing", "Stamina", -5)
        ]);
    });

    this.goodReluctant = new ChangeController(id, "goodReluctant", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+5);
        global.kobold.status.mental.decrease(7, "Kissing balls");
        global.kobold.status.exertion.increase(5, "Kissing balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Humiliation", "Sanity", -10),
            new Change("Amused Fenrir", "Sanity", +3),
            new Change("Kissing balls", "Sexual exhaustion", +5, true)
        ]);
    });

    this.goodEager = new ChangeController(id, "goodEager", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+6);
        global.kobold.status.mental.increase(3, "Pleasing Fenrir");
        global.kobold.status.exertion.increase(10, "Worshipping balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stockholm syndrome", "Sanity", -2),
            new Change("Pleased Fenrir", "Sanity", +5),
            new Change("Eager ball-licking", "Sexual exhaustion", +10, true)
        ]);
    });

    this.badNothing = new ChangeController(id, "badNothing", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+4);
        global.kobold.status.mental.decrease(5, "Impending doom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Inability to decide", "Sanity", -2),
            new Change("Impending doom", "Sanity", -3)
        ]);
    });

    this.badDecline = new ChangeController(id, "badDecline", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+3);
        global.kobold.status.mental.increase(2, "Impending doom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Impending doom", "Sanity", -3)
        ]);
    });

    this.badInsult = new ChangeController(id, "badInsult", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.mental.increase(1, "Impending doom");
        global.kobold.status.stamina.decrease(2, "Excessive insulting");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Went a little overboard", "Sanity", -1),
            new Change("Impending doom", "Sanity", -3),
            new Change("Excessive insulting", "Stamina", -2)
        ]);
    });

    this.badAttack = new ChangeController(id, "badAttack", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.mental.decrease(2, "Impending doom");
        global.kobold.status.stamina.decrease(5, "Wild flailing");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Resorted to violence", "Sanity", -2),
            new Change("Blind rage", "Sanity", -2),
            new Change("Impending doom", "Sanity", -3),
            new Change("Wild flailing", "Stamina", -5)
        ]);
    });

    this.badReluctant = new ChangeController(id, "badReluctant", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+5);
        global.kobold.status.mental.decrease(5, "Kissing balls");
        global.kobold.status.exertion.increase(5, "Kissing balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Humiliation", "Sanity", -10),
            new Change("Avoided gag", "Sanity", +5),
            new Change("Kissing balls", "Sexual exhaustion", +5, true)
        ]);
    });

    this.badEager = new ChangeController(id, "badEager", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+6);
        global.kobold.status.mental.increase(8, "Pleasing Fenrir");
        global.kobold.status.exertion.increase(10, "Worshipping balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stockholm syndrome", "Sanity", -2),
            new Change("Pleased Fenrir", "Sanity", +5),
            new Change("Avoided gag", "Sanity", +5),
            new Change("Eager ball-licking", "Sexual exhaustion", +10, true)
        ]);
    });

    this.preGag = new ChoiceController(id, "preGag");

    this.gag = new ChoiceController(id, "gag");

    this.gagRefuse = new ChangeController(id, "gagRefuse", function () {
        global.kobold.inventory.equipment.wear(new UnderwearGag());
        global.kobold.status.physical.decrease(10, "Underwear gag");
        global.kobold.status.mental.decrease(14, "Underwear gag");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Kidney punched", "Health", -7),
            new Change("Unhygienic gag", "Health", -3),
            new Change("Rancid taste", "Sanity", -10),
            new Change("Humiliation", "Sanity", -4)
        ]);
    });

    this.gagOpen = new ChangeController(id, "gagOpen", function () {
        global.kobold.inventory.equipment.wear(new UnderwearGag());
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.physical.decrease(3, "Underwear gag");
        global.kobold.status.mental.decrease(9, "Underwear gag");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Unhygienic gag", "Health", -3),
            new Change("Kept pride", "Sanity", +5),
            new Change("Rancid taste", "Sanity", -10),
            new Change("Humiliation", "Sanity", -4)
        ]);
    });

    this.preInject = new ChoiceController(id, "preInject");

    this.inject = new ChangeController(id, "inject", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick + 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts + 1)
        }
        global.kobold.status.physical.decrease(4, "Pricked by needle");
        global.kobold.status.mental.decrease(12, "Forced transformation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Pricked by needle", "Health", -4),
            new Change("Forced transformation", "Sanity", -8),
            new Change("Unvented frustration", "Sanity", -4)
        ]);
    });

    this.potion = new ChoiceController(id, "potion");

    this.neither = new ChangeController(id, "neither", function () {
        global.kobold.status.mental.increase(4, "Kind gesture");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Kind gesture", "Sanity", +6)
        ]);
    });

    this.mPlus = new ChangeController(id, "mPlus", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick + 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts - 1);
        }
        global.kobold.status.mental.increase(4, "Kind present");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Received present", "Sanity", +6),
            new Change("Transformation", "Sanity", -2)
        ]);
    });

    this.femPlus = new ChangeController(id, "femPlus", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick - 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts + 1);
        }
        global.kobold.status.mental.increase(4, "Kind present");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Received present", "Sanity", +6),
            new Change("Transformation", "Sanity", -2)
        ]);
    });

    this.preOutside = new ChangeController(id, "preOutside");

    this.outside = new ChangeController(id, "outside", function () {
        global.kobold.status.mental.decrease(4, "Public nudity");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Public nudity", "Sanity", -4)
        ]);
    });

    this.batheBad = new ChangeController(id, "batheBad", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.physical.decrease(3, "Terrible hygiene");
        global.kobold.status.mental.decrease(15, "Bathing in animal spit");
        global.kobold.stats.decreaseStat(StatsEnum.CHARISMA, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Terrible hygiene", "Health", -3),
            new Change("Bathing in spit", "Sanity", -6),
            new Change("Fenrir's masturbation", "Sanity", -4),
            new Change("Captor standoff", "Sanity", -2),
            new Change("Lingering smell", "Charisma", -1)
        ]);
    });

    this.batheGood = new ChangeController(id, "batheGood", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.physical.decrease(3, "Terrible hygiene");
        global.kobold.status.mental.decrease(4, "Bathing in animal spit");
        global.kobold.stats.decreaseStat(StatsEnum.CHARISMA, 1);
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Terrible hygiene", "Health", -3),
            new Change("Bathing in spit", "Sanity", -6),
            new Change("Pleased Fenrir", "Sanity", +2),
            new Change("Lingering smell", "Charisma", -1)
        ]);
    });

    this.drinkBad = new ChangeController(id, "drinkBad", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.physical.decrease(5, "Drinking animal spit");
        global.kobold.status.mental.decrease(5, "Drinking animal spit");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hydration", "Health", +3),
            new Change("Drinking spit", "Health", -3),
            new Change("Butt kicked", "Health", -2),
            new Change("Bathing in spit", "Health", -3),
            new Change("Hydration", "Sanity", +3),
            new Change("Drinking spit", "Sanity", -4),
            new Change("Pain", "Sanity", -2),
            new Change("Captor standoff", "Sanity", -2)
        ]);
    });

    this.drinkGood = new ChangeController(id, "drinkGood", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.physical.increase(0, "Drinking animal spit");
        global.kobold.status.mental.decrease(4, "Drinking animal spit");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Hydration", "Health", +3),
            new Change("Drinking spit", "Health", -3),
            new Change("Hydration", "Sanity", +3),
            new Change("Drinking spit", "Sanity", -4),
            new Change("Irony", "Sanity", -1),
            new Change("Captor standoff", "Sanity", -2)
        ]);
    });

    this.refuseBad = new ChangeController(id, "refuseBad", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(0);
        global.kobold.status.mental.decrease(3, "Standoff with Fenrir");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Intense standoff", "Sanity", -4),
            new Change("Captor standoff", "Sanity", -2),
            new Change("Avoided spit-trough", "Sanity", +3)
        ]);
    });

    this.refuseGood = new ChangeController(id, "refuseGood", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(0);
        global.kobold.status.mental.increase(5, "Fenrir's favor");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Avoided spit-trough", "Sanity", +3),
            new Change("Fenrir's favor", "Sanity", +4),
            new Change("Captor standoff", "Sanity", -2)
        ]);
    });

    this.preStage = new ChoiceController(id, "preStage");

    this.stage = new ChangeController(id, "stage", function () {
        global.kobold.status.physical.decrease(2, "Thrown onto stage");
        global.kobold.status.mental.decrease(6, "Safety concerns");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Thrown onto stage", "Health", -2),
            new Change("Naked in front of crowd", "Sanity", -2),
            new Change("Insulted and degraded", "Sanity", -2),
            new Change("Fearing for safety", "Sanity", -2)
        ]);
    });

    this.pose = new ChangeController(id, "pose", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(2);
        global.kobold.status.mental.decrease(2, "Willing exhibition");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Willing exhibition", "Sanity", -4),
            new Change("Pleased caravan master", "Sanity", +2)
        ]);
    });

    this.refuse = new ChangeController(id, "refuse", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(0);
        global.kobold.status.physical.decrease(14, "Gut-punch");
        global.kobold.status.mental.decrease(12, "Pain");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Choked", "Health", -6),
            new Change("Gut-punched", "Health", -8),
            new Change("Pain", "Sanity", -6),
            new Change("Crowd schadenfreude", "Sanity", -6)
        ]);
    });

    this.smile = new ChangeController(id, "smile", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(1);
        global.kobold.status.mental.increase(0, "Reluctant smile");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Reluctant smile", "Sanity", -2),
            new Change("Pleased caravan master", "Sanity", +2)
        ]);
    });

    this.preResult = new ChoiceController(id, "preResult");

    this.result = new ChoiceController(id, "result");

    this.nobody = new ChangeController(id, "nobody", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.seki = new ChangeController(id, "seki", function () {
        global.kobold.status.mental.increase(5, "Saved by Seki");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Saved", "Sanity", +10),
            new Change("Scolded", "Sanity", -5)
        ]);
    });

    this.farmer = new ChangeController(id, "farmer", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.outsideComplianceStorage = new ChoiceController(id, "outsideComplianceStorage");
    this.resultComplianceStorage = new ChoiceController(id, "resultComplianceStorage");
    this.resultBodyMisc = new MiscController(id, "resultBody");

    this.fragments = {};
    this.fragments.results = new SlaveNoonTwoResults(this);
    this.fragments.stage = new SlaveNoonTwoStage(this);
    this.fragments.outside = new SlaveNoonTwoOutside(this);
    this.fragments.gagged = new SlaveNoonTwoBadGag(this);
    this.fragments.notGagged = new SlaveNoonTwoGoodPotion(this);
    this.fragments.proposition = new SlaveNoonTwoProposition(this);

    //this.bgm = new AudioController(id, "res/audio/effects/cave.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

var SlaveNoonTwoOfferChoice = {
    NOTHING: 1,
    DECLINE: 2,
    INSULT: 3,
    ATTACK: 4,
    RELUCTANT: 5,
    EAGER: 6
};

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\SlaveNoonTwoController.js

// scenes\Enslavement\DayTwo\SlaveNoonTwo\SlaveNoonTwo.js

/**
 * Noon two of enslavement.
 */
function SlaveNoonTwo() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "SlaveNoonTwo";
    var sceneName = "Enslavement, Noon Two";
    var sceneSubfolder = "Enslavement/DayTwo";
    var ctrl = new SlaveNoonTwoController(sceneId);
    var arrival = new SlaveNoonTwoArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]Enslavement[/t]`);
        tab += global.parser.parse(`[st]Noon two[/st]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new SlaveNoonTwo();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\Enslavement\DayTwo\SlaveNoonTwo\SlaveNoonTwo.js



// END SCENE SlaveNoonTwo

